@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007-2011 Steven L. Scott
 
@@ -19,21 +20,21 @@
 #ifndef BOOM_ARRAY_HPP
 #define BOOM_ARRAY_HPP
 
-#include <LinAlg/Vector.hpp>
-#include <LinAlg/VectorView.hpp>
-#include <LinAlg/Matrix.hpp>
-#include <LinAlg/SpdMatrix.hpp>
-#include <LinAlg/ArrayIterator.hpp>
+#include "LinAlg/ArrayIterator.hpp"
+#include "LinAlg/Matrix.hpp"
+#include "LinAlg/SpdMatrix.hpp"
+#include "LinAlg/Vector.hpp"
+#include "LinAlg/VectorView.hpp"
 
 #include <vector>
-#include <cpputil/report_error.hpp>
+#include "cpputil/report_error.hpp"
 
-namespace BOOM{
+namespace BOOM {
   // ConstArrayBase implements the const methods common to the Array
   // class and its views.  It implements all size-related queries, as
   // well as indexing and equality comparisons.
 
-  class ConstArrayBase{
+  class ConstArrayBase {
    public:
     ConstArrayBase();
     ConstArrayBase(const ConstArrayBase &rhs) = default;
@@ -43,21 +44,21 @@ namespace BOOM{
                    const std::vector<int> &strides);
     virtual ~ConstArrayBase() {}
 
-    ConstArrayBase & operator=(const ConstArrayBase &rhs) = default;
-    ConstArrayBase & operator=(ConstArrayBase &&rhs) = default;
+    ConstArrayBase &operator=(const ConstArrayBase &rhs) = default;
+    ConstArrayBase &operator=(ConstArrayBase &&rhs) = default;
 
-    virtual const double *data()const=0;
+    virtual const double *data() const = 0;
 
     double operator[](const std::vector<int> &index) const;
 
-    int ndim() const {return dims_.size();}
-    int dim(int i) const {return dims_[i];}
-    const std::vector<int> &dim() const {return dims_;}
+    int ndim() const { return dims_.size(); }
+    int dim(int i) const { return dims_[i]; }
+    const std::vector<int> &dim() const { return dims_; }
 
     // stride(i) is the number of steps you must advance in data()
     // to increment the i'th index by one.
-    int stride(int i) const {return strides_[i];}
-    const std::vector<int> &strides() const {return strides_;}
+    int stride(int i) const { return strides_[i]; }
+    const std::vector<int> &strides() const { return strides_; }
 
     // size() is the number of elements stored in the array.  It is
     // the product of dims_;
@@ -92,8 +93,8 @@ namespace BOOM{
     static std::vector<int> index3(int x1, int x2, int x3);
     static std::vector<int> index4(int x1, int x2, int x3, int x4);
     static std::vector<int> index5(int x1, int x2, int x3, int x4, int x5);
-    static std::vector<int> index6(
-        int x1, int x2, int x3, int x4, int x5, int x6);
+    static std::vector<int> index6(int x1, int x2, int x3, int x4, int x5,
+                                   int x6);
 
     // If the number of dimensions is 2 or 1 then write the elements
     // to a matrix with the appropriate number of rows and columns.
@@ -104,6 +105,7 @@ namespace BOOM{
    private:
     std::vector<int> dims_;
     std::vector<int> strides_;
+
    protected:
     void reset_dims(const std::vector<int> &dims);
     void reset_strides(const std::vector<int> &strides);
@@ -121,34 +123,38 @@ namespace BOOM{
     ArrayBase(const std::vector<int> &dims);
     ArrayBase(const std::vector<int> &dims, const std::vector<int> &strides);
 
-    ArrayBase & operator=(const ArrayBase &rhs) = default;
-    ArrayBase & operator=(ArrayBase &&rhs) = default;
+    ArrayBase &operator=(const ArrayBase &rhs) = default;
+    ArrayBase &operator=(ArrayBase &&rhs) = default;
 
     using ConstArrayBase::data;
-    virtual double *data()=0;
+    virtual double *data() = 0;
 
     using ConstArrayBase::operator[];
-    double & operator[](const std::vector<int> &index);
+    double &operator[](const std::vector<int> &index);
 
     using ConstArrayBase::operator();
-    double & operator()(int x1);
-    double & operator()(int x1, int x2);
-    double & operator()(int x1, int x2, int x3);
-    double & operator()(int x1, int x2, int x3, int x4);
-    double & operator()(int x1, int x2, int x3, int x4, int x5);
-    double & operator()(int x1, int x2, int x3, int x4, int x5, int x6);
-
+    double &operator()(int x1);
+    double &operator()(int x1, int x2);
+    double &operator()(int x1, int x2, int x3);
+    double &operator()(int x1, int x2, int x3, int x4);
+    double &operator()(int x1, int x2, int x3, int x4, int x5);
+    double &operator()(int x1, int x2, int x3, int x4, int x5, int x6);
   };
 
   //======================================================================
   inline bool operator==(const Vector &lhs, const ConstArrayBase &rhs) {
-    return rhs==lhs;}
+    return rhs == lhs;
+  }
   inline bool operator==(const VectorView &lhs, const ConstArrayBase &rhs) {
-    return rhs==lhs;}
-  inline bool operator==(const ConstVectorView &lhs, const ConstArrayBase &rhs) {
-    return rhs==lhs;}
+    return rhs == lhs;
+  }
+  inline bool operator==(const ConstVectorView &lhs,
+                         const ConstArrayBase &rhs) {
+    return rhs == lhs;
+  }
   inline bool operator==(const Matrix &lhs, const ConstArrayBase &rhs) {
-    return rhs==lhs;}
+    return rhs == lhs;
+  }
   //======================================================================
   class Array;
   class ConstArrayView : public ConstArrayBase {
@@ -158,17 +164,14 @@ namespace BOOM{
 
     ConstArrayView(const Array &);
     ConstArrayView(const double *data, const std::vector<int> &dims);
-    ConstArrayView(const double *data,
-                   const std::vector<int> &dims,
+    ConstArrayView(const double *data, const std::vector<int> &dims,
                    const std::vector<int> &strides);
     ConstArrayView(const ConstArrayBase &rhs);
 
-    const double *data() const override{return data_;}
+    const double *data() const override { return data_; }
 
-    void reset(const double *data,
-               const std::vector<int> &dims);
-    void reset(const double *data,
-               const std::vector<int> &dims,
+    void reset(const double *data, const std::vector<int> &dims);
+    void reset(const double *data, const std::vector<int> &dims,
                const std::vector<int> &strides);
 
     // 'slice' returns a lower dimensional view into an array.  If you
@@ -195,11 +198,12 @@ namespace BOOM{
     ConstVectorView vector_slice(int x1, int x2, int x3) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5) const;
-    ConstVectorView vector_slice(
-        int x1, int x2, int x3, int x4, int x5, int x6) const;
+    ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5,
+                                 int x6) const;
 
     ConstArrayIterator begin() const;
     ConstArrayIterator end() const;
+
    private:
     const double *data_;
   };
@@ -211,25 +215,23 @@ namespace BOOM{
 
     ArrayView(Array &);
     ArrayView(double *data, const std::vector<int> &dims);
-    ArrayView(double *data,
-              const std::vector<int> &dims,
+    ArrayView(double *data, const std::vector<int> &dims,
               const std::vector<int> &strides);
 
-          double *data() override{return data_;}
-    const double *data() const override{return data_;}
+    double *data() override { return data_; }
+    const double *data() const override { return data_; }
 
     void reset(double *data, const std::vector<int> &dims);
-    void reset(double *data,
-               const std::vector<int> &dims,
+    void reset(double *data, const std::vector<int> &dims,
                const std::vector<int> &strides);
 
-    ArrayView & operator=(const Array &a);
-    ArrayView & operator=(const ArrayView &a);
-    ArrayView & operator=(const ConstArrayView &a);
-    ArrayView & operator=(const Matrix &a);
-    ArrayView & operator=(const Vector &a);
-    ArrayView & operator=(const VectorView &a);
-    ArrayView & operator=(const ConstVectorView &a);
+    ArrayView &operator=(const Array &a);
+    ArrayView &operator=(const ArrayView &a);
+    ArrayView &operator=(const ConstArrayView &a);
+    ArrayView &operator=(const Matrix &a);
+    ArrayView &operator=(const Vector &a);
+    ArrayView &operator=(const VectorView &a);
+    ArrayView &operator=(const ConstVectorView &a);
 
     // 'slice' returns a lower dimensional view into an array.  If you
     // have a 3-way array indexed by (i, j, k), and you want to get
@@ -263,8 +265,7 @@ namespace BOOM{
     VectorView vector_slice(int x1, int x2, int x3);
     VectorView vector_slice(int x1, int x2, int x3, int x4);
     VectorView vector_slice(int x1, int x2, int x3, int x4, int x5);
-    VectorView vector_slice(
-        int x1, int x2, int x3, int x4, int x5, int x6);
+    VectorView vector_slice(int x1, int x2, int x3, int x4, int x5, int x6);
 
     ConstVectorView vector_slice(const std::vector<int> &index) const;
     ConstVectorView vector_slice(int x1) const;
@@ -272,19 +273,20 @@ namespace BOOM{
     ConstVectorView vector_slice(int x1, int x2, int x3) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5) const;
-    ConstVectorView vector_slice(
-        int x1, int x2, int x3, int x4, int x5, int x6) const;
+    ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5,
+                                 int x6) const;
 
     ConstArrayIterator begin() const;
     ConstArrayIterator end() const;
     ArrayIterator begin();
     ArrayIterator end();
+
    private:
     double *data_;
   };
 
   //======================================================================
-  class Array : public ArrayBase{
+  class Array : public ArrayBase {
    public:
     typedef std::vector<double>::iterator iterator;
     typedef std::vector<double>::const_iterator const_iterator;
@@ -297,20 +299,20 @@ namespace BOOM{
 
     Array(const Array &rhs) = default;
     Array(Array &&rhs) = default;
-    Array & operator=(const Array &rhs) = default;
-    Array & operator=(Array &&rhs) = default;
+    Array &operator=(const Array &rhs) = default;
+    Array &operator=(Array &&rhs) = default;
 
     template <class FwdIt>
-    Array & assign(FwdIt begin, FwdIt end) {
+    Array &assign(FwdIt begin, FwdIt end) {
       data_.assign(begin, end);
-      if(data_.size() != this->size()) {
+      if (data_.size() != this->size()) {
         report_error("Wrong sized data passed to Array::assign");
       }
       return *this;
     }
 
-    double * data() override{return data_.data();}
-    const double * data() const override{return data_.data();}
+    double *data() override { return data_.data(); }
+    const double *data() const override { return data_.data(); }
 
     using ConstArrayBase::operator==;
     bool operator==(const Array &rhs) const;
@@ -350,8 +352,8 @@ namespace BOOM{
     ConstVectorView vector_slice(int x1, int x2, int x3) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4) const;
     ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5) const;
-    ConstVectorView vector_slice(
-        int x1, int x2, int x3, int x4, int x5, int x6) const;
+    ConstVectorView vector_slice(int x1, int x2, int x3, int x4, int x5,
+                                 int x6) const;
 
     VectorView vector_slice(const std::vector<int> &index);
     VectorView vector_slice(int x1);
@@ -361,12 +363,13 @@ namespace BOOM{
     VectorView vector_slice(int x1, int x2, int x3, int x4, int x5);
     VectorView vector_slice(int x1, int x2, int x3, int x4, int x5, int x6);
 
-    iterator begin() {return data_.begin();}
-    iterator end() {return data_.end();}
-    const_iterator begin() const {return data_.begin();}
-    const_iterator end() const {return data_.end();}
+    iterator begin() { return data_.begin(); }
+    iterator end() { return data_.end(); }
+    const_iterator begin() const { return data_.begin(); }
+    const_iterator end() const { return data_.end(); }
+
    private:
     std::vector<double> data_;
   };
-}
-#endif// BOOM_ARRAY_HPP
+}  // namespace BOOM
+#endif  // BOOM_ARRAY_HPP
