@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -17,14 +18,14 @@
 */
 #ifndef BOOM_NEWLA_DIAGONAL_MATRIX_HPP
 #define BOOM_NEWLA_DIAGONAL_MATRIX_HPP
-#include <vector>
 #include <boost/shared_ptr.hpp>
 #include <iosfwd>
-#include <LinAlg/Matrix.hpp>
+#include <vector>
+#include "LinAlg/Matrix.hpp"
 
-namespace BOOM{
-  using std::ostream;
+namespace BOOM {
   using std::istream;
+  using std::ostream;
 
   class Vector;
   class VectorView;
@@ -43,9 +44,9 @@ namespace BOOM{
     explicit DiagonalMatrix(const ConstVectorView &diagonal_elements);
     explicit DiagonalMatrix(const std::vector<double> &diagonal_elements);
 
-    DiagonalMatrix & operator=(const double value);
+    DiagonalMatrix &operator=(const double value);
 
-    bool operator==(const DiagonalMatrix &)const;
+    bool operator==(const DiagonalMatrix &) const;
 
     void swap(DiagonalMatrix &rhs);
 
@@ -53,41 +54,39 @@ namespace BOOM{
     void randomize();
 
     // size queries
-    uint nrow() const {return diagonal_elements_.size();}
-    uint ncol() const {return diagonal_elements_.size();}
+    uint nrow() const { return diagonal_elements_.size(); }
+    uint ncol() const { return diagonal_elements_.size(); }
 
     //---- change size and shape  -----
-    DiagonalMatrix & resize(uint n);
+    DiagonalMatrix &resize(uint n);
 
     // Diagonal elements.  Returns a VectorView instead of a Vector &
     // to prevent resizing.
     VectorView diag();
-    const Vector & diag() const;
+    const Vector &diag() const;
 
     //====== Linear algebra.  Lots of special cases here. ==================
 
     //------- Matrix
     // Fill 'ans' with scalar * this * B.
     // Return ans.
-    Matrix & mult(const Matrix &B, Matrix &ans, double scalar = 1.0) const;
+    Matrix &mult(const Matrix &B, Matrix &ans, double scalar = 1.0) const;
 
     // Fill 'ans' with scalar * this^T * B.
     // Return ans.
-    Matrix & Tmult(const Matrix &B, Matrix &ans, double scalar = 1.0)const;
+    Matrix &Tmult(const Matrix &B, Matrix &ans, double scalar = 1.0) const;
 
     // Fill 'ans' with scalar * this * B^T
     // Return ans.
-    Matrix & multT(const Matrix &B, Matrix &ans, double scalar = 1.0)const;
+    Matrix &multT(const Matrix &B, Matrix &ans, double scalar = 1.0) const;
 
     //------- SpdMatrix
 
-    Matrix & mult(const SpdMatrix &S, Matrix & ans, double scalar = 1.0)const;
+    Matrix &mult(const SpdMatrix &S, Matrix &ans, double scalar = 1.0) const;
 
-    Matrix & Tmult(const SpdMatrix &S, Matrix & ans,
-                   double scalar = 1.0)const;
+    Matrix &Tmult(const SpdMatrix &S, Matrix &ans, double scalar = 1.0) const;
 
-    Matrix & multT(const SpdMatrix &S, Matrix & ans,
-                   double scalar = 1.0)const;
+    Matrix &multT(const SpdMatrix &S, Matrix &ans, double scalar = 1.0) const;
 
     // this * m * this
     SpdMatrix sandwich(const SpdMatrix &m) const;
@@ -98,56 +97,53 @@ namespace BOOM{
     //     double scalar = 1.0)const;
 
     //------- DiagonalMatrix
-    DiagonalMatrix & mult(const DiagonalMatrix &B,
-                          DiagonalMatrix &ans,
-                          double scalar = 1.0)const;
-    DiagonalMatrix & Tmult(const DiagonalMatrix &B,
-                           DiagonalMatrix &ans,
-                           double scalar = 1.0)const;
-    DiagonalMatrix & multT(const DiagonalMatrix &B,
-                           DiagonalMatrix &ans,
-                           double scalar = 1.0)const;
+    DiagonalMatrix &mult(const DiagonalMatrix &B, DiagonalMatrix &ans,
+                         double scalar = 1.0) const;
+    DiagonalMatrix &Tmult(const DiagonalMatrix &B, DiagonalMatrix &ans,
+                          double scalar = 1.0) const;
+    DiagonalMatrix &multT(const DiagonalMatrix &B, DiagonalMatrix &ans,
+                          double scalar = 1.0) const;
 
     //------- Vector
-    Vector & mult(const Vector &v, Vector &ans, double scalar = 1.0) const;
-    Vector & Tmult(const Vector &v, Vector &ans, double scalar = 1.0)const;
+    Vector &mult(const Vector &v, Vector &ans, double scalar = 1.0) const;
+    Vector &Tmult(const Vector &v, Vector &ans, double scalar = 1.0) const;
 
     DiagonalMatrix t() const;
     DiagonalMatrix inv() const;
-    DiagonalMatrix inner() const;   // returns X^tX
+    DiagonalMatrix inner() const;  // returns X^tX
 
     Matrix solve(const Matrix &mat) const;
     Vector solve(const Vector &v) const;
     double det() const;
-    Vector singular_values()const; // sorted largest to smallest
-    uint rank(double prop=1e-12) const;
+    Vector singular_values() const;  // sorted largest to smallest
+    uint rank(double prop = 1e-12) const;
     // 'rank' is the number of singular values at least 'prop' times
     // the largest
-    Vector real_evals()const;
+    Vector real_evals() const;
 
     //--------  Math -------------
-    DiagonalMatrix & operator+=(double x);
-    DiagonalMatrix & operator+=(const DiagonalMatrix &m);
+    DiagonalMatrix &operator+=(double x);
+    DiagonalMatrix &operator+=(const DiagonalMatrix &m);
 
-    DiagonalMatrix & operator-=(double x);
-    DiagonalMatrix & operator-=(const DiagonalMatrix &m);
+    DiagonalMatrix &operator-=(double x);
+    DiagonalMatrix &operator-=(const DiagonalMatrix &m);
 
-    DiagonalMatrix & operator*=(double x);
-    DiagonalMatrix & operator*=(const DiagonalMatrix &m);
+    DiagonalMatrix &operator*=(double x);
+    DiagonalMatrix &operator*=(const DiagonalMatrix &m);
 
-    DiagonalMatrix & operator/=(double x);
-    DiagonalMatrix & operator/=(const DiagonalMatrix &m);
+    DiagonalMatrix &operator/=(double x);
+    DiagonalMatrix &operator/=(const DiagonalMatrix &m);
 
-    double sum()const;
-    double prod()const;
+    double sum() const;
+    double prod() const;
 
-    ostream & print(ostream &out) const;
+    ostream &print(ostream &out) const;
 
    private:
     BOOM::Vector diagonal_elements_;
   };
 
-  inline ostream & operator<<(ostream &out, const DiagonalMatrix &m) {
+  inline ostream &operator<<(ostream &out, const DiagonalMatrix &m) {
     return m.print(out);
   }
 
@@ -180,4 +176,4 @@ namespace BOOM{
 
 }  // namespace BOOM
 
-#endif // BOOM_NEWLA_MATRIX_HPP
+#endif  // BOOM_NEWLA_MATRIX_HPP
