@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -18,25 +19,24 @@
 #ifndef BOOM_GAUSSIAN_MODEL_GIVEN_SIGMA_HPP
 #define BOOM_GAUSSIAN_MODEL_GIVEN_SIGMA_HPP
 
-#include <Models/ModelTypes.hpp>
-#include <Models/ParamTypes.hpp>
-#include <Models/Sufstat.hpp>
-#include <Models/Policies/SufstatDataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/Policies/ParamPolicy_2.hpp>
+#include "Models/ModelTypes.hpp"
+#include "Models/ParamTypes.hpp"
+#include "Models/Policies/ParamPolicy_2.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/Policies/SufstatDataPolicy.hpp"
+#include "Models/Sufstat.hpp"
 
-#include <Models/GaussianModelBase.hpp>
+#include "Models/GaussianModelBase.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   // A Gaussian model parameterized as N(mu0, sigma^2/kappa), where sigma^2 is
   // owned by another model.  This model is the conjugate prior for the mean of
   // a normal distribution, conditional on its variance (sigma^2).
-  class GaussianModelGivenSigma
-    : public GaussianModelBase,
-      public ParamPolicy_2<UnivParams, UnivParams>,
-      public PriorPolicy {
-  public:
+  class GaussianModelGivenSigma : public GaussianModelBase,
+                                  public ParamPolicy_2<UnivParams, UnivParams>,
+                                  public PriorPolicy {
+   public:
     // Args:
     //   scaling_variance: The 'sigma^2' parameter that scales the variance of
     //     this distribution.  If left as nullptr then 'set_scaling_variance'
@@ -45,14 +45,14 @@ namespace BOOM{
     //     comment.
     //   sample_size: The denominator of the variance of this distribution.
     //     This is 'kappa' in the class comment.
-    GaussianModelGivenSigma(const Ptr<UnivParams> &scaling_variance = nullptr,
-                            double mean = 0,
-                            double sample_size = 1);
-    GaussianModelGivenSigma * clone()const override;
+    explicit GaussianModelGivenSigma(
+        const Ptr<UnivParams> &scaling_variance = nullptr, double mean = 0,
+        double sample_size = 1);
+    GaussianModelGivenSigma *clone() const override;
 
     // Sets the parameter in the numerator of the variance of the normal
     // distribution.
-    void set_scaling_variance(const Ptr<UnivParams> &sigsq);
+    void set_scaling_variance(const Ptr<UnivParams> &scaling_variance);
 
     void set_params(double mu0, double kappa);
     void set_mu(double mu0);
@@ -71,15 +71,19 @@ namespace BOOM{
 
     Ptr<UnivParams> Mu_prm();
     Ptr<UnivParams> Kappa_prm();
-    const Ptr<UnivParams> Mu_prm()const;
-    const Ptr<UnivParams> Kappa_prm()const;
+    const Ptr<UnivParams> Mu_prm() const;
+    const Ptr<UnivParams> Kappa_prm() const;
 
     void mle() override;
     double Loglike(const Vector &mu_kappa, Vector &g, Matrix &h,
                    uint nderiv) const override;
-  private:
+    double log_likelihood() const override {
+      return LoglikeModel::log_likelihood();
+    }
+
+   private:
     Ptr<UnivParams> scaling_variance_;
   };
 
-}
-#endif// BOOM_GAUSSIAN_MODEL_GIVEN_SIGMA_HPP
+}  // namespace BOOM
+#endif  // BOOM_GAUSSIAN_MODEL_GIVEN_SIGMA_HPP
