@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2016 Steven L. Scott
 
@@ -19,42 +20,40 @@
 #ifndef BOOM_BINOMIAL_PROBIT_MODEL_HPP_
 #define BOOM_BINOMIAL_PROBIT_MODEL_HPP_
 
-#include <Models/Glm/BinomialRegressionData.hpp>
-#include <BOOM.hpp>
-#include <TargetFun/TargetFun.hpp>
-#include <numopt.hpp>
-#include <Models/Glm/Glm.hpp>
-#include <Models/Policies/IID_DataPolicy.hpp>
-#include <Models/Policies/ParamPolicy_1.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/EmMixtureComponent.hpp>
+#include "BOOM.hpp"
+#include "Models/EmMixtureComponent.hpp"
+#include "Models/Glm/BinomialRegressionData.hpp"
+#include "Models/Glm/Glm.hpp"
+#include "Models/Policies/IID_DataPolicy.hpp"
+#include "Models/Policies/ParamPolicy_1.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "TargetFun/TargetFun.hpp"
+#include "numopt.hpp"
 
 namespace BOOM {
 
-  class BinomialProbitModel
-      : public GlmModel,
-        public NumOptModel,
-        public ParamPolicy_1<GlmCoefs>,
-        public IID_DataPolicy<BinomialRegressionData>,
-        public PriorPolicy,
-        virtual public MixtureComponent
-  {
+  class BinomialProbitModel : public GlmModel,
+                              public NumOptModel,
+                              public ParamPolicy_1<GlmCoefs>,
+                              public IID_DataPolicy<BinomialRegressionData>,
+                              public PriorPolicy,
+                              virtual public MixtureComponent {
    public:
-    BinomialProbitModel(uint beta_dim, bool include_all=true);
-    BinomialProbitModel(const Vector &beta);
+    explicit BinomialProbitModel(uint beta_dim, bool include_all = true);
+    explicit BinomialProbitModel(const Vector &beta);
 
     // Use this constructor if the model needs to share its
     // coefficient vector with another model.
-    BinomialProbitModel(Ptr<GlmCoefs> beta);
+    explicit BinomialProbitModel(const Ptr<GlmCoefs> &beta);
 
     BinomialProbitModel(const Matrix &X, const Vector &y, const Vector &n);
     BinomialProbitModel(const BinomialProbitModel &);
     BinomialProbitModel *clone() const override;
 
-    GlmCoefs & coef() override {return ParamPolicy::prm_ref();}
-    const GlmCoefs & coef() const override {return ParamPolicy::prm_ref();}
-    Ptr<GlmCoefs> coef_prm() override {return ParamPolicy::prm();}
-    const Ptr<GlmCoefs> coef_prm() const override {return ParamPolicy::prm();}
+    GlmCoefs &coef() override { return ParamPolicy::prm_ref(); }
+    const GlmCoefs &coef() const override { return ParamPolicy::prm_ref(); }
+    Ptr<GlmCoefs> coef_prm() override { return ParamPolicy::prm(); }
+    const Ptr<GlmCoefs> coef_prm() const override { return ParamPolicy::prm(); }
 
     double success_probability(const Vector &x) const;
     double success_probability(const VectorView &x) const;
@@ -63,9 +62,10 @@ namespace BOOM {
     double failure_probability(const VectorView &x) const;
     double failure_probability(const ConstVectorView &x) const;
 
-    double pdf(const Data * dp, bool logscale) const override;
-    double pdf(dPtr dp, bool logscale) const;
-    double pdf(Ptr<BinomialRegressionData>, bool) const;
+    double pdf(const Data *dp, bool logscale) const override;
+    double pdf(const Ptr<Data> &dp, bool logscale) const;
+    double pdf(const Ptr<BinomialRegressionData> &, bool) const;
+    int number_of_observations() const override { return dat().size(); }
 
     // Returns the log of the binomial probability of y successes in n
     // trials.
@@ -78,8 +78,8 @@ namespace BOOM {
 
     // In the following, beta refers to the set of nonzero "included"
     // coefficients.
-    double Loglike(const Vector &beta,
-                   Vector &g, Matrix &h, uint nd) const override;
+    double Loglike(const Vector &beta, Vector &g, Matrix &h,
+                   uint nd) const override;
     virtual double log_likelihood(const Vector &beta, Vector *g, Matrix *h,
                                   bool initialize_derivs = true) const;
     using LoglikeModel::log_likelihood;
@@ -90,4 +90,4 @@ namespace BOOM {
 
 }  // namespace BOOM
 
-#endif //  BOOM_BINOMIAL_PROBIT_MODEL_HPP_
+#endif  //  BOOM_BINOMIAL_PROBIT_MODEL_HPP_
