@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -19,25 +20,24 @@
 #ifndef CUMULATIVE_LOGIT_MODEL_HPP
 #define CUMULATIVE_LOGIT_MODEL_HPP
 
-#include <Models/Glm/Glm.hpp>
-#include <Models/Glm/OrdinalCutpointModel.hpp>
+#include "Models/Glm/Glm.hpp"
+#include "Models/Glm/OrdinalCutpointModel.hpp"
 
-namespace BOOM{
-  class CumulativeLogitModel
-      : public OrdinalCutpointModel
-  {
+namespace BOOM {
+  class CumulativeLogitModel : public OrdinalCutpointModel {
    public:
-    CumulativeLogitModel(const Vector &beta, const Vector & delta);
+    CumulativeLogitModel(const Vector &beta, const Vector &delta);
     CumulativeLogitModel(const Matrix &X, const Vector &y);
     CumulativeLogitModel(const CumulativeLogitModel &rhs);
-    CumulativeLogitModel * clone() const override;
+    CumulativeLogitModel *clone() const override;
+
+    double link_inv(double) const override;
+    double dlink_inv(double) const override;
 
-    double link_inv(double)const override;
-    double dlink_inv(double)const override;
    private:
-    double simulate_latent_variable(RNG &rng)const override;
+    double simulate_latent_variable(RNG &rng) const override;
   };
 
-} // ends namespace BOOM
+}  // namespace BOOM
 
-#endif // CUMULATIVE_LOGIT_MODEL_HPP
+#endif  // CUMULATIVE_LOGIT_MODEL_HPP
