@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2009 Steven L. Scott
 
@@ -19,19 +20,17 @@
 #ifndef BOOM_CUMULATIVE_PROBIT_SAMPLER_HPP_
 #define BOOM_CUMULATIVE_PROBIT_SAMPLER_HPP_
 
-#include <Models/Glm/CumulativeProbitModel.hpp>
-#include <Models/Glm/RegressionModel.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/MvnBase.hpp>
+#include "Models/Glm/CumulativeProbitModel.hpp"
+#include "Models/Glm/RegressionModel.hpp"
+#include "Models/MvnBase.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class CumulativeProbitSampler
-      : public PosteriorSampler
-  {
+  class CumulativeProbitSampler : public PosteriorSampler {
    public:
     CumulativeProbitSampler(CumulativeProbitModel *m,
-                            Ptr<MvnBase> beta_prior,
+                            const Ptr<MvnBase> &beta_prior,
                             RNG &seeding_rng = GlobalRng::rng);
 
     void impute_latent_data();
@@ -39,6 +38,7 @@ namespace BOOM{
     void draw_delta();
     void draw() override;
     double logpri() const override;
+
    private:
     CumulativeProbitModel *m_;
     Ptr<MvnBase> beta_prior_;
@@ -49,5 +49,5 @@ namespace BOOM{
     Vector delta_;
     // assume a flat prior on delta
   };
-}
-#endif// BOOM_CUMULATIVE_PROBIT_SAMPLER_HPP_
+}  // namespace BOOM
+#endif  // BOOM_CUMULATIVE_PROBIT_SAMPLER_HPP_
