@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -18,32 +19,31 @@
 #ifndef BOOM_MVT_REG_SAMPLER_HPP
 #define BOOM_MVT_REG_SAMPLER_HPP
 
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/Glm/MvtRegModel.hpp>
-#include <Models/Glm/MvReg2.hpp>
-#include <Models/Glm/PosteriorSamplers/MvRegSampler.hpp>
-#include <Models/ScaledChisqModel.hpp>
-#include <Models/ScaledChisqModel.hpp>
-#include <Samplers/SliceSampler.hpp>
+#include "Models/Glm/MvReg2.hpp"
+#include "Models/Glm/MvtRegModel.hpp"
+#include "Models/Glm/PosteriorSamplers/MvRegSampler.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
+#include "Models/ScaledChisqModel.hpp"
+#include "Samplers/SliceSampler.hpp"
 
-namespace BOOM{
+namespace BOOM {
   class GammaModel;
   class ScalarLogpostTF;
   class SliceSampler;
 
-  class MvtRegSampler
-    : public PosteriorSampler
-  {
-  public:
+  class MvtRegSampler : public PosteriorSampler {
+   public:
     // assumes vec(B)|Sigma ~ N( b, kappa * Sigma^{-1} \otimes I_p )
 
     MvtRegSampler(MvtRegModel *m, const Matrix &B, double kappa,
-          double prior_df, const SpdMatrix & Sigma_guess,
-          Ptr<DoubleModel> nu_prior, RNG &seeding_rng = GlobalRng::rng);
+                  double prior_df, const SpdMatrix &Sigma_guess,
+                  const Ptr<DoubleModel> &nu_prior,
+                  RNG &seeding_rng = GlobalRng::rng);
 
     void draw() override;
-    double logpri()const override;
-  private:
+    double logpri() const override;
+
+   private:
     MvtRegModel *mod;
 
     Ptr<MvReg> reg_model;  // update sufficient statistics but not data
@@ -55,12 +55,12 @@ namespace BOOM{
 
     Vector yhat;
     void impute_w();
-    double impute_w(Ptr<MvRegData> dp);
+    double impute_w(const Ptr<MvRegData> &dp);
     void draw_Sigma();
     void draw_Beta();
     void draw_nu();
     void clear_suf();
   };
 
-}
-#endif// BOOM_MVT_REG_SAMPLER_HPP
+}  // namespace BOOM
+#endif  // BOOM_MVT_REG_SAMPLER_HPP
