@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2012 Steven L. Scott
 
@@ -19,10 +20,10 @@
 #ifndef BOOM_NORMAL_MIXTURE_APPROXIMATION_HPP_
 #define BOOM_NORMAL_MIXTURE_APPROXIMATION_HPP_
 
-#include <numopt.hpp>
-#include <LinAlg/Vector.hpp>
-#include <distributions/rng.hpp>
-#include <distributions/Rmath_dist.hpp>
+#include "LinAlg/Vector.hpp"
+#include "distributions/Rmath_dist.hpp"
+#include "distributions/rng.hpp"
+#include "numopt.hpp"
 
 namespace BOOM {
 
@@ -37,12 +38,11 @@ namespace BOOM {
    public:
     // Use this constructor for an empty NormalMixtureApproximation
     // with n mixture components.
-    NormalMixtureApproximation(int n);
+    explicit NormalMixtureApproximation(int n);
 
     // Use this constructor for a NormalMixtureApproximation with a
     // specified set of mixture components and mixing weights.
-    NormalMixtureApproximation(const Vector &mu,
-                               const Vector &sigma,
+    NormalMixtureApproximation(const Vector &mu, const Vector &sigma,
                                const Vector &weights);
 
     // Use this constructor to find the approximation that best fits a
@@ -66,14 +66,11 @@ namespace BOOM {
     //   force_zero_mu: If true then then all mixture components will
     //     be forced to have zero mean.
     NormalMixtureApproximation(
-        ScalarTarget log_target_density,
-        const Vector &initial_mu,
-        const Vector &initial_sigma,
-        const Vector &initial_weights,
-        double precision = 1e-6,   // the precision of the final KL divergence
-        int max_evals = 20000,     // max number of times to evaluate logf
-        double initial_stepsize = 10.0,
-        bool force_zero_mu = false);
+        const ScalarTarget &log_target_density, const Vector &initial_mu,
+        const Vector &initial_sigma, const Vector &initial_weights,
+        double precision = 1e-6,  // the precision of the final KL divergence
+        int max_evals = 20000,    // max number of times to evaluate logf
+        double initial_stepsize = 10.0, bool force_zero_mu = false);
 
     // Set the mixing weights, means, and standard deviations to the
     // specified values.
@@ -85,29 +82,29 @@ namespace BOOM {
     void set(const Vector &theta);
 
     // The number of mixture components used in the approximation.
-    int dim()const{return mu_.size();}
+    int dim() const { return mu_.size(); }
 
-    const Vector &mu()const{return mu_;}
-    const Vector &sigma()const{return sigma_;}
-    const Vector &weights()const{return weights_;}
-    const Vector &log_weights()const{return log_weights_;}
+    const Vector &mu() const { return mu_; }
+    const Vector &sigma() const { return sigma_; }
+    const Vector &weights() const { return weights_; }
+    const Vector &log_weights() const { return log_weights_; }
 
     // Return the log of the approximating normal mixture density at
     // x.
-    double logp(double x)const;
+    double logp(double x) const;
 
     // For a particular observation u drawn from the distribution
     // being approximated, take a random draw of the mixture component
     // that generated it.
-    void unmix(RNG &rng, double u, double *mu, double *sigsq)const;
+    void unmix(RNG &rng, double u, double *mu, double *sigsq) const;
 
-    double kullback_leibler()const;
+    double kullback_leibler() const;
     // Records the answer in state.
-    double kullback_leibler(ScalarTarget target);
+    double kullback_leibler(const ScalarTarget &target);
 
-    int number_of_function_evaluations()const;
+    int number_of_function_evaluations() const;
 
-    ostream & print(ostream &out)const;
+    ostream &print(ostream &out) const;
 
     Vector serialize() const;
     Vector::const_iterator deserialize(Vector::const_iterator begin);
@@ -148,9 +145,10 @@ namespace BOOM {
     int number_of_function_evaluations_;
   };
 
-  inline ostream & operator<<(ostream &out,
-                              const NormalMixtureApproximation &approximation){
-    return approximation.print(out);}
+  inline ostream &operator<<(ostream &out,
+                             const NormalMixtureApproximation &approximation) {
+    return approximation.print(out);
+  }
 
   //======================================================================
 
@@ -158,22 +156,22 @@ namespace BOOM {
   class NormalMixtureApproximationTable {
    public:
     NormalMixtureApproximationTable();
-    ~NormalMixtureApproximationTable(){}
+    ~NormalMixtureApproximationTable() {}
     NormalMixtureApproximationTable(const NormalMixtureApproximationTable &rhs);
-    NormalMixtureApproximationTable & operator=(
+    NormalMixtureApproximationTable &operator=(
         const NormalMixtureApproximationTable &rhs);
 
     // Add an entry into the table.
     void add(int index, const NormalMixtureApproximation &spec);
 
     // Return the smallest and lagest indices contained in the table.
-    int smallest_index()const;
-    int largest_index()const;
+    int smallest_index() const;
+    int largest_index() const;
 
     // If a numerical approximation exists at index_value, then return
     // it.  Otherwise return an interpolation between the two nearest
     // indices.
-    NormalMixtureApproximation & approximate(int index_value);
+    NormalMixtureApproximation &approximate(int index_value);
 
     // Save the current state of the table to a numeric vector that
     // can be stored somewhere.
@@ -194,9 +192,11 @@ namespace BOOM {
   // variable.
   class NegLogGamma {
    public:
-    NegLogGamma(double nu) : nu_(nu) {}
-    double operator()(double y)const {
-      return -nu_*y - exp(-y) - lgamma(nu_); }
+    explicit NegLogGamma(double nu) : nu_(nu) {}
+    double operator()(double y) const {
+      return -nu_ * y - exp(-y) - lgamma(nu_);
+    }
+
    private:
     double nu_;
   };
@@ -206,10 +206,9 @@ namespace BOOM {
   // between the NormalMixtureApproximation and the target function.
   class ApproximationDistance {
    public:
-    ApproximationDistance(ScalarTarget logf,
+    ApproximationDistance(const ScalarTarget &logf,
                           const NormalMixtureApproximation &approximation,
-                          double lower_limit,
-                          double upper_limit,
+                          double lower_limit, double upper_limit,
                           double guess_at_mode);
 
     virtual ~ApproximationDistance() {}
@@ -217,15 +216,15 @@ namespace BOOM {
     // The distance metric is a function of a set of parameters
     // contained in the vector theta.  A default method is provided,
     // but it can be over-ridden.
-    virtual double operator()(const Vector &theta)const;
+    virtual double operator()(const Vector &theta) const;
 
-    double current_distance()const;
+    double current_distance() const;
 
     // The integrand
     virtual double integrand(double x) const = 0;
 
     double logf(double x) const;
-    double approximation(double x)const;
+    double approximation(double x) const;
     double lower_limit() const;
     double upper_limit() const;
 
@@ -239,18 +238,20 @@ namespace BOOM {
 
   class KullbackLeiblerDivergence : public ApproximationDistance {
    public:
-    KullbackLeiblerDivergence(
-        ScalarTarget logf, const NormalMixtureApproximation &approx,
-        double lower_limit, double upper_limit, double guess_at_mode);
-    double integrand(double x)const override;
+    KullbackLeiblerDivergence(const ScalarTarget &logf,
+                              const NormalMixtureApproximation &approx,
+                              double lower_limit, double upper_limit,
+                              double guess_at_mode);
+    double integrand(double x) const override;
   };
 
   class AbsNormDistance : public ApproximationDistance {
    public:
-    AbsNormDistance(
-        ScalarTarget logf, const NormalMixtureApproximation &approx,
-        double lower_limit, double upper_limit, double guess_at_mode);
-    double integrand(double x)const override;
+    AbsNormDistance(const ScalarTarget &logf,
+                    const NormalMixtureApproximation &approx,
+                    double lower_limit, double upper_limit,
+                    double guess_at_mode);
+    double integrand(double x) const override;
   };
 }  // namespace BOOM
-#endif //  BOOM_NORMAL_MIXTURE_APPROXIMATION_HPP_
+#endif  //  BOOM_NORMAL_MIXTURE_APPROXIMATION_HPP_
