@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -19,28 +20,26 @@
 #ifndef BOOM_WEIGHTED_REGRESSION_MODEL_HPP
 #define BOOM_WEIGHTED_REGRESSION_MODEL_HPP
 
-#include <Models/Glm/RegressionModel.hpp>
-#include <Models/Glm/Glm.hpp>
+#include "Models/Glm/Glm.hpp"
+#include "Models/Glm/RegressionModel.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   //------------------------------------------------------------
 
-  class WeightedRegSuf
-    : public SufstatDetails<WeightedRegressionData>
-  {
+  class WeightedRegSuf : public SufstatDetails<WeightedRegressionData> {
    public:
     typedef WeightedRegressionData data_type;
     typedef std::vector<Ptr<WeightedRegressionData> > dataset_type;
     typedef Ptr<dataset_type, false> dsetPtr;
 
-    WeightedRegSuf(int p); // dimension of beta
-    WeightedRegSuf(const Matrix &X, const Vector &y); // w implicitly 1.0
+    explicit WeightedRegSuf(int p);                    // dimension of beta
+    WeightedRegSuf(const Matrix &X, const Vector &y);  // w implicitly 1.0
     WeightedRegSuf(const Matrix &X, const Vector &y, const Vector &w);
-    WeightedRegSuf(const dsetPtr &dat);
+    explicit WeightedRegSuf(const dsetPtr &dat);
     WeightedRegSuf(const WeightedRegSuf &rhs);  // value semantics
 
-    WeightedRegSuf * clone()const override;
+    WeightedRegSuf *clone() const override;
 
     virtual void reweight(const Matrix &X, const Vector &y, const Vector &w);
     virtual void reweight(const dsetPtr &dat);
@@ -53,30 +52,31 @@ namespace BOOM{
     void add_data(const Vector &x, double y, double w);
 
     void clear() override;
-    virtual uint size()const;  // dimension of beta
-    virtual double yty()const;              // Y^t W Y
-    virtual Vector xty()const;                 // X^T W Y
-    virtual SpdMatrix xtx()const;                 // X^T W X
-    virtual Vector xty(const Selector &)const;  // X^T W Y
-    virtual SpdMatrix xtx(const Selector &)const;  // X^T W X
-    virtual Vector beta_hat()const;            // WLS estimate
+    virtual uint size() const;                      // dimension of beta
+    virtual double yty() const;                     // Y^t W Y
+    virtual Vector xty() const;                     // X^T W Y
+    virtual SpdMatrix xtx() const;                  // X^T W X
+    virtual Vector xty(const Selector &) const;     // X^T W Y
+    virtual SpdMatrix xtx(const Selector &) const;  // X^T W X
+    virtual Vector beta_hat() const;                // WLS estimate
     double weighted_sum_of_squared_errors(const Vector &beta) const;
-    virtual double SSE()const;   //
-    virtual double SST()const;   // weighted sum of squares
-    virtual double ybar()const;  // weighted average
-    virtual double n()const;
-    virtual double sumw()const; // sum of weights
-    virtual double sumlogw()const; // sum of weights
-    ostream & print(ostream &out)const override;
-    void combine(Ptr<WeightedRegSuf>);
+    virtual double SSE() const;   //
+    virtual double SST() const;   // weighted sum of squares
+    virtual double ybar() const;  // weighted average
+    virtual double n() const;
+    virtual double sumw() const;     // sum of weights
+    virtual double sumlogw() const;  // sum of weights
+    ostream &print(ostream &out) const override;
+    void combine(const Ptr<WeightedRegSuf> &);
     void combine(const WeightedRegSuf &);
-    WeightedRegSuf * abstract_combine(Sufstat *s) override;
+    WeightedRegSuf *abstract_combine(Sufstat *s) override;
 
-    Vector vectorize(bool minimal=true)const override;
+    Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
-                                       bool minimal=true) override;
+                                       bool minimal = true) override;
     Vector::const_iterator unvectorize(const Vector &v,
                                        bool minimal = true) override;
+
    private:
     mutable SpdMatrix xtwx_;
     Vector xtwy_;
@@ -86,56 +86,56 @@ namespace BOOM{
     mutable bool sym_;
 
     void setup_mat(uint p);
-    void make_symmetric()const;
+    void make_symmetric() const;
   };
 
-  inline ostream & operator<<(ostream & out, const WeightedRegSuf &s){
-    return s.print(out);}
+  inline ostream &operator<<(ostream &out, const WeightedRegSuf &s) {
+    return s.print(out);
+  }
 
   //------------------------------------------------------------
 
   class WeightedRegressionModel
-    : public ParamPolicy_2<GlmCoefs, UnivParams>,
-      public SufstatDataPolicy<WeightedRegressionData, WeightedRegSuf>,
-      public PriorPolicy,
-      public GlmModel,
-      public NumOptModel
-  {
-  public:
+      : public ParamPolicy_2<GlmCoefs, UnivParams>,
+        public SufstatDataPolicy<WeightedRegressionData, WeightedRegSuf>,
+        public PriorPolicy,
+        public GlmModel,
+        public NumOptModel {
+   public:
     typedef WeightedRegressionData data_type;
     typedef WeightedRegSuf suf_type;
 
-    WeightedRegressionModel(uint p);
+    explicit WeightedRegressionModel(uint p);
     WeightedRegressionModel(const Vector &b, double Sigma);
     WeightedRegressionModel(const WeightedRegressionModel &rhs);
     WeightedRegressionModel(const Matrix &X, const Vector &y);
     WeightedRegressionModel(const Matrix &X, const Vector &y, const Vector &w);
-    WeightedRegressionModel(const DatasetType &d, bool all=true);
-    WeightedRegressionModel * clone()const override;
+    explicit WeightedRegressionModel(const DatasetType &d, bool all = true);
+    WeightedRegressionModel *clone() const override;
 
-    GlmCoefs & coef() override;
-    const GlmCoefs & coef()const override;
+    GlmCoefs &coef() override;
+    const GlmCoefs &coef() const override;
     Ptr<GlmCoefs> coef_prm() override;
-    const Ptr<GlmCoefs> coef_prm()const override;
+    const Ptr<GlmCoefs> coef_prm() const override;
     Ptr<UnivParams> Sigsq_prm();
-    const Ptr<UnivParams> Sigsq_prm()const;
+    const Ptr<UnivParams> Sigsq_prm() const;
 
     // beta() and Beta() inherited from GLM;
     //    void set_beta(const Vector &b);
     void set_sigsq(double s2);
 
-    const double & sigsq()const;
-    double sigma()const;
+    const double &sigsq() const;
+    double sigma() const;
 
     void mle() override;
     // The argument is a vector with leading coefficients 'beta' and
     // final element sigsq.
-    double Loglike(const Vector &beta_sigsq,
-                   Vector &g, Matrix &h, uint nd)const override;
-    double pdf(dPtr, bool)const;
-    double pdf(Ptr<data_type>, bool)const;
+    double Loglike(const Vector &beta_sigsq, Vector &g, Matrix &h,
+                   uint nd) const override;
+    double pdf(const Ptr<Data> &, bool) const;
+    double pdf(const Ptr<data_type> &, bool) const;
   };
 
 }  // namespace BOOM
 
-#endif // BOOM_WEIGHTED_REGRESSION_MODEL_HPP
+#endif  // BOOM_WEIGHTED_REGRESSION_MODEL_HPP
