@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2011 Steven L. Scott
 
@@ -19,23 +20,23 @@
 #ifndef BOOM_HEALTH_STATE_MODEL_HPP_
 #define BOOM_HEALTH_STATE_MODEL_HPP_
 
-#include <Models/DataTypes.hpp>
-#include <Models/TimeSeries/TimeSeriesDataPolicy.hpp>
-#include <Models/Policies/CompositeParamPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/ModelTypes.hpp>
-#include <Models/MarkovModel.hpp>
+#include "Models/DataTypes.hpp"
+#include "Models/MarkovModel.hpp"
+#include "Models/ModelTypes.hpp"
+#include "Models/Policies/CompositeParamPolicy.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/TimeSeries/TimeSeriesDataPolicy.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   class HealthStateData : public Data {
    public:
-    HealthStateData(Ptr<Data>, int treatment);
+    HealthStateData(const Ptr<Data> &, int treatment);
     HealthStateData(const HealthStateData &rhs);
 
     // Required virtual functions...
-    HealthStateData * clone() const override;
-    ostream & display(ostream &out)const override;
+    HealthStateData *clone() const override;
+    ostream &display(ostream &out) const override;
 
     // If the subject switched treatment groups during the time period
     // covered by this data point, then split_treatment can be used to
@@ -43,20 +44,22 @@ namespace BOOM{
     // fraction of time spent in the final treatment.  It is assumed
     // that at most one treatment switch is possible, so the fraction
     // of time in initial_treatment is 1-final_treatment_fraction.
-    void split_treatment(int initial_treatment, double final_treatment_fraction);
+    void split_treatment(int initial_treatment,
+                         double final_treatment_fraction);
 
-    // Treatment group to which the subject belonged at the end of the time period.
-    int treatment()const;
+    // Treatment group to which the subject belonged at the end of the time
+    // period.
+    int treatment() const;
     // Fraction of the preceding time period that the subject belonged
     // to the treatment group indicated by treatment().
-    double final_treatment_fraction()const;
+    double final_treatment_fraction() const;
 
     // Treatment group to which the subject belonged at the start of
     // the time period.  This will
-    int initial_treatment()const;
+    int initial_treatment() const;
 
     Ptr<Data> shared_value();
-    const Data * value()const;
+    const Data *value() const;
 
    private:
     Ptr<Data> value_;
@@ -74,22 +77,20 @@ namespace BOOM{
     double final_treatment_fraction_;
   };
   //======================================================================
-  class HealthStateModel :
-      public TimeSeriesDataPolicy<HealthStateData>,
-      public CompositeParamPolicy,
-      public PriorPolicy
-  {
+  class HealthStateModel : public TimeSeriesDataPolicy<HealthStateData>,
+                           public CompositeParamPolicy,
+                           public PriorPolicy {
    public:
     HealthStateModel(const std::vector<Ptr<MixtureComponent> > &mix,
                      const std::vector<Ptr<MarkovModel> > &mark);
 
     HealthStateModel(const HealthStateModel &rhs);
-    HealthStateModel * clone() const override;
+    HealthStateModel *clone() const override;
 
-    double loglike()const;
+    double loglike() const;
 
-    uint state_space_size()const;
-    uint ntreatments()const;
+    uint state_space_size() const;
+    uint ntreatments() const;
     void clear_client_data();
 
     std::vector<Ptr<MixtureComponent> > mixture_components();
@@ -97,29 +98,28 @@ namespace BOOM{
 
     double impute_latent_data(RNG &rng);
     Ptr<MarkovModel> mark(int treatment);
+
    private:
     // Add mix_ and mark_ to the list of models managed by the
     // CompositeParamPolicy.
     void initialize_param_policy();
 
-    double initialize_fwd(Ptr<HealthStateData>)const;
+    double initialize_fwd(const Ptr<HealthStateData> &) const;
     double fwd(const TimeSeries<HealthStateData> &series);
-    double compute_loglike(const TimeSeries<HealthStateData> &series)const;
+    double compute_loglike(const TimeSeries<HealthStateData> &series) const;
     void bkwd(RNG &rng, const TimeSeries<HealthStateData> &series);
 
     // Fill logp_[0..state_space_size()-1] with the conditional
     // probability density of the given data point under each mixture
     // component.
-    void fill_logp(Ptr<HealthStateData>);
-    void fill_logp(Ptr<HealthStateData>, Vector &logp)const;
+    void fill_logp(const Ptr<HealthStateData> &);
+    void fill_logp(const Ptr<HealthStateData> &, Vector &logp) const;
 
-    void fill_logQ(Ptr<HealthStateData>);
-    void fill_logQ(Ptr<HealthStateData>, Matrix &logQ)const;
+    void fill_logQ(const Ptr<HealthStateData> &);
+    void fill_logQ(const Ptr<HealthStateData> &, Matrix &logQ) const;
 
-    int sample_treatment(RNG &rng,
-                         Ptr<HealthStateData>,
-                         uint previous_state,
-                         uint current_state);
+    int sample_treatment(RNG &rng, const Ptr<HealthStateData> &data,
+                         uint previous_state, uint current_state);
 
     std::vector<Ptr<MixtureComponent> > mix_;
     std::vector<Ptr<MarkovModel> > mark_;
@@ -131,10 +131,10 @@ namespace BOOM{
     mutable Matrix logQ_;
 
     std::vector<Mat> P_;  // joint distribution of state in FB
-    mutable Vector pi_;    // marginal distribution of state in FB
-    Vector one_;   // vector of 1's of dimension state_space_size
+    mutable Vector pi_;   // marginal distribution of state in FB
+    Vector one_;          // vector of 1's of dimension state_space_size
   };
 
-}
+}  // namespace BOOM
 
-#endif //  BOOM_HEALTH_STATE_MODEL_HPP_
+#endif  //  BOOM_HEALTH_STATE_MODEL_HPP_
