@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2012 Steven L. Scott
 
@@ -19,24 +20,23 @@
 #ifndef BOOM_INDEPENDENT_MVN_MODEL_HPP
 #define BOOM_INDEPENDENT_MVN_MODEL_HPP
 
-#include <Models/MvnBase.hpp>
-#include <Models/Policies/ParamPolicy_2.hpp>
-#include <Models/Policies/SufstatDataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
+#include "Models/MvnBase.hpp"
+#include "Models/Policies/ParamPolicy_2.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/Policies/SufstatDataPolicy.hpp"
 
-namespace BOOM{
+namespace BOOM {
   class IndependentMvnSuf : public SufstatDetails<VectorData> {
    public:
-    IndependentMvnSuf(int dim);
-    IndependentMvnSuf * clone() const override;
+    explicit IndependentMvnSuf(int dim);
+    IndependentMvnSuf *clone() const override;
 
     void clear() override;
     void resize(int dim);
     void Update(const VectorData &) override;
-    void update_raw(const Vector &x);
-    void add_mixture_data(const Vector &x, double prob);
-    void update_expected_value(double sample_size,
-                               const Vector &expected_sum,
+    void update_raw(const Vector &y);
+    void add_mixture_data(const Vector &v, double prob);
+    void update_expected_value(double sample_size, const Vector &expected_sum,
                                const Vector &expected_sum_of_squares);
 
     double sum(int i) const;
@@ -47,15 +47,16 @@ namespace BOOM{
     double ybar(int i) const;
     double sample_var(int i) const;
 
-    IndependentMvnSuf * abstract_combine(Sufstat *s) override;
-    void combine(Ptr<IndependentMvnSuf>);
+    IndependentMvnSuf *abstract_combine(Sufstat *s) override;
+    void combine(const Ptr<IndependentMvnSuf> &);
     void combine(const IndependentMvnSuf &);
     Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
-                                               bool minimal = true) override;
+                                       bool minimal = true) override;
     Vector::const_iterator unvectorize(const Vector &v,
-                                               bool minimal = true) override;
-    ostream & print(ostream &out) const override;
+                                       bool minimal = true) override;
+    ostream &print(ostream &out) const override;
+
    private:
     Vector sum_;
     Vector sumsq_;
@@ -67,30 +68,29 @@ namespace BOOM{
         public ParamPolicy_2<VectorParams, VectorParams>,
         public SufstatDataPolicy<VectorData, IndependentMvnSuf>,
         public PriorPolicy,
-        virtual public MixtureComponent
-  {
-  public:
-    IndependentMvnModel(int dim);
-    IndependentMvnModel(const Vector &mean,
-                        const Vector &variance);
+        virtual public MixtureComponent {
+   public:
+    explicit IndependentMvnModel(int dim);
+    IndependentMvnModel(const Vector &mean, const Vector &variance);
     IndependentMvnModel(const IndependentMvnModel &rhs);
-    IndependentMvnModel * clone() const override;
+    IndependentMvnModel *clone() const override;
     // Several virtual functions from MvnBase are re-implemented here
     // for efficiency.
-    double Logp(const Vector &x, Vector &g, Matrix &h, uint nderiv) const override;
-    const Vector & mu() const override;
-    const SpdMatrix & Sigma() const override;
-    const SpdMatrix & siginv() const override;
+    double Logp(const Vector &x, Vector &g, Matrix &h,
+                uint nderivs) const override;
+    const Vector &mu() const override;
+    const SpdMatrix &Sigma() const override;
+    const SpdMatrix &siginv() const override;
     double ldsi() const override;
     Vector sim(RNG &rng = GlobalRng::rng) const override;
 
     Ptr<VectorParams> Mu_prm();
     const Ptr<VectorParams> Mu_prm() const;
-    const VectorParams & Mu_ref() const;
+    const VectorParams &Mu_ref() const;
 
     Ptr<VectorParams> Sigsq_prm();
     const Ptr<VectorParams> Sigsq_prm() const;
-    const VectorParams & Sigsq_ref() const;
+    const VectorParams &Sigsq_ref() const;
 
     const Vector &sigsq() const;
     double mu(int i) const;
@@ -98,16 +98,18 @@ namespace BOOM{
     double sigma(int i) const;
 
     void set_mu(const Vector &mu);
-    void set_mu_element(double mu, int position);
+    void set_mu_element(double value, int position);
     void set_sigsq(const Vector &sigsq);
     void set_sigsq_element(double sigsq, int position);
 
-    double pdf(const Data * dp, bool logscale) const override;
+    double pdf(const Data *dp, bool logscale) const override;
+    int number_of_observations() const override { return dat().size(); }
+
    private:
     mutable SpdMatrix sigma_scratch_;
     mutable Vector g_;
     mutable Matrix h_;
   };
 
-}
-#endif //  BOOM_INDEPENDENT_MVN_MODEL_HPP
+}  // namespace BOOM
+#endif  //  BOOM_INDEPENDENT_MVN_MODEL_HPP
