@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2013 Steven L. Scott
 
@@ -19,8 +20,8 @@
 #ifndef BOOM_INDEPENDENT_MVN_MODEL_GIVEN_SCALAR_SIGMA_HPP_
 #define BOOM_INDEPENDENT_MVN_MODEL_GIVEN_SCALAR_SIGMA_HPP_
 
-#include <Models/MvnGivenScalarSigma.hpp>
-#include <Models/IndependentMvnModel.hpp>
+#include "Models/IndependentMvnModel.hpp"
+#include "Models/MvnGivenScalarSigma.hpp"
 
 namespace BOOM {
 
@@ -36,11 +37,10 @@ namespace BOOM {
       : public MvnGivenScalarSigmaBase,
         public ParamPolicy_2<VectorParams, VectorParams>,
         public IID_DataPolicy<VectorData>,
-        public PriorPolicy
-  {
+        public PriorPolicy {
    public:
     // Args:
-    //   mean:  The mean of the distribution.
+    //   prior_mean:  The mean of the distribution.
     //   unscaled_variance_diagonal: A vector positive numbers
     //     representing the diagonal of the unscaled variance matrix.
     //     Multiplying each element by sigsq gives the element-wise
@@ -48,13 +48,12 @@ namespace BOOM {
     //   sigsq: The residual variance parameter.  This is not
     //     considered to be a "parameter" of this model, in the sense
     //     that it is not managed by a ParamPolicy.
-    IndependentMvnModelGivenScalarSigma(
-        const Vector &mean,
-        const Vector &unscaled_variance_diagonal,
-        Ptr<UnivParams> sigsq);
+    IndependentMvnModelGivenScalarSigma(const Vector &prior_mean,
+                                        const Vector &unscaled_variance_diagonal,
+                                        const Ptr<UnivParams> &sigsq);
 
     // Args:
-    //   mean:  The mean of the distribution.
+    //   prior_mean:  The mean of the distribution.
     //   unscaled_variance_diagonal: A vector positive numbers
     //     representing the diagonal of the unscaled variance matrix.
     //     Multiplying each element by sigsq gives the element-wise
@@ -63,31 +62,29 @@ namespace BOOM {
     //     considered to be a "parameter" of this model, in the sense
     //     that it is not managed by a ParamPolicy.
     IndependentMvnModelGivenScalarSigma(
-        Ptr<VectorParams> mean,
-        Ptr<VectorParams> unscaled_variance_diagonal,
-        Ptr<UnivParams> sigsq);
+        const Ptr<VectorParams> &prior_mean,
+        const Ptr<VectorParams> &unscaled_variance_diagonal,
+        const Ptr<UnivParams> &sigsq);
 
-    IndependentMvnModelGivenScalarSigma * clone() const override;
+    IndependentMvnModelGivenScalarSigma *clone() const override;
 
-    double Logp(const Vector &x,
-                        Vector &gradient,
-                        Matrix &hessian,
-                        uint nderiv)const override;
-    const Vector &mu()const override;
-    const SpdMatrix &Sigma()const override;
-    const SpdMatrix &siginv()const override;
-    double ldsi()const override;
-    Vector sim(RNG &rng = GlobalRng::rng)const override;
+    double Logp(const Vector &x, Vector &gradient, Matrix &hessian,
+                uint nderiv) const override;
+    const Vector &mu() const override;
+    const SpdMatrix &Sigma() const override;
+    const SpdMatrix &siginv() const override;
+    double ldsi() const override;
+    Vector sim(RNG &rng = GlobalRng::rng) const override;
 
     // unscaled_variance_diagonal() * sigsq() is the diagonal of
     // Sigma().
-    const Vector & unscaled_variance_diagonal()const;
+    const Vector &unscaled_variance_diagonal() const;
     double sd_for_element(int i) const;
+
    private:
     mutable SpdMatrix sigma_scratch_;
   };
 
 }  // namespace BOOM
 
-
 #endif  //  BOOM_INDEPENDENT_MVN_MODEL_GIVEN_SCALAR_SIGMA_HPP_
