@@ -21,30 +21,30 @@
 
 #include <vector>
 
-#include <memory>
 #include <boost/unordered_map.hpp>
+#include <memory>
 
-#include <Models/PointProcess/PointProcess.hpp>
-#include <Models/PointProcess/PoissonProcess.hpp>
-#include <Models/Policies/CompositeParamPolicy.hpp>
-#include <Models/Policies/IID_DataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <cpputil/RefCounted.hpp>
+#include "Models/PointProcess/PointProcess.hpp"
+#include "Models/PointProcess/PoissonProcess.hpp"
+#include "Models/Policies/CompositeParamPolicy.hpp"
+#include "Models/Policies/IID_DataPolicy.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "cpputil/RefCounted.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  namespace MmppHelper{
-    typedef std::vector<std::vector<PoissonProcess *> > SourceVector;
+  namespace MmppHelper {
+    typedef std::vector<std::vector<PoissonProcess *>> SourceVector;
 
     // A class to describe which processes are active in an HMM state,
     // and keep track of information needed during the forward-backward
     // algorithm, such as which other states it communicates with.
-    class HmmState : private RefCounted{
+    class HmmState : private RefCounted {
      public:
       // The HmmState does not own the PoissonProcess * pointers that
       // it is passed.  Each should be owned by a Ptr external to this
       // class.
-      HmmState(std::vector<PoissonProcess *> processes);
+      explicit HmmState(const std::vector<PoissonProcess *> &processes);
 
       // The id_number is this state's position in the vector of
       // hmm_states_ in the managing MMPP.
@@ -54,16 +54,16 @@ namespace BOOM{
       // Two states compare equal if they have the same set of active
       // processes.  The comparison is fast because active_processes_
       // is kept sorted.
-      bool operator==(const HmmState &rhs)const;
+      bool operator==(const HmmState &rhs) const;
 
       // The number of processes constituting the state.
-      int number_of_active_processes()const;
+      int number_of_active_processes() const;
 
       // Accessor for the set of active processes.  Note that the
       // constructor sorts them, so the order here may be different
       // than the order the processes were in when they were passed to
       // the constructor.
-      const std::vector<PoissonProcess *> & active_processes()const;
+      const std::vector<PoissonProcess *> &active_processes() const;
 
       // Add or remove processes to the set of active processes
       // defining the state.  Adding processes that are already part
@@ -73,14 +73,14 @@ namespace BOOM{
       void add_processes(std::vector<PoissonProcess *> additional_processes);
       void remove_processes(std::vector<PoissonProcess *> processes_to_remove);
 
-      const std::vector<HmmState *> & potential_outgoing_transitions() const;
-      const std::vector<HmmState *> & potential_incoming_transitions() const;
+      const std::vector<HmmState *> &potential_outgoing_transitions() const;
+      const std::vector<HmmState *> &potential_incoming_transitions() const;
 
       // The set of processes that could be responsible for a transition
       // from *this to *destination.  The result could be a singleton,
       // or it could be empty.
-      const std::vector<PoissonProcess *> &
-      processes_transitioning_to(const HmmState *destination)const;
+      const std::vector<PoissonProcess *> &processes_transitioning_to(
+          const HmmState *destination) const;
 
       // Inform the object that it is possible to transition to *this
       // from *previous_state.
@@ -105,14 +105,16 @@ namespace BOOM{
 
       // Keep track of which processes are responsible for a transition
       // from this state to each state in can_transition_to_.
-      typedef std::map<const HmmState *, std::vector<PoissonProcess *> >
-      TransitionResponsibilityMap;
+      typedef std::map<const HmmState *, std::vector<PoissonProcess *>>
+          TransitionResponsibilityMap;
       TransitionResponsibilityMap responsible_for_transition_to_;
 
      public:
-      friend void intrusive_ptr_add_ref(HmmState *s){s->up_count();}
-      friend void intrusive_ptr_release(HmmState *s){
-        s->down_count(); if(s->ref_count()==0) delete s;}
+      friend void intrusive_ptr_add_ref(HmmState *s) { s->up_count(); }
+      friend void intrusive_ptr_release(HmmState *s) {
+        s->down_count();
+        if (s->ref_count() == 0) delete s;
+      }
     };
 
     //----------------------------------------------------------------------
@@ -136,8 +138,8 @@ namespace BOOM{
       //     the processes argument.  Some elements of the vector can be
       //     repeated if the same mixture component is shared by
       //     multiple processes.
-      ProcessInfo(const std::vector<PoissonProcess *> & processes,
-                  const std::vector<MixtureComponent *> & mixture_components);
+      ProcessInfo(const std::vector<PoissonProcess *> &processes,
+                  const std::vector<MixtureComponent *> &mixture_components);
 
       // Evaluate the cumulative_hazard for the interval [t-1, t], the
       // instantaneous event rate at time t, and mixture component log
@@ -156,22 +158,23 @@ namespace BOOM{
       // possible source of the event at time 't' then this function
       // returns -infinity.  Otherwise it returns the log of the event
       // rate for 'process' at the timestamp of event 't'.
-      double log_event_rate(const PoissonProcess *process, int t)const;
+      double log_event_rate(const PoissonProcess *process, int t) const;
 
       // Returns the log density for the mixture component associated
       // with 'process' evalutated on event t.  If that event contains
       // no marks or if no mixture components are supplied then 0 is
       // returned.
-      double mixture_log_likelihood(const PoissonProcess *process, int t)const;
+      double mixture_log_likelihood(const PoissonProcess *process, int t) const;
 
       // The sum of the cumulative hazards of the active processes in
       // state from time t-1 to t.  This return values is not affected
       // by the presence or absence of the 'source' argument to
       // 'evaluate'.
-      double conditional_cumulative_hazard(const HmmState *state, int t)const;
+      double conditional_cumulative_hazard(const HmmState *state, int t) const;
+
      private:
       // Returns the position of 'process' in processes_;
-      int process_id(const PoissonProcess *process)const;
+      int process_id(const PoissonProcess *process) const;
 
       const double neginf_;
       std::vector<PoissonProcess *> processes_;
@@ -207,7 +210,7 @@ namespace BOOM{
       Matrix logp_;
     };
 
-  } // namespace MmppHelper
+  }  // namespace MmppHelper
 
   //======================================================================
   // The Markov modulated Poisson Process, as defined in Scott and
@@ -237,11 +240,9 @@ namespace BOOM{
   // should be capable of calling sample_posterior().
   //
   // Calling sample_posterior
-  class MarkovModulatedPoissonProcess
-      : public CompositeParamPolicy,
-        public IID_DataPolicy<PointProcess>,
-        public PriorPolicy
-  {
+  class MarkovModulatedPoissonProcess : public CompositeParamPolicy,
+                                        public IID_DataPolicy<PointProcess>,
+                                        public PriorPolicy {
    public:
     typedef MmppHelper::HmmState HmmState;
     typedef MmppHelper::ProcessInfo ProcessInfo;
@@ -249,7 +250,7 @@ namespace BOOM{
 
     MarkovModulatedPoissonProcess();
     MarkovModulatedPoissonProcess(const MarkovModulatedPoissonProcess &rhs);
-    MarkovModulatedPoissonProcess * clone() const override;
+    MarkovModulatedPoissonProcess *clone() const override;
 
     // Adds 'process' as a component process to the MMPP.  Every
     // component process must be registered with the MMPP using this
@@ -270,10 +271,10 @@ namespace BOOM{
     //     deactivated when 'process' generates an event.  For birth or
     //     death processes, 'processes' can be included in this vector.
     //   emits: A model describing the marks that 'process' emits.
-    void add_component_process(Ptr<PoissonProcess> process,
-                               std::vector<Ptr<PoissonProcess> > spawns,
-                               std::vector<Ptr<PoissonProcess> > kills,
-                               Ptr<MixtureComponent> emits);
+    void add_component_process(const Ptr<PoissonProcess> &process,
+                               std::vector<Ptr<PoissonProcess>> spawns,
+                               std::vector<Ptr<PoissonProcess>> kills,
+                               const Ptr<MixtureComponent> &emits);
 
     // After all component processes have been added using
     // add_component_process() the user should call make_hmm_states()
@@ -285,14 +286,14 @@ namespace BOOM{
     //      is just a seed to use for determining which states of
     //      nature need to be considered.
     void make_hmm_states(
-        std::vector<Ptr<PoissonProcess> > initial_state_elements);
+        const std::vector<Ptr<PoissonProcess>> &initial_state_elements);
 
     // Add data to the model.  This had to be over-ridden because the
     // matrices that keep track of the probability of activity and the
     // probability of responsibility get modified when a new process
     // is added.
-    void add_data(Ptr<Data> dp) override;
-    void add_data(Ptr<PointProcess> dp) override;
+    void add_data(const Ptr<Data> &dp) override;
+    void add_data(const Ptr<PointProcess> &dp) override;
 
     // If a subset (possibly all) of the data are from a training set
     // where the original source is knwon then add the data using
@@ -303,7 +304,8 @@ namespace BOOM{
     // then you can use an empty vector to signal "don't know" for
     // that event.  The size of 'source' must match the number of
     // events in 'process'.  It cannot be empty.
-    void add_supervised_data(Ptr<PointProcess> dp, const SourceVector &source);
+    void add_supervised_data(const Ptr<PointProcess> &dp,
+                             const SourceVector &source);
 
     // Clears the data managed by this model.  The over-ride is
     // necessary because of internal state not managed by the
@@ -321,9 +323,7 @@ namespace BOOM{
 
     // Returns the log likelihood value that was computed during the
     // most recent data imputation.
-    double last_loglike()const{
-      return last_loglike_;
-    }
+    double last_loglike() const { return last_loglike_; }
 
     // As the MCMC progresses, the model accumulates information about
     // which processes were active at various points in time and which
@@ -399,16 +399,14 @@ namespace BOOM{
     //   MCMC.  Thus they are maintained as integers counting the
     //   number of events seen thus far.  They are turned into
     //   probabilities by dividing by the number of MCMC iterations.
-    void backward_sampling(RNG &rng,
-                           const PointProcess &process,
+    void backward_sampling(RNG &rng, const PointProcess &process,
                            Matrix &probability_of_activity,
                            Matrix &probability_of_responsibility);
 
-
     // In some MMPP's the hmm state space size grows exponentially
     // with the number of latent processes.
-    int hmm_state_space_size()const;
-    int number_of_processes()const;
+    int hmm_state_space_size() const;
+    int number_of_processes() const;
 
     // Return the probability that each state was active at time the
     // time of event t.
@@ -420,7 +418,7 @@ namespace BOOM{
     //   A matrix containing the probability that each state was
     //   active at time the time of event t.  Rows are component
     //   processes, columns are times.
-    Matrix probability_of_activity(int data_series_number = 0)const;
+    Matrix probability_of_activity(int data_series_number = 0) const;
 
     // Return the probability that each component process was
     // responsible for the event at time t.
@@ -432,7 +430,7 @@ namespace BOOM{
     //   A matrix containing the probability that each component
     //   process was responsible for the event at time t.  Rows are
     //   component processes, columns are times.
-    Matrix probability_of_responsibility(int data_series_number)const;
+    Matrix probability_of_responsibility(int data_series_number) const;
 
     // Return log(lambda_1(t) * p_1(y) + lambda_2(t) * p_2(y) + ...),
     // where
@@ -443,16 +441,14 @@ namespace BOOM{
     //  * the sum is over all possible processes that could have been
     //    responsible for the transition from first_state to
     //    second_state.
-    double conditional_event_loglikelihood(int t,
-                                           const HmmState *first_state,
-                                           const HmmState *second_state,
-                                           const ProcessInfo &process_info)const;
+    double conditional_event_loglikelihood(
+        int t, const HmmState *first_state, const HmmState *second_state,
+        const ProcessInfo &process_info) const;
 
     // Add the exposure time between events t-1 and t from 'process'
     // to the active processes from the hmm_state indexed by
     // 'previous_state'.
-    void update_exposure_time(const PointProcess &process,
-                              int t,
+    void update_exposure_time(const PointProcess &process, int t,
                               int previous_state);
 
     // Draw the previous HMM state given the index of the current
@@ -477,11 +473,10 @@ namespace BOOM{
     //   The component process responsible for the transition from
     //   previous_state to current_state, as sampled from its full
     //   conditional distribution.
-    PoissonProcess * sample_responsible_process(RNG &rng,
-                                                int previous_state,
-                                                int current_state,
-                                                const ProcessInfo &process_info,
-                                                int t);
+    PoissonProcess *sample_responsible_process(RNG &rng, int previous_state,
+                                               int current_state,
+                                               const ProcessInfo &process_info,
+                                               int t);
 
     // Records the current probability that each process is active.
     // Args:
@@ -495,21 +490,18 @@ namespace BOOM{
     //   can divide probability_of_activity by the number of MCMC
     //   iterations to get the marginal probability that each state is
     //   active at each time point, averaging over the parameters.
-    void record_activity(VectorView probability_of_activity,
-                         int hmm_state_id);
+    void record_activity(VectorView probability_of_activity, int hmm_state_id);
 
     // The set of hmm states created by make_hmm_states().  Exposed
     // mainly for testing.
-    const std::vector<Ptr<HmmState> > & hmm_states()const {
-      return hmm_states_;
-    }
+    const std::vector<Ptr<HmmState>> &hmm_states() const { return hmm_states_; }
 
    private:
-    std::vector<Ptr<PoissonProcess> > component_processes_;
+    std::vector<Ptr<PoissonProcess>> component_processes_;
 
     // The minimal list of mixture components, with each element being
     // unique.
-    std::vector<Ptr<MixtureComponent> > mixture_components_;
+    std::vector<Ptr<MixtureComponent>> mixture_components_;
 
     // A flag for whether mixture components are present, which is
     // determined by the first call to add_component_process().
@@ -527,27 +519,28 @@ namespace BOOM{
 
     // spawns_[process] is the vector of processes that an event from
     // 'process' turns on.
-    std::map<const PoissonProcess *, std::vector<PoissonProcess *> > spawns_;
+    std::map<const PoissonProcess *, std::vector<PoissonProcess *>> spawns_;
 
     // The processes that an event from 'process' turns off.
-    std::map<const PoissonProcess *, std::vector<PoissonProcess *> > kills_;
+    std::map<const PoissonProcess *, std::vector<PoissonProcess *>> kills_;
     std::map<const PoissonProcess *, MixtureComponent *> emits_;
     //------------------------------------------------------------
 
     // The set of HMM states used to define the forward-backward
     // algorithm.
-    std::vector<Ptr<HmmState> > hmm_states_;
+    std::vector<Ptr<HmmState>> hmm_states_;
 
     void check_that_all_processes_have_been_registered();
-    void check_first_entry(Ptr<PoissonProcess> process);
-    void check_for_new_process(Ptr<PoissonProcess> process);
-    void check_for_new_mixture_component(Ptr<MixtureComponent> component);
-    Ptr<HmmState> check_for_new_hmm_state(Ptr<HmmState> potential_state);
-    void generate_new_states(Ptr<HmmState> state);
+    void check_first_entry(const Ptr<PoissonProcess> &process);
+    void check_for_new_process(const Ptr<PoissonProcess> &process);
+    void check_for_new_mixture_component(
+        const Ptr<MixtureComponent> &component);
+    Ptr<HmmState> check_for_new_hmm_state(const Ptr<HmmState> &potential_state);
+    void generate_new_states(const Ptr<HmmState> &state);
 
     // Return the position of 'process' in the data member
     // component_processes_.
-    int process_id(const PoissonProcess *process)const;
+    int process_id(const PoissonProcess *process) const;
     double initialize_filter(const PointProcess &process);
     void create_process_info();
 
@@ -581,5 +574,5 @@ namespace BOOM{
     SourceMap known_source_store_;
   };
 
-}
-#endif // BOOM_MARKOV_MODULATED_POISSON_PROCESS_HPP_
+}  // namespace BOOM
+#endif  // BOOM_MARKOV_MODULATED_POISSON_PROCESS_HPP_
