@@ -19,30 +19,30 @@
 #ifndef BOOM_POINT_PROCESS_DATA_HPP_
 #define BOOM_POINT_PROCESS_DATA_HPP_
 
-#include <Models/DataTypes.hpp>
-#include <cpputil/DateTime.hpp>
 #include <boost/operators.hpp>
+#include "Models/DataTypes.hpp"
+#include "cpputil/DateTime.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   class PointProcessEvent
       : public Data,
         public boost::less_than_comparable<PointProcessEvent>,
-        public boost::less_than_comparable<PointProcessEvent, DateTime>
-  {
+        public boost::less_than_comparable<PointProcessEvent, DateTime> {
    public:
-    PointProcessEvent(const DateTime &time);
-    PointProcessEvent(const DateTime &time, Ptr<Data> mark);
-    PointProcessEvent * clone() const override;
-    ostream & display(ostream &)const override;
+    // Implicit conversion from DateTime is intentional.
+    PointProcessEvent(const DateTime &time);  // NOLINT
+    PointProcessEvent(const DateTime &time, const Ptr<Data> &mark);
+    PointProcessEvent *clone() const override;
+    ostream &display(ostream &) const override;
 
-    const DateTime &timestamp()const;
-    const Data * mark()const;
-    Ptr<Data> mark_ptr()const;
-    bool has_mark()const;
+    const DateTime &timestamp() const;
+    const Data *mark() const;
+    Ptr<Data> mark_ptr() const;
+    bool has_mark() const;
 
-    bool operator<(const PointProcessEvent &rhs)const;
-    bool operator<(const DateTime &rhs)const;
+    bool operator<(const PointProcessEvent &rhs) const;
+    bool operator<(const DateTime &rhs) const;
 
    private:
     DateTime timestamp_;
@@ -57,38 +57,38 @@ namespace BOOM{
     // If you create an empty point process the beginning and end of
     // the observation window will be the default value for DateTime.
     // You must adjust the window before you can use the object.
-    PointProcess(){}
+    PointProcess() {}
     PointProcess(const DateTime &begin, const DateTime &end);
     PointProcess(const DateTime &begin, const DateTime &end,
-                 const std::vector<DateTime> & events);
+                 const std::vector<DateTime> &events);
     PointProcess(const DateTime &begin, const DateTime &end,
-                 const std::vector<DateTime> & events,
+                 const std::vector<DateTime> &events,
                  const std::vector<Ptr<Data> > &marks);
 
     // Use this constructor when the observation window is unknown and
     // all you have is the vector of event times.  It will set the
     // observation window to coincide with the first and last event
     // time.
-    PointProcess(const std::vector<DateTime> &events);
+    explicit PointProcess(const std::vector<DateTime> &events);
     PointProcess(const std::vector<DateTime> &events,
                  const std::vector<Ptr<Data> > &marks);
 
     PointProcess(const PointProcess &rhs);
 
-    PointProcess * clone() const override;
-    ostream &display(ostream &out)const override;
+    PointProcess *clone() const override;
+    ostream &display(ostream &out) const override;
 
-    uint number_of_events()const;
-    double window_duration()const;      // Time is measured in days.
+    uint number_of_events() const;
+    double window_duration() const;  // Time is measured in days.
 
-    const PointProcessEvent &event(int i)const;
+    const PointProcessEvent &event(int i) const;
 
     // The interarrival time between events i and i-1.  If i==0 the
     // arrival time is measured from the start of the observation
     // window.  If i == number_of_events() then the arrival time is
     // the time from the last event to the end of the observation
     // window.  Time is measured in days.
-    double arrival_time(int i)const;
+    double arrival_time(int i) const;
 
     // If *this and rhs share an endpoint then they will be joined and
     // their events will be combined.  It is an error to append a
@@ -97,19 +97,19 @@ namespace BOOM{
 
     // Predicates indicating whether *this and rhs share an endpoint
     // in their observation windows.
-    bool immediately_follows(const PointProcess &rhs)const;
-    bool immediately_precedes(const PointProcess &rhs)const;
-    bool adjoins(const PointProcess &rhs)const;
+    bool immediately_follows(const PointProcess &rhs) const;
+    bool immediately_precedes(const PointProcess &rhs) const;
+    bool adjoins(const PointProcess &rhs) const;
 
     // It is an error to add a timestamp that is outside the window
     // covered by the process.
-    PointProcess & add_event(const DateTime &timestamp);
-    PointProcess & add_event(const DateTime &timestamp, Ptr<Data> mark);
-    PointProcess & add_event(const PointProcessEvent &event);
+    PointProcess &add_event(const DateTime &timestamp);
+    PointProcess &add_event(const DateTime &timestamp, const Ptr<Data> &mark);
+    PointProcess &add_event(const PointProcessEvent &event);
 
     // Accessors and setters for either end of the observation window.
-    const DateTime & window_begin()const;
-    const DateTime & window_end()const;
+    const DateTime &window_begin() const;
+    const DateTime &window_end() const;
     void set_window(const DateTime &begin, const DateTime &end);
     void set_window_end(const DateTime &end);
     void set_window_begin(const DateTime &start);
@@ -118,12 +118,11 @@ namespace BOOM{
 
    private:
     // Functions to check state
-    void check_endpoints(const DateTime &begin,
-                         const DateTime &end)const;
+    void check_endpoints(const DateTime &begin, const DateTime &end) const;
     void check_events_inside_window(const DateTime &begin,
-                                    const DateTime &end)const;
-    void check_event_inside_window(const DateTime &)const;
-    void check_legal_event_number(int i)const;
+                                    const DateTime &end) const;
+    void check_event_inside_window(const DateTime &) const;
+    void check_legal_event_number(int i) const;
 
     DateTime begin_;
     DateTime end_;
@@ -134,5 +133,5 @@ namespace BOOM{
     double resolution_;
   };
 
-}
-#endif //  BOOM_POINT_PROCESS_DATA_HPP_
+}  // namespace BOOM
+#endif  //  BOOM_POINT_PROCESS_DATA_HPP_
