@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -19,17 +20,17 @@
 #ifndef POISSON_MODEL_H
 #define POISSON_MODEL_H
 
-#include <Models/ModelTypes.hpp>
-#include <Models/Sufstat.hpp>
-#include <Models/Policies/ParamPolicy_1.hpp>
-#include <Models/Policies/SufstatDataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
+#include "Models/ModelTypes.hpp"
+#include "Models/Policies/ParamPolicy_1.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/Policies/SufstatDataPolicy.hpp"
+#include "Models/Sufstat.hpp"
 
 //----------------------------------------------------------------------//
-namespace BOOM{
+namespace BOOM {
 
-  class PoissonSuf : public SufstatDetails<IntData>{
-  public:
+  class PoissonSuf : public SufstatDetails<IntData> {
+   public:
     // constructor
     PoissonSuf();
 
@@ -52,24 +53,24 @@ namespace BOOM{
                                 double incremental_exposure);
 
     void clear() override;
-    double sum()const;
-    double n()const;
-    double lognc()const;
+    double sum() const;
+    double n() const;
+    double lognc() const;
 
-    void Update(const IntData & dat) override;
+    void Update(const IntData &dat) override;
     void add_mixture_data(double y, double prob);
-    void combine(Ptr<PoissonSuf>);
+    void combine(const Ptr<PoissonSuf> &);
     void combine(const PoissonSuf &);
-    PoissonSuf * abstract_combine(Sufstat *s) override;
+    PoissonSuf *abstract_combine(Sufstat *s) override;
 
-    Vector vectorize(bool minimal=true)const override;
+    Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
-                                            bool minimal=true) override;
+                                       bool minimal = true) override;
     Vector::const_iterator unvectorize(const Vector &v,
-                                            bool minimal=true) override;
-    ostream &print(ostream &out)const override;
+                                       bool minimal = true) override;
+    ostream &print(ostream &out) const override;
 
-  private:
+   private:
     double sum_;    // event_count
     double n_;      // exposure
     double lognc_;  // log nc is the log product of x-factorials
@@ -81,37 +82,36 @@ namespace BOOM{
                        public PriorPolicy,
                        public NumOptModel,
                        public IntModel,
-                       virtual public MixtureComponent
-  {
-  public:
-
-    PoissonModel(double lam=1.0);
-    PoissonModel(const std::vector<uint> &);
+                       virtual public MixtureComponent {
+   public:
+    explicit PoissonModel(double lam = 1.0);
+    explicit PoissonModel(const std::vector<uint> &);
     PoissonModel(const PoissonModel &m);
     PoissonModel *clone() const override;
 
     void mle() override;
-    double Loglike(const Vector &lambda,
-                           Vector &g, Matrix &h, uint nd)const override;
+    double Loglike(const Vector &lambda, Vector &g, Matrix &h,
+                   uint nd) const override;
 
     Ptr<UnivParams> Lam();
-    const Ptr<UnivParams> Lam()const;
-    double lam()const;
+    const Ptr<UnivParams> Lam() const;
+    double lam() const;
     void set_lam(double);
 
     // probability calculations
-    virtual double pdf(Ptr<Data> x, bool logscale) const;
-    double pdf(const Data * x, bool logscale) const override;
+    virtual double pdf(const Ptr<Data> &dp, bool logscale) const;
+    double pdf(const Data *x, bool logscale) const override;
     double pdf(uint x, bool logscale) const;
     double logp(int x) const override;
+    int number_of_observations() const override { return dat().size(); }
 
     // moments and summaries:
-    double mean()const;
-    double var()const;
-    double sd()const;
+    double mean() const;
+    double var() const;
+    double sd() const;
     double simdat(RNG &rng = GlobalRng::rng) const;
 
-    virtual void add_mixture_data(Ptr<Data>,  double prob);
+    virtual void add_mixture_data(const Ptr<Data> &, double prob);
   };
 
 }  // namespace BOOM
