@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -17,46 +18,53 @@
 */
 #ifndef BOOM_MIXTURE_DATA_POLICIES_HPP
 #define BOOM_MIXTURE_DATA_POLICIES_HPP
-#include <Models/ModelTypes.hpp>
-#include <Models/Policies/DataInfoPolicy.hpp>
-#include <Models/CategoricalData.hpp>
-#include <Models/DataTypes.hpp>
-#include <fstream>
-#include <list>
+#include "Models/CategoricalData.hpp"
+#include "Models/DataTypes.hpp"
+#include "Models/ModelTypes.hpp"
+#include "Models/Policies/DataInfoPolicy.hpp"
 
-namespace BOOM{
- //======================================================================
-
-  class MixtureDataPolicy : public DefaultDataInfoPolicy<Data>{
+namespace BOOM {
+  // A data policy for use with finite mixture and similar models.  Data are
+  // stored as a vector of Ptr<Data> objects.  The index of the mixture
+  // component responsible for each data point can be specified.
+  class MixtureDataPolicy : public DefaultDataInfoPolicy<Data> {
    public:
     typedef Data DataType;
     typedef MixtureDataPolicy DataPolicy;
-    typedef std::vector<Ptr<DataType> > DatasetType;
+    typedef std::vector<Ptr<DataType>> DatasetType;
     typedef Ptr<DatasetType, false> dsetPtr;
-   protected:
+
    public:
-    MixtureDataPolicy(uint S);
+    explicit MixtureDataPolicy(int number_of_latent_levels);
     MixtureDataPolicy(const MixtureDataPolicy &);
-    MixtureDataPolicy * clone()const override =0;
-    MixtureDataPolicy & operator=(const MixtureDataPolicy &);
+    MixtureDataPolicy *clone() const override = 0;
+    MixtureDataPolicy &operator=(const MixtureDataPolicy &);
 
     void clear_data() override;
 
-    DatasetType & dat() override{return *dat_;}
-    const DatasetType & dat()const override{return *dat_;}
+    DatasetType &dat() override { return *dat_; }
+    const DatasetType &dat() const override { return *dat_; }
 
-    std::vector<Ptr<CategoricalData> >  & latent_data();
-    const std::vector<Ptr<CategoricalData> >  & latent_data()const;
+    // The mixture indicators specifying which components are responsible for
+    // each observation.
+    std::vector<Ptr<CategoricalData>> &latent_data();
+    const std::vector<Ptr<CategoricalData>> &latent_data() const;
 
-    virtual void set_data(const dsetPtr d);
+    virtual void set_data(const dsetPtr &d);
     virtual void set_data(const DatasetType &d);
 
     template <class FwdIt>
     void set_data(FwdIt Beg, FwdIt End);
-    void add_data(Ptr<Data> dp) override;
-    void combine_data(const Model &, bool just_suf=true) override;
+    void add_data(const Ptr<Data> &dp) override;
+    void combine_data(const Model &, bool just_suf = true) override;
 
-    void add_data_with_known_source(Ptr<Data>, int source);
+    // Add a data point to the model.  The data point is known to come from a
+    // particular mixture component.
+    //
+    // Args:
+    //   data_point: The data point to be added to the model.
+    //   source:  The index of the mixture component responsible for dp.
+    void add_data_with_known_source(const Ptr<Data> &data_point, int source);
 
     // Sets the source of each observation.  Negative numbers mean the
     // source is uncertain.  Non negative numbers less than the number
@@ -68,21 +76,22 @@ namespace BOOM{
     // Indicates which mixture component the specified observation
     // comes from.  A negative answer (the usual case) means the
     // source of the observation is uncertain.
-    int which_mixture_component(int observation_number)const;
+    int which_mixture_component(int observation_number) const;
+
    private:
     dsetPtr dat_;  // Model owns pointer to its data.
-    std::vector<Ptr<CategoricalData> > latent_;
-    Ptr<CatKey> pkey_;
+    std::vector<Ptr<CategoricalData>> latent_;
+    Ptr<CatKeyBase> pkey_;
 
     // The following vector will be empty in most cases.  It will be filled when
     std::vector<int> known_data_source_;
   };
   //======================================================================
 
-  template<class FwdIt>
-  void MixtureDataPolicy::set_data(FwdIt Beg, FwdIt End){
+  template <class FwdIt>
+  void MixtureDataPolicy::set_data(FwdIt Beg, FwdIt End) {
     clear_data();
-    while(Beg!=End){
+    while (Beg != End) {
       add_data(*Beg);
       ++Beg;
     }
@@ -90,5 +99,5 @@ namespace BOOM{
 
   //============================================================
 
-}
-#endif //BOOM_MIXTURE_DATA_POLICIES_HPP
+}  // namespace BOOM
+#endif  // BOOM_MIXTURE_DATA_POLICIES_HPP
