@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -19,33 +20,31 @@
 #ifndef BOOM_PRIOR_POLICY_HPP
 #define BOOM_PRIOR_POLICY_HPP
 
-#include <Models/ModelTypes.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
 #include <map>
+#include "Models/ModelTypes.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   // A policy class implementing the relationship between a Model and
   // its PosteriorSampler.
   class PriorPolicy : virtual public Model {
    public:
-    PriorPolicy * clone()const override =0;
+    PriorPolicy *clone() const override = 0;
 
     // Invoke each of the sampling methods that have been set, in the
     // order they were set.
     void sample_posterior() override;
     double logpri() const override;
-    void set_method(Ptr<PosteriorSampler>) override;
+    void set_method(const Ptr<PosteriorSampler> &) override;
     void clear_methods();
 
     // Returns the number of sampling methods that have been set.
     int number_of_sampling_methods() const override;
 
    protected:
-    PosteriorSampler * sampler(int i) override {
-      return samplers_[i].get();
-    }
-    PosteriorSampler const * const sampler(int i) const override {
+    PosteriorSampler *sampler(int i) override { return samplers_[i].get(); }
+    PosteriorSampler const *const sampler(int i) const override {
       return samplers_[i].get();
     }
 
@@ -55,4 +54,4 @@ namespace BOOM{
 
 }  // namespace BOOM
 
-#endif // BOOM_PRIOR_POLICY_HPP
+#endif  // BOOM_PRIOR_POLICY_HPP
