@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -17,47 +18,26 @@
 */
 #ifndef BOOM_CORRELATION_SAMPLER_HPP
 #define BOOM_CORRELATION_SAMPLER_HPP
-#include <Samplers/Sampler.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <TargetFun/TargetFun.hpp>
-#include <Models/ParamTypes.hpp>
-#include <Models/ModelTypes.hpp>
-#include <Models/MvnModel.hpp>
-namespace BOOM{
-
-  class CorrTF
-    : public TargetFun
-  {
-  public:
-    CorrTF(Ptr<SpdParams>,
-       Ptr<LoglikeModel>,
-       Ptr<CorrelationModel>);
-    CorrTF(const CorrTF &rhs);
-    //    CorrTF * clone()const;
-    double operator()(const Vector &x)const override;
-  private:
-    mutable CorrelationMatrix R, R2;
-    mutable Ptr<SpdParams> spd;
-    mutable Ptr<LoglikeModel> mod;
-    mutable Vector wsp;
-    Ptr<CorrelationModel> pri;
-    bool refresh;
-  };
+#include "Models/ModelTypes.hpp"
+#include "Models/MvnModel.hpp"
+#include "Models/ParamTypes.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
+#include "Samplers/Sampler.hpp"
+#include "TargetFun/TargetFun.hpp"
+namespace BOOM {
 
   // Draws from the posterior distribution of the correlation matrix
   // in a Gaussian model with known means and variances given a
   // CorrelationModel prior distribution on the correlation matrix
-  class MvnCorrelationSampler
-    : public PosteriorSampler
-  {
-  public:
-    MvnCorrelationSampler(MvnModel *,
-              Ptr<CorrelationModel>,
-              bool refresh_suf = false,
-        RNG &seeding_rng = GlobalRng::rng);
+  class MvnCorrelationSampler : public PosteriorSampler {
+   public:
+    MvnCorrelationSampler(MvnModel *model, const Ptr<CorrelationModel> &prior,
+                          bool refresh_suf = false,
+                          RNG &seeding_rng = GlobalRng::rng);
     void draw() override;
-    double logpri()const override;
-  private:
+    double logpri() const override;
+
+   private:
     double logp(double r);
     void find_limits();
     void draw_one();
@@ -74,5 +54,5 @@ namespace BOOM{
     double lo_, hi_;
   };
 
-}
-#endif// BOOM_CORRELATION_SAMPLER_HPP
+}  // namespace BOOM
+#endif  // BOOM_CORRELATION_SAMPLER_HPP
