@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2013 Steven L. Scott
 
@@ -19,24 +20,24 @@
 #ifndef BOOM_ZERO_INFLATED_GAMMA_POSTERIOR_SAMPLER_HPP_
 #define BOOM_ZERO_INFLATED_GAMMA_POSTERIOR_SAMPLER_HPP_
 
-#include <Models/ZeroInflatedGammaModel.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/PosteriorSamplers/BetaBinomialSampler.hpp>
-#include <Models/PosteriorSamplers/GammaPosteriorSampler.hpp>
+#include "Models/PosteriorSamplers/BetaBinomialSampler.hpp"
+#include "Models/PosteriorSamplers/GammaPosteriorSampler.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
+#include "Models/ZeroInflatedGammaModel.hpp"
 
 namespace BOOM {
 
-  class ZeroInflatedGammaPosteriorSampler
-      : public PosteriorSampler {
+  class ZeroInflatedGammaPosteriorSampler : public PosteriorSampler {
    public:
     ZeroInflatedGammaPosteriorSampler(
         ZeroInflatedGammaModel *model,
-        Ptr<BetaModel> prior_for_positive_probability,
-        Ptr<DoubleModel> prior_for_gamma_mean,
-        Ptr<DoubleModel> prior_for_gamma_shape,
+        const Ptr<BetaModel> &prior_for_positive_probability,
+        const Ptr<DoubleModel> &prior_for_gamma_mean,
+        const Ptr<DoubleModel> &prior_for_gamma_shape,
         RNG &seeding_rng = GlobalRng::rng);
     double logpri() const override;
     void draw() override;
+
    private:
     Ptr<BetaBinomialSampler> binomial_sampler_;
     Ptr<GammaPosteriorSampler> gamma_sampler_;
@@ -44,4 +45,4 @@ namespace BOOM {
 
 }  // namespace BOOM
 
-#endif //  BOOM_ZERO_INFLATED_GAMMA_POSTERIOR_SAMPLER_HPP_
+#endif  //  BOOM_ZERO_INFLATED_GAMMA_POSTERIOR_SAMPLER_HPP_
