@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2012 Steven L. Scott
 
@@ -19,23 +20,24 @@
 #ifndef BOOM_ZERO_INFLATED_POISSON_SAMPLER_HPP_
 #define BOOM_ZERO_INFLATED_POISSON_SAMPLER_HPP_
 
-#include <Models/ZeroInflatedPoissonModel.hpp>
-#include <Models/GammaModel.hpp>
-#include <Models/BetaModel.hpp>
+#include "Models/BetaModel.hpp"
+#include "Models/GammaModel.hpp"
+#include "Models/ZeroInflatedPoissonModel.hpp"
 
-namespace BOOM{
+namespace BOOM {
   class ZeroInflatedPoissonSampler : public PosteriorSampler {
    public:
     ZeroInflatedPoissonSampler(ZeroInflatedPoissonModel *model,
-                               Ptr<GammaModel> lambda_prior,
-                               Ptr<BetaModel> zero_probability_prior,
+                               const Ptr<GammaModel> &lambda_prior,
+                               const Ptr<BetaModel> &zero_probability_prior,
                                RNG &seeding_rng = GlobalRng::rng);
     void draw() override;
     double logpri() const override;
+
    private:
     ZeroInflatedPoissonModel *model_;
     Ptr<GammaModel> lambda_prior_;
     Ptr<BetaModel> zero_probability_prior_;
   };
-}
-#endif// BOOM_ZERO_INFLATED_POISSON_SAMPLER_HPP_
+}  // namespace BOOM
+#endif  // BOOM_ZERO_INFLATED_POISSON_SAMPLER_HPP_
