@@ -1,5 +1,9 @@
+#ifndef BOOM_MATH_CONSTANTS_HPP_
+#define BOOM_MATH_CONSTANTS_HPP_
+
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
-  Copyright (C) 2005-2010 Steven L. Scott
+  Copyright (C) 2005-2018 Steven L. Scott
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -16,19 +20,19 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#ifndef BOOM_MATH_CONSTANTS_HPP_
-#define BOOM_MATH_CONSTANTS_HPP_
-namespace BOOM{
+namespace BOOM {
 
-struct Constants{
-  static double pi;
-  static double pi_squared;
-  static double half_pi_squared;
-  static double root_2pi;
-  static double log_root_2pi;
-  static double log_pi;
-};
+  struct Constants {
+    static constexpr double pi = 3.141592653589793;
+    static constexpr double pi_squared = 9.86960440108936;
+    static constexpr double pi_squared_over_3 = 3.289868133696452872944830333292;
+    static constexpr double pi_squared_over_6 = 1.6449340668482264061;
+    static constexpr double half_pi_squared = 4.93480220054468;
+    static constexpr double root_2pi = 2.506628274631;
+    static constexpr double log_root_2pi = 0.918938533204673;
+    static constexpr double log_pi = 1.1447298858494;
+    static constexpr double root2 = 1.4142135623730951455;
+  };
 
-
-}
-#endif // BOOM_MATH_CONSTANTS_HPP_
+}  // namespace BOOM
+#endif  // BOOM_MATH_CONSTANTS_HPP_
