@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -20,25 +21,38 @@
 #define BOOM_DATE_HPP
 
 #include <string>
-#include <BOOM.hpp>
+#include "BOOM.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   // Starting with Jan=1 helps keep things sane, but puts everything
   // off by 1 from the tm_mon field in struct tm from <ctime>.
-  enum MonthNames{unknown_month=0, Jan=1, Feb, Mar, Apr, May, Jun, Jul,
-                   Aug, Sep, Oct, Nov, Dec};
-  inline MonthNames next(MonthNames month){
-    return month < Dec ? MonthNames(month+1) : Jan;
+  enum MonthNames {
+    unknown_month = 0,
+    Jan = 1,
+    Feb,
+    Mar,
+    Apr,
+    May,
+    Jun,
+    Jul,
+    Aug,
+    Sep,
+    Oct,
+    Nov,
+    Dec
+  };
+  inline MonthNames next(MonthNames month) {
+    return month < Dec ? MonthNames(month + 1) : Jan;
   }
 
   // Starting with Sun=0 matches struct tm::wday in <ctime>.
-  enum DayNames{Sun=0, Mon, Tue, Wed, Thu, Fri, Sat};
-  inline DayNames next(DayNames day){
+  enum DayNames { Sun = 0, Mon, Tue, Wed, Thu, Fri, Sat };
+  inline DayNames next(DayNames day) {
     return day < Sat ? DayNames(day + 1) : Sun;
   }
 
-  enum calendar_format{Full,full,Abbreviations, abbreviations,numeric};
+  enum calendar_format { Full, full, Abbreviations, abbreviations, numeric };
 
   // Args:
   //   month_name: The following formats are acceptable
@@ -59,64 +73,64 @@ namespace BOOM{
   //   The enum corresponding to the day of the week in the input string.
   DayNames str2day(const string &day_name);
 
-  ostream & operator<<(ostream &, const DayNames &);
+  ostream &operator<<(ostream &, const DayNames &);
 
-  class Date{
+  class Date {
    public:
-    enum print_order{mdy, dmy, ymd};
-    enum date_format{slashes, dashes, script};
+    enum print_order { mdy, dmy, ymd };
+    enum date_format { slashes, dashes, script };
 
-    Date();                          // 'today'
-    Date(int days_after_jan_1_1970); // Unix time, but in days
-    Date(int m, int dd, int yyyy);   // January 3, 2007 is Date(1, 3, 2007);
-    Date(MonthNames m, int dd, int yyyy);     // Date(Jan, 3, 2007)
-    Date(const string &mdy, char delim='/');  // Date("Jan/3/2007")
-    Date(const string &m, int d, int yyyy);   // Date("January", 3, 2007);
-    Date(const Date & rhs);
-    Date(const struct tm &time_info);
+    Date();                           // 'today'
+    explicit Date(int days_after_jan_1_1970);  // Unix time, but in days
+    Date(int m, int dd, int yyyy);    // January 3, 2007 is Date(1, 3, 2007);
+    Date(MonthNames m, int dd, int yyyy);       // Date(Jan, 3, 2007)
+    explicit Date(const string &mdy, char delim = '/');  // Date("Jan/3/2007")
+    Date(const string &m, int d, int yyyy);     // Date("January", 3, 2007);
+    Date(const Date &rhs);
+    explicit Date(const struct tm &time_info);
 
-    Date & operator=(const Date &rhs);
-    Date & operator=(const struct tm &rhs);
-    Date & set(const tm &rhs);
-    Date & set(MonthNames month, int day, int four_digit_year);
-    Date & set(int days_after_jan_1_1970);
+    Date &operator=(const Date &rhs);
+    Date &operator=(const struct tm &rhs);
+    Date &set(const tm &rhs);
+    Date &set(MonthNames month, int day, int four_digit_year);
+    Date &set(int days_after_jan_1_1970);
 
-    Date & operator++();       // next day
-    Date operator++(int);      // next day (postfix)
-    Date & operator--();       // previous day
-    Date operator--(int);      // previous day (postfix);
-    Date & operator+=(int n);  // add n days
-    Date & operator-=(int n);  // subtract n days
+    Date &operator++();       // next day
+    Date operator++(int);     // next day (postfix)
+    Date &operator--();       // previous day
+    Date operator--(int);     // previous day (postfix);
+    Date &operator+=(int n);  // add n days
+    Date &operator-=(int n);  // subtract n days
 
-    Date operator+(int n)const;
-    Date operator-(int n)const;
+    Date operator+(int n) const;
+    Date operator-(int n) const;
 
-    bool operator==(const Date &rhs)const;  // comparison operators
-    bool operator!=(const Date &rhs)const;
-    bool operator<(const Date &rhs)const;
-    bool operator>(const Date &rhs)const;
-    bool operator<=(const Date &rhs)const;
-    bool operator>=(const Date &rhs)const;
+    bool operator==(const Date &rhs) const;  // comparison operators
+    bool operator!=(const Date &rhs) const;
+    bool operator<(const Date &rhs) const;
+    bool operator>(const Date &rhs) const;
+    bool operator<=(const Date &rhs) const;
+    bool operator>=(const Date &rhs) const;
 
     // Accessors
-    MonthNames month()const;
-    int day()const;
-    int year()const;
+    MonthNames month() const;
+    int day() const;
+    int year() const;
 
-    DayNames day_of_week()const;
-    int days_until(DayNames day)const;
-    int days_after(DayNames day)const;
-    int days_left_in_month()const;//jan 31 = 0, jan1=30
-    int days_into_year()const;    // jan 1 is 1
-    int days_left_in_year()const; // dec 31 = 0; jan 1 = 364
+    DayNames day_of_week() const;
+    int days_until(DayNames day) const;
+    int days_after(DayNames day) const;
+    int days_left_in_month() const;  // jan 31 = 0, jan1=30
+    int days_into_year() const;      // jan 1 is 1
+    int days_left_in_year() const;   // dec 31 = 0; jan 1 = 364
 
-    bool is_leap_year()const;
-    long days_after_jan_1_1970()const;
-    std::ostream & display(std::ostream &)const;
-    std::ostream & display_month(std::ostream &)const;
-    string str()const;
+    bool is_leap_year() const;
+    long days_after_jan_1_1970() const;
+    std::ostream &display(std::ostream &) const;
+    std::ostream &display_month(std::ostream &) const;
+    string str() const;
 
-    time_t to_time_t()const;
+    time_t to_time_t() const;
 
     //---------------public static members below this line ------------------
     // These could also be free functions in an appropriate namespace.
@@ -125,24 +139,24 @@ namespace BOOM{
     static void set_print_order(print_order d);
     static void set_date_format(date_format f);
 
-    static bool is_leap_year(int yyyy){
+    static bool is_leap_year(int yyyy) {
       // Divisible by 4, not if divisible by 100, but true if divisible
       // by 400.
-      return (!(yyyy % 4))  && ((yyyy % 100) || (!(yyyy % 400)));
+      return (!(yyyy % 4)) && ((yyyy % 100) || (!(yyyy % 400)));
     }
     static int days_after_jan_1_1970(MonthNames month, int day, int year);
     static int days_before_jan_1_1970(MonthNames month, int day, int year);
 
-    static int days_in_month(MonthNames month, bool leap_year=false){
-      if(month == Feb) return leap_year ? 29 : 28;
-      return days_in_month_[month];}
+    static int days_in_month(MonthNames month, bool leap_year = false) {
+      if (month == Feb) return leap_year ? 29 : 28;
+      return days_in_month_[month];
+    }
 
     // The number of days (month,day) is into the year.  Unit based,
     // so Jan 1 is 1.
-    static int days_into_year(MonthNames month, int day, bool leap){
-      int ans = leap ?
-          days_before_month_in_leap_year_[month] + day :
-          days_before_month_[month] + day;
+    static int days_into_year(MonthNames month, int day, bool leap) {
+      int ans = leap ? days_before_month_in_leap_year_[month] + day
+                     : days_before_month_[month] + day;
       return ans;
     }
 
@@ -176,6 +190,7 @@ namespace BOOM{
                                                 bool include_endpoint = false);
     static void find_month_and_day(int days_into_year, bool leap,
                                    MonthNames *month, int *day);
+
    private:
     MonthNames month_;
     int day_;
@@ -197,11 +212,11 @@ namespace BOOM{
     static const int days_before_month_[13];
     static const int days_before_month_in_leap_year_[13];
 
-    Date & start_next_month();
-    Date & end_prev_month();
-    Date & set_before_1970(int days_before_jan_1_1970);
+    Date &start_next_month();
+    Date &end_prev_month();
+    Date &set_before_1970(int days_before_jan_1_1970);
 
-    void check(MonthNames month, int day, int four_digit_year)const;
+    void check(MonthNames month, int day, int four_digit_year) const;
     static int compute_local_time_zone();
   };
   //======================================================================
@@ -209,15 +224,16 @@ namespace BOOM{
 
   // To compute (e.g.) the third Monday in June, 1972:
   // nth_day_in_month(3, Mon, Jun, 1972);
-  Date nth_weekday_in_month(int n, DayNames weekday, MonthNames month, int year);
+  Date nth_weekday_in_month(int n, DayNames weekday, MonthNames month,
+                            int year);
 
   // To compute (e.g.) the last Friday in Feb 2006:
   // last_weekday_in_month(Fri, Feb, 2006);
   Date last_weekday_in_month(DayNames weekday, MonthNames month, int year);
 
-  std::ostream & operator<<(std::ostream &, const Date &d);
-  std::ostream & display(std::ostream &, DayNames,
-                         calendar_format=Abbreviations);
-  Date guess_date_format(const string &s, char delim='/');
-}
-#endif // BOOM_DATE_HPP
+  std::ostream &operator<<(std::ostream &, const Date &d);
+  std::ostream &display(std::ostream &, DayNames,
+                        calendar_format = Abbreviations);
+  Date guess_date_format(const string &s, char delim = '/');
+}  // namespace BOOM
+#endif  // BOOM_DATE_HPP
