@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2008 Steven L. Scott
 
@@ -17,24 +18,26 @@
 */
 #ifndef BOOM_OUTPUT_TABLE_HPP
 #define BOOM_OUTPUT_TABLE_HPP
-#include <cpputil/string_utils.hpp>
-#include <uint.hpp>
+#include "cpputil/string_utils.hpp"
+#include "uint.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-class OutputTable{
- public:
-  OutputTable(uint pad=2);
-  Svec & column(uint i);
-  OutputTable & add_row(const Svec &);
-  OutputTable & add_column(const Svec &);
-  OutputTable & add_to_column(const string &, uint i);
+  class OutputTable {
+   public:
+    explicit OutputTable(uint pad = 2);
+    std::vector<std::string> &column(uint i);
+    OutputTable &add_row(const std::vector<std::string> &);
+    OutputTable &add_column(const std::vector<std::string> &);
+    OutputTable &add_to_column(const string &, uint i);
 
-  ostream & print(ostream &)const;
-  void equalize_rows();
- private:
-  uint pad_;
-  std::vector<Svec> cols_;
-};
-}
-#endif// BOOM_OUTPUT_TABLE_HPP
+    ostream &print(ostream &) const;
+    void equalize_rows();
+
+   private:
+    uint pad_;
+    std::vector<std::vector<std::string>> cols_;
+  };
+
+}  // namespace BOOM
+#endif  // BOOM_OUTPUT_TABLE_HPP
