@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,19 +14,18 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
 #ifndef CPP_DATE_UTILS_H
 #define CPP_DATE_UTILS_H
 #include <string>
 
-namespace BOOM{
+namespace BOOM {
 
   char *get_date(char *);
   std::string get_date();
 
-}
-#endif //CPP_DATE_UTILS_H
-
-
+}  // namespace BOOM
+#endif  // CPP_DATE_UTILS_H
