@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -19,15 +20,15 @@
 #ifndef BOOM_DISTRIBUTIONS_HPP
 #define BOOM_DISTRIBUTIONS_HPP
 
-#include <LinAlg/Vector.hpp>
-#include <LinAlg/Matrix.hpp>
-#include <LinAlg/SpdMatrix.hpp>
+#include "LinAlg/Matrix.hpp"
+#include "LinAlg/SpdMatrix.hpp"
+#include "LinAlg/Vector.hpp"
 
-#include <distributions/Rmath_dist.hpp>
-#include <distributions/rng.hpp>
+#include "distributions/Rmath_dist.hpp"
+#include "distributions/rng.hpp"
 
 #include <vector>
-#include <uint.hpp>
+#include "uint.hpp"
 
 namespace BOOM {
   class VectorView;
@@ -37,13 +38,14 @@ namespace BOOM {
     // Implements adaptive rejection sampling for drawing from the
     // truncated normal distribution given x>a>0.
    public:
-    TnSampler(double a);              // Set the truncation point.
-    double draw(RNG & );              // simluate a value
-    void add_point(double x);         // adds the point to the hull
-    double f(double x)const;          // log of the target distribution
-    double df(double x)const;         // derivative of logf at x
-    double h(double x, uint k)const;  // evaluates the outer hull at x
-    std::ostream & print(std::ostream & out)const;
+    explicit TnSampler(double a);      // Set the truncation point.
+    double draw(RNG &);                // simluate a value
+    void add_point(double x);          // adds the point to the hull
+    double f(double x) const;          // log of the target distribution
+    double df(double x) const;         // derivative of logf at x
+    double h(double x, uint k) const;  // evaluates the outer hull at x
+    std::ostream &print(std::ostream &out) const;
+
    private:
     std::vector<double> x;
     // points that have been tried thus far, stored in ascending
@@ -60,30 +62,31 @@ namespace BOOM {
     // to logf at x.  First knot is x[0].  Later knots satisfy x[i-1]
     // < knots[i] < x[i].
 
-    std::vector<double> cdf;     // cdf[i] = cdf[i-1] + the integral of
+    std::vector<double> cdf;  // cdf[i] = cdf[i-1] + the integral of
     // the hull from knots[i] to
     // knots[i+1].  cdf.back() assumes a
     // final knot at infinity
 
     void update_cdf();
     void refresh_knots();
-    double compute_knot(uint k)const;
-    typedef std::vector<double>::iterator IT;
+    double compute_knot(uint k) const;
+    using IT = std::vector<double>::iterator;
   };
 
   class Tn2Sampler {
     // implements adaptive rejection sampling for drawinf from the
     // truncated standard normal distribution with 0 < lo < x < hi
-    public:
+   public:
     Tn2Sampler(double lo, double hi);
     double draw(RNG &);
     void add_point(double x);
-    double f(double x)const;
-    double df(double x)const;
+    double f(double x) const;
+    double df(double x) const;
 
     // hull is the envelope distribution on the log scale
-    double hull(double x, uint k)const;
-    private:
+    double hull(double x, uint k) const;
+
+   private:
     // x contains the values of the points that have been tried.
     // initialized with lo and hi
     std::vector<double> x;
@@ -104,10 +107,10 @@ namespace BOOM {
     // integral of hull part i;
     std::vector<double> cdf;
 
-     void update_cdf();
-     void refresh_knots();
-     double compute_knot(uint k)const;
-     typedef std::vector<double>::iterator IT;
+    void update_cdf();
+    void refresh_knots();
+    double compute_knot(uint k) const;
+    using IT = std::vector<double>::iterator;
   };
 
   double trun_norm(double);
@@ -125,42 +128,65 @@ namespace BOOM {
   // Be aware that the standard deviation of the untruncated
   // distribution is input.  The variance of the truncated
   // distribution is output.
-  void trun_norm_moments(
-      double mu, double sigma, double cutpoint, bool positive_support,
-      double *mean, double *variance);
+  void trun_norm_moments(double mu, double sigma, double cutpoint,
+                         bool positive_support, double *mean, double *variance);
 
-  double rtrun_norm(double mu, double sigma,
-                    double cutpoint, bool positive_support = true);
-  double rtrun_norm_mt(RNG &, double mu, double sigma,
-                       double cutpoint, bool positive_support = true);
+  // Args:
+  //   mu:  Mean of the (untruncated) normal distribution.
+  //   sigma:  Standard deviation of the (untruncated) normal distribution.
+  //   cutpoint:  The point of truncation.
+  //   positive_support: If true, then draw a deviate from above the cutpoint.
+  //     If false then draw a deviate from below the cutpoint.
+  // Returns:
+  //   A draw from the truncated normal distribution.
+  double rtrun_norm(double mu, double sigma, double cutpoint,
+                    bool positive_support = true);
+  double rtrun_norm_mt(RNG &, double mu, double sigma, double cutpoint,
+                       bool positive_support = true);
 
-  double dtrun_norm(double, double, double, double,
-                    bool low=true, bool log=false);
-  double dtrun_norm_2(double, double, double, double, double, bool log=false);
+  double dtrun_norm(double, double, double, double, bool low = true,
+                    bool log = false);
+  double dtrun_norm_2(double, double, double, double, double, bool log = false);
 
   double rtrun_norm_2(double mu, double sig, double lo, double hi);
   double rtrun_norm_2_mt(RNG &, double mu, double sig, double lo, double hi);
 
-  double dstudent(double y, double mu, double sigma, double df, bool log=false);
+  double dstudent(double y, double mu, double sigma, double df,
+                  bool log = false);
   double rstudent(double mu, double sigma, double df);
-  double rstudent_mt(RNG & rng, double mu, double sigma, double df);
+  double rstudent_mt(RNG &rng, double mu, double sigma, double df);
 
-  double rtrun_exp_mt(RNG & rng, double lam, double lo, double hi);
+  double rtrun_exp_mt(RNG &rng, double lam, double lo, double hi);
   double rtrun_exp(double lam, double lo, double hi);
   double rpiecewise_log_linear_mt(RNG &rng, double slope, double lo, double hi);
 
-  double rlexp(double loglam);  // log E(lam).  loglam = log(lam)
-  double rlexp_mt(RNG & rng, double loglam);  // log E(lam).  loglam = log(lam)
+  double rlexp(double loglam);               // log E(lam).  loglam = log(lam)
+  double rlexp_mt(RNG &rng, double loglam);  // log E(lam).  loglam = log(lam)
 
-  // extreme value distribution with mean 'loc'
-  // and variance 'scale^2 * pi^2/6'
-  double dexv(double x, double loc = 0., double scale=1., bool log=false);
-  double rexv_mt(RNG & rng, double loc = 0., double scale=1.);
-  double rexv(double loc = 0., double scale=1.);
+  // extreme value distribution with centrality parameter 'mu + gamma', where
+  // gamma is Euler's constant -0.5772157... and variance 'sigma^2 * pi^2/6'.  
+
+  double pexv(double x, double mu = 0, double sigma = 1, bool logscale = false);
+  double dexv(double x, double mu = 0., double sigma = 1., bool logscale = false);
+  double rexv_mt(RNG &rng, double mu = 0., double sigma = 1.);
+  double rexv(double mu = 0., double sigma = 1.);
 
   // random integer uniform on lo to hi, inclusive
   int random_int(int lo, int hi);
-  int random_int_mt(RNG & rng, int lo, int hi);
+  int random_int_mt(RNG &rng, int lo, int hi);
+
+  // Returns an n-vector of independent normal deviates, each with mean mu and
+  // standard deviation sigma.
+  inline Vector rnorm_vector(int n, double mu, double sigma) {
+    if (n <= 0) {
+      return Vector(0);
+    }
+    Vector ans(n);
+    for (int i = 0; i < n; ++i) {
+      ans[i] = rnorm_mt(GlobalRng::rng, mu, sigma);
+    }
+    return ans;
+  }
 
   //======================================================================
   // Several varieties of multivariate normal generation.
@@ -168,21 +194,21 @@ namespace BOOM {
   // basic rmvn checks the cholesky decomposition, if there is a
   // problem it calls rmvn_robust
   Vector rmvn(const Vector &Mu, const SpdMatrix &Sigma);
-  Vector rmvn_mt(RNG & rng, const Vector &Mu, const SpdMatrix &Sigma);
+  Vector rmvn_mt(RNG &rng, const Vector &Mu, const SpdMatrix &Sigma);
 
   // rmvn_robust computes the spectral decomposition of Sigma which
   // can be done even if there is a zero pivot that would prevent the
   // Cholesky decomposition from working, so it can be used even if
   // Sigma is only positive semidefinite.
   Vector rmvn_robust(const Vector &Mu, const SpdMatrix &Sigma);
-  Vector rmvn_robust_mt(RNG & rng, const Vector &Mu, const SpdMatrix &Sigma);
+  Vector rmvn_robust_mt(RNG &rng, const Vector &Mu, const SpdMatrix &Sigma);
 
-  // Simulate given the lower cholesky triange of the variance matrix.
+  // Simulate given the lower cholesky triangle of the variance matrix.
   Vector rmvn_L(const Vector &mu, const Matrix &L);
-  Vector rmvn_L_mt(RNG & rng, const Vector &mu, const Matrix &L);
+  Vector rmvn_L_mt(RNG &rng, const Vector &mu, const Matrix &L);
 
   Vector rmvn_ivar(const Vector &Mu, const SpdMatrix &Sigma_Inverse);
-  Vector rmvn_ivar_mt(RNG & rng, const Vector &Mu, const SpdMatrix &precision);
+  Vector rmvn_ivar_mt(RNG &rng, const Vector &Mu, const SpdMatrix &precision);
 
   // Simulate using the upper cholesky triangle of the precision matrix.
   // Args:
@@ -194,15 +220,13 @@ namespace BOOM {
   //   A draw from the N(mu, Sigma) distribution, where Sigma^{-1} = L * L',
   //   with L' = precision_upper_cholesky.
   Vector rmvn_precision_upper_cholesky_mt(
-      RNG & rng,
-      const Vector &mean,
-      const Matrix &precision_upper_cholesky);
+      RNG &rng, const Vector &mean, const Matrix &precision_upper_cholesky);
 
   // Simulate given the precision matrix, and the precision matrix
   // times the mean.  This form arises frequently in Bayesian
   // inference.
-  Vector rmvn_suf(const SpdMatrix & Ivar, const Vector & IvarMu);
-  Vector rmvn_suf_mt(RNG & rng, const SpdMatrix & Ivar, const Vector & IvarMu);
+  Vector rmvn_suf(const SpdMatrix &Ivar, const Vector &IvarMu);
+  Vector rmvn_suf_mt(RNG &rng, const SpdMatrix &Ivar, const Vector &IvarMu);
 
   //======================================================================
   // Evaluates the multivariate normal density function.
@@ -218,17 +242,17 @@ namespace BOOM {
   //   location.
   double dmvn(const Vector &y, const Vector &mu, const SpdMatrix &Siginv,
               double ldsi, bool logscale);
-  double dmvn_zero_mean(const Vector &y, const SpdMatrix &Siginv,
-                        double ldsi, bool logscale);
+  double dmvn_zero_mean(const Vector &y, const SpdMatrix &Siginv, double ldsi,
+                        bool logscale);
   double dmvn(const Vector &y, const Vector &mu, const SpdMatrix &Siginv,
               bool logscale);
 
   // Y~ matrix_normal(Mu, Siginv, Ominv) if
   // Vector(Y) ~ N(Vector(Mu), (Siginv \otimes Ominv)^{-1})
 
-  Matrix rmatrix_normal_ivar(const Matrix & Mu, const SpdMatrix &Siginv,
+  Matrix rmatrix_normal_ivar(const Matrix &Mu, const SpdMatrix &Siginv,
                              const SpdMatrix &Ominv);
-  Matrix rmatrix_normal_ivar_mt(RNG & rng, const Matrix & Mu,
+  Matrix rmatrix_normal_ivar_mt(RNG &rng, const Matrix &Mu,
                                 const SpdMatrix &Siginv,
                                 const SpdMatrix &Ominv);
   double dmatrix_normal_ivar(const Matrix &Y, const Matrix &Mu,
@@ -245,61 +269,46 @@ namespace BOOM {
   double qusp(double p, double z0);
 
   double rusp(double z0);
-  double rusp_mt(RNG & rng, double z0);
+  double rusp_mt(RNG &rng, double z0);
 
   //  SpdMatrix rWish( double,  SpdMatrix &);
-  SpdMatrix rWish(double df, const SpdMatrix &sumsq_inv, bool inv=false);
+  SpdMatrix rWish(double df, const SpdMatrix &sumsq_inv, bool inv = false);
   SpdMatrix rWish_mt(RNG &, double df, const SpdMatrix &sumsq_inv,
-                     bool inv=false);
+                     bool inv = false);
   SpdMatrix rWishChol(double df, const Matrix &sumsq_upper_chol,
-                      bool inv=false);
+                      bool inv = false);
   SpdMatrix rWishChol_mt(RNG &, double df, const Matrix &sumsq_upper_chol,
-                         bool inv=false);
+                         bool inv = false);
   double dWish(const SpdMatrix &S, const SpdMatrix &sumsq, double df,
-               bool logscale,
-               bool inv=false);
-  inline double dWishinv(
-      const SpdMatrix &S, const SpdMatrix &sumsq, double df, bool logscale) {
-    return dWish(S, sumsq, df, logscale, true); }
+               bool logscale, bool inv = false);
+  inline double dWishinv(const SpdMatrix &S, const SpdMatrix &sumsq, double df,
+                         bool logscale) {
+    return dWish(S, sumsq, df, logscale, true);
+  }
 
-  double ddirichlet(const Vector & x,
-                    const Vector & nu,
+  double ddirichlet(const Vector &x, const Vector &nu, bool logscale);
+  double ddirichlet(const VectorView &x, const Vector &nu, bool logscale);
+  double ddirichlet(const Vector &x, const VectorView &nu, bool logscale);
+  double ddirichlet(const VectorView &x, const VectorView &nu, bool logscale);
+  double ddirichlet(const Vector &x, const ConstVectorView &nu, bool logscale);
+  double ddirichlet(const ConstVectorView &x, const Vector &nu, bool logscale);
+  double ddirichlet(const ConstVectorView &x, const ConstVectorView &nu,
                     bool logscale);
-  double ddirichlet(const VectorView & x,
-                    const Vector & nu,
+  double ddirichlet(const VectorView &x, const ConstVectorView &nu,
                     bool logscale);
-  double ddirichlet(const Vector & x,
-                    const VectorView & nu,
-                    bool logscale);
-  double ddirichlet(const VectorView & x,
-                    const VectorView & nu,
-                    bool logscale);
-  double ddirichlet(const Vector & x,
-                    const ConstVectorView & nu,
-                    bool logscale);
-  double ddirichlet(const ConstVectorView & x,
-                    const Vector & nu,
-                    bool logscale);
-  double ddirichlet(const ConstVectorView & x,
-                    const ConstVectorView & nu,
-                    bool logscale);
-  double ddirichlet(const VectorView & x,
-                    const ConstVectorView & nu,
-                    bool logscale);
-  double ddirichlet(const ConstVectorView & x,
-                    const VectorView & nu,
+  double ddirichlet(const ConstVectorView &x, const VectorView &nu,
                     bool logscale);
 
   Vector mdirichlet(const Vector &nu);
   double dirichlet_loglike(const Vector &nu, Vector *g, Matrix *h,
-                           const Vector & sumlogpi, double nobs);
+                           const Vector &sumlogpi, double nobs);
 
-  Vector rdirichlet(const Vector & nu);
-  Vector rdirichlet_mt(RNG &rng, const Vector & nu);
-  Vector rdirichlet(const VectorView & nu);
-  Vector rdirichlet_mt(RNG &rng, const VectorView & nu);
-  Vector rdirichlet(const ConstVectorView & nu);
-  Vector rdirichlet_mt(RNG &rng, const ConstVectorView & nu);
+  Vector rdirichlet(const Vector &nu);
+  Vector rdirichlet_mt(RNG &rng, const Vector &nu);
+  Vector rdirichlet(const VectorView &nu);
+  Vector rdirichlet_mt(RNG &rng, const VectorView &nu);
+  Vector rdirichlet(const ConstVectorView &nu);
+  Vector rdirichlet_mt(RNG &rng, const ConstVectorView &nu);
 
   uint rmulti(const Vector &);
   uint rmulti(const VectorView &);
@@ -311,9 +320,9 @@ namespace BOOM {
   int rmulti(int, int);
   int rmulti_mt(RNG &, int, int);
 
-  double dmvt(const Vector &x,  const Vector &mu, const SpdMatrix &Siginv,
+  double dmvt(const Vector &x, const Vector &mu, const SpdMatrix &Siginv,
               double nu, double ldsi, bool logscale);
-  double dmvt(const Vector &x,  const Vector &mu, const SpdMatrix &Siginv,
+  double dmvt(const Vector &x, const Vector &mu, const SpdMatrix &Siginv,
               double nu, bool logscale);
 
   Vector rmvt(const Vector &mu, const SpdMatrix &Sigma, double nu);
