@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -18,12 +19,12 @@
 #ifndef BOOM_FREQ_DIST_HPP
 #define BOOM_FREQ_DIST_HPP
 
-#include <vector>
 #include <string>
-#include <uint.hpp>
-#include <LinAlg/Vector.hpp>
+#include <vector>
+#include "LinAlg/Vector.hpp"
+#include "uint.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   // A frequency distribution for categorical data.
   class FrequencyDistribution {
@@ -31,31 +32,43 @@ namespace BOOM{
     // Overloaded constructors for various integral types.
     // Args:
     //   y:  A vector of categorical data to be tabulated.
-    //   contiguous: If true, then all the values between the smallest
-    //     and largest values in y will be included (with zero counts
-    //     if they did not appear in y).  If false, then values that
-    //     did not appear in y will be skipped.
-    FrequencyDistribution(const std::vector<uint> &y,
-                          bool contiguous = false);
-    FrequencyDistribution(const std::vector<int> &y,
-                          bool contiguous = false);
-    FrequencyDistribution(const std::vector<unsigned long> &y,
-                          bool contiguous = false);
+    //   contiguous: If true, then all the values between the smallest and
+    //     largest values in y will be included (with zero counts if they did
+    //     not appear in y).  If false, then values that did not appear in y
+    //     will be skipped.
+    explicit FrequencyDistribution(const std::vector<uint> &y, bool contiguous = false);
+    explicit FrequencyDistribution(const std::vector<int> &y, bool contiguous = false);
+    explicit FrequencyDistribution(const std::vector<unsigned long> &y,
+                                   bool contiguous = false);
 
     // Set the category labels for the unique values in y.
     void set_labels(const std::vector<std::string> &labels);
-    const std::vector<std::string> & labels() const {return labs_;}
+    const std::vector<std::string> &labels() const { return labs_; }
 
     // Count the frequency of each value in y.
-    const std::vector<int> & counts() const {return counts_;}
+    const std::vector<int> &counts() const { return counts_; }
+
     Vector relative_frequencies() const {
       Vector ans(counts_);
       double normalizing_constant = sum(ans);
-      if (normalizing_constant == 0.0) return ans;
-      else return ans / normalizing_constant;
+      if (normalizing_constant == 0.0)
+        return ans;
+      else
+        return ans / normalizing_constant;
     }
 
-    std::ostream & print(std::ostream &out)const;
+    std::ostream &print(std::ostream &out) const;
+
+    // Returns the label corresponding to the largest count.  If two or more
+    // levels tie then the first mode is reported.
+    std::string mode() const;
+
+    // Returns the count corresponding to a particular label.  Implemented using
+    // linear search, so use this with care if the number of distinct labels is
+    // large.
+    //
+    // Returns 0 if the label was not found.
+    int count(const std::string &label) const;
 
    private:
     std::vector<std::string> labs_;
@@ -75,11 +88,10 @@ namespace BOOM{
     //
     // The constructor will sort the cutpoints, then count how many
     // times each cutpoints[i] < x <= cutpoints[i+1].
-    BucketedFrequencyDistribution(const Vector &x,
-                                  const Vector &cutpoints);
+    BucketedFrequencyDistribution(const Vector &x, const Vector &cutpoints);
 
     // The vector of counts is one larger than the vector of cutpoints.
-    const Vector &cutpoints() const {return cutpoints_;}
+    const Vector &cutpoints() const { return cutpoints_; }
 
    private:
     Vector cutpoints_;
@@ -87,10 +99,10 @@ namespace BOOM{
     std::vector<std::string> create_labels() const;
   };
 
-  inline std::ostream & operator<<(std::ostream &out,
-                                   const FrequencyDistribution &f){
+  inline std::ostream &operator<<(std::ostream &out,
+                                  const FrequencyDistribution &f) {
     return f.print(out);
   }
 
 }  // namespace BOOM
-#endif// BOOM_FREQ_DIST_HPP
+#endif  // BOOM_FREQ_DIST_HPP
