@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -15,29 +16,29 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <LinAlg/Kronecker.hpp>
+#include "LinAlg/Kronecker.hpp"
 
-namespace BOOM{
-  Matrix Kronecker(const Matrix &A, const Matrix &B){
+namespace BOOM {
+  Matrix Kronecker(const Matrix &A, const Matrix &B) {
     uint nra = A.nrow();
     uint nca = A.ncol();
 
-    Matrix tmp = A(0,0)*B;
+    Matrix tmp = A(0, 0) * B;
     Matrix ans(tmp);
-    for(uint j=1; j<nca; ++j){
-      tmp = A(0,j)*B;
-      ans = cbind(ans,tmp);
+    for (uint j = 1; j < nca; ++j) {
+      tmp = A(0, j) * B;
+      ans = cbind(ans, tmp);
     }
 
-    for(uint i=1; i<nra; ++i){
-      tmp = A(i,0)*B;
+    for (uint i = 1; i < nra; ++i) {
+      tmp = A(i, 0) * B;
       Matrix row(tmp);
-      for(uint j = 1; j<nca; ++j){
-        tmp = A(i,j)*B;
+      for (uint j = 1; j < nca; ++j) {
+        tmp = A(i, j) * B;
         row = cbind(row, tmp);
       }
-      ans = rbind(ans,row);
+      ans = rbind(ans, row);
     }
     return ans;
   }
-}
+}  // namespace BOOM
