@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -16,30 +17,29 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <LinAlg/LinAlgExceptions.hpp>
-#include <string>
+#include "LinAlg/LinAlgExceptions.hpp"
 #include <sstream>
+#include <string>
 
-namespace BOOM{
+namespace BOOM {
   using namespace std;
   using std::string;
-  matrix_not_positive_definite::matrix_not_positive_definite
-  (const Matrix &M, const string &err_msg)
-      : m(M), msg(err_msg)
-  {}
+  matrix_not_positive_definite::matrix_not_positive_definite(
+      const Matrix &M, const string &err_msg)
+      : m(M), msg(err_msg) {}
 
-  string print_matrix_limits(const Matrix &m, const string &name=""){
+  string print_matrix_limits(const Matrix &m, const string &name = "") {
     ostringstream out;
     out << name << "[" << m.nrow() << "," << m.ncol() << "] = " << std::endl
         << m << std::endl;
     return out.str();
   }
 
-  const char * matrix_not_positive_definite::what()const throw(){
+  const char *matrix_not_positive_definite::what() const throw() {
     ostringstream out;
     out << msg << std::endl;
     out << print_matrix_limits(m);
     return out.str().c_str();
   }
 
-}
+}  // namespace BOOM
