@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -16,36 +17,33 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/CompositeData.hpp>
+#include "Models/CompositeData.hpp"
 
-namespace BOOM{
+#include <utility>
 
-  CompositeData::CompositeData() {}
+namespace BOOM {
 
-  CompositeData::CompositeData(const std::vector<Ptr<Data> > &d)
-    : dat_(d)
-  {}
+  CompositeData::CompositeData() = default;
 
-  CompositeData * CompositeData::clone()const{
-    return new CompositeData(*this);}
+  CompositeData::CompositeData(const std::vector<Ptr<Data>> &d) : dat_(d) {}
 
-  ostream & CompositeData::display(ostream &out)const{
+  CompositeData *CompositeData::clone() const {
+    return new CompositeData(*this);
+  }
+
+  ostream &CompositeData::display(ostream &out) const {
     uint n = dat_.size();
-    for(uint i=0; i<n; ++i) dat_[i]->display(out) << " ";
+    for (uint i = 0; i < n; ++i) {
+      dat_[i]->display(out) << " ";
+    }
     return out;
   }
 
-  void CompositeData::add(Ptr<Data> dp){
-    dat_.push_back(dp);
-  }
+  void CompositeData::add(const Ptr<Data> &dp) { dat_.push_back(dp); }
 
-  uint CompositeData::dim()const{ return dat_.size();}
+  uint CompositeData::dim() const { return dat_.size(); }
 
-  Ptr<Data> CompositeData::get_ptr(uint i){
-    return dat_[i];
-  }
+  Ptr<Data> CompositeData::get_ptr(uint i) { return dat_[i]; }
 
-  const Data * CompositeData::get(uint i)const{
-    return dat_[i].get();
-  }
-}
+  const Data *CompositeData::get(uint i) const { return dat_[i].get(); }
+}  // namespace BOOM
