@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2012 Steven L. Scott
 
@@ -16,47 +17,45 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/PoissonRegressionModel.hpp>
-#include <numopt/initialize_derivatives.hpp>
-#include <TargetFun/TargetFun.hpp>
+#include "Models/Glm/PoissonRegressionModel.hpp"
 #include <functional>
-#include <cpputil/report_error.hpp>
-#include <distributions.hpp>
-#include <numopt.hpp>
+#include "TargetFun/TargetFun.hpp"
+#include "cpputil/report_error.hpp"
+#include "distributions.hpp"
+#include "numopt.hpp"
+#include "numopt/initialize_derivatives.hpp"
 
 namespace BOOM {
 
   PoissonRegressionModel::PoissonRegressionModel(int xdim)
-      : ParamPolicy(new GlmCoefs(xdim))
-  {}
+      : ParamPolicy(new GlmCoefs(xdim)) {}
 
   PoissonRegressionModel::PoissonRegressionModel(const Vector &beta)
-      : ParamPolicy(new GlmCoefs(beta))
-  {}
+      : ParamPolicy(new GlmCoefs(beta)) {}
 
-  PoissonRegressionModel::PoissonRegressionModel(const Ptr<GlmCoefs> beta)
-      : ParamPolicy(beta)
-  {}
+  PoissonRegressionModel::PoissonRegressionModel(const Ptr<GlmCoefs> &beta)
+      : ParamPolicy(beta) {}
 
-  PoissonRegressionModel * PoissonRegressionModel::clone()const{
-    return new PoissonRegressionModel(*this);}
-
-  GlmCoefs & PoissonRegressionModel::coef(){
-    return ParamPolicy::prm_ref();
+  PoissonRegressionModel *PoissonRegressionModel::clone() const {
+    return new PoissonRegressionModel(*this);
   }
-  const GlmCoefs & PoissonRegressionModel::coef()const{
+
+  GlmCoefs &PoissonRegressionModel::coef() { return ParamPolicy::prm_ref(); }
+  const GlmCoefs &PoissonRegressionModel::coef() const {
     return ParamPolicy::prm_ref();
   }
 
-  Ptr<GlmCoefs> PoissonRegressionModel::coef_prm(){
-    return ParamPolicy::prm();}
+  Ptr<GlmCoefs> PoissonRegressionModel::coef_prm() {
+    return ParamPolicy::prm();
+  }
 
-  const Ptr<GlmCoefs> PoissonRegressionModel::coef_prm()const{
-    return ParamPolicy::prm();}
+  const Ptr<GlmCoefs> PoissonRegressionModel::coef_prm() const {
+    return ParamPolicy::prm();
+  }
 
-
-  double PoissonRegressionModel::log_likelihood(
-      const Vector &beta, Vector *g, Matrix *h, bool reset_derivatives)const{
+  double PoissonRegressionModel::log_likelihood(const Vector &beta, Vector *g,
+                                                Matrix *h,
+                                                bool reset_derivatives) const {
     // L = (E *lambda)^y exp(-E*lambda)
     //   ell = y * (log(E) + log(lambda)) - E*exp(x * beta)
     //       = yXbeta - E*exp(Xbeta)
@@ -75,7 +74,7 @@ namespace BOOM {
     }
     initialize_derivatives(g, h, nvars, reset_derivatives);
 
-    for(int i = 0; i < data.size(); ++i){
+    for (int i = 0; i < data.size(); ++i) {
       const Vector x = included.select(data[i]->x());
       int64_t y = data[i]->y();
       double lambda = 1.0;
@@ -95,8 +94,8 @@ namespace BOOM {
     return ans;
   }
 
-  double PoissonRegressionModel::Loglike(const Vector &beta,
-                                         Vector &g, Matrix &h, uint nd)const{
+  double PoissonRegressionModel::Loglike(const Vector &beta, Vector &g,
+                                         Matrix &h, uint nd) const {
     Vector *gp = NULL;
     Matrix *hp = NULL;
     if (nd > 0) gp = &g;
@@ -107,29 +106,23 @@ namespace BOOM {
   void PoissonRegressionModel::mle() {
     Vector beta = included_coefficients();
     d2TargetFunPointerAdapter target(
-        [this](const Vector &x, Vector *gradient,
-               Matrix *hessian, bool reset) {
-          return this->log_likelihood(x, gradient, hessian, reset);});
+        [this](const Vector &x, Vector *gradient, Matrix *hessian, bool reset) {
+          return this->log_likelihood(x, gradient, hessian, reset);
+        });
     Vector gradient;
     Matrix hessian;
     double function_value;
     std::string error_message;
-    bool ok = max_nd2_careful(beta,
-                              gradient,
-                              hessian,
-                              function_value,
-                              Target(target),
-                              dTarget(target),
-                              d2Target(target),
-                              1e-5,
-                              error_message);
+    bool ok =
+        max_nd2_careful(beta, gradient, hessian, function_value, Target(target),
+                        dTarget(target), d2Target(target), 1e-5, error_message);
     if (!ok) {
       beta = 0;
     }
     set_included_coefficients(beta);
   }
 
-  double PoissonRegressionModel::pdf(const Data *dp, bool logscale)const{
+  double PoissonRegressionModel::pdf(const Data *dp, bool logscale) const {
     // const PoissonRegressionData *d(
     //     dynamic_cast<const PoissonRegressionData *>(dp));
     const PoissonRegressionData *d(DAT(dp));
@@ -137,9 +130,9 @@ namespace BOOM {
     return logscale ? ans : exp(ans);
   }
 
-  double PoissonRegressionModel::logp(const PoissonRegressionData &data)const{
+  double PoissonRegressionModel::logp(const PoissonRegressionData &data) const {
     double lambda = exp(predict(data.x()));
     return dpois(data.y(), data.exposure() * lambda, true);
   }
 
-} // namespace BOOM
+}  // namespace BOOM
