@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2010 Steven L. Scott
 
@@ -15,44 +16,42 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/Glm/PosteriorSamplers/BinomialLogitSpikeSlabSampler.hpp>
-#include <cpputil/seq.hpp>
-#include <LinAlg/Cholesky.hpp>
-#include <distributions.hpp>
-#include <cpputil/math_utils.hpp>
+#include "Models/Glm/PosteriorSamplers/BinomialLogitSpikeSlabSampler.hpp"
+#include "LinAlg/Cholesky.hpp"
+#include "cpputil/math_utils.hpp"
+#include "cpputil/seq.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
   typedef BinomialLogitSpikeSlabSampler BLSSS;
 
-  BLSSS::BinomialLogitSpikeSlabSampler(BinomialLogitModel *m,
-                                       Ptr<MvnBase> pri,
-                                       Ptr<VariableSelectionPrior> vpri,
-                                       int clt_threshold,
-                                       RNG &seeding_rng)
-      : BinomialLogitAuxmixSampler(m, pri, clt_threshold, seeding_rng),
-        m_(m),
-        pri_(pri),
-        vpri_(vpri),
+  BLSSS::BinomialLogitSpikeSlabSampler(BinomialLogitModel *model,
+                                       const Ptr<MvnBase> &slab,
+                                       const Ptr<VariableSelectionPrior> &spike,
+                                       int clt_threshold, RNG &seeding_rng)
+      : BinomialLogitAuxmixSampler(model, slab, clt_threshold, seeding_rng),
+        model_(model),
+        slab_(check_slab_dimension(slab)),
+        spike_(check_spike_dimension(spike)),
         allow_model_selection_(true),
         max_flips_(-1),
         posterior_mode_found_(false),
-        log_posterior_at_mode_(negative_infinity())
-  {}
+        log_posterior_at_mode_(negative_infinity()) {}
 
   void BLSSS::draw() {
     impute_latent_data();
-    if(allow_model_selection_) draw_model_indicators();
+    if (allow_model_selection_) draw_model_indicators();
     draw_beta();
   }
 
   void BLSSS::draw_beta() {
-    Selector g = m_->coef().inc();
-    if(g.nvars() == 0) {
-      m_->drop_all();
+    Selector g = model_->coef().inc();
+    if (g.nvars() == 0) {
+      model_->drop_all();
       return;
     }
-    SpdMatrix precision = g.select(pri_->siginv());
-    Vector scaled_mean = precision * g.select(pri_->mu());
+    SpdMatrix precision = g.select(slab_->siginv());
+    Vector scaled_mean = precision * g.select(slab_->mu());
     precision += g.select(suf().xtx());
     Chol precision_cholesky_factor(precision);
     scaled_mean += g.select(suf().xty());
@@ -63,26 +62,24 @@ namespace BOOM{
     // If model selection is turned off and some elements of beta
     // happen to be zero (because, e.g., of a failed MH step) we don't
     // want the dimension of beta to change.
-    m_->set_included_coefficients(beta, g);
+    model_->set_included_coefficients(beta, g);
   }
 
-  double BLSSS::logpri()const{
-    const Selector & g(m_->coef().inc());
-    double ans = vpri_->logp(g);  // p(gamma)
-    if(ans == BOOM::negative_infinity()) return ans;
-    if(g.nvars() > 0) {
-      ans += dmvn(m_->included_coefficients(),
-                  g.select(pri_->mu()),
-                  g.select(pri_->siginv()),
-                  true);
+  double BLSSS::logpri() const {
+    const Selector &g(model_->coef().inc());
+    double ans = spike_->logp(g);  // p(gamma)
+    if (ans == BOOM::negative_infinity()) return ans;
+    if (g.nvars() > 0) {
+      ans += dmvn(model_->included_coefficients(), g.select(slab_->mu()),
+                  g.select(slab_->siginv()), true);
     }
     return ans;
   }
 
-  double BLSSS::log_model_prob(const Selector &g)const{
+  double BLSSS::log_model_prob(const Selector &g) const {
     // borrowed from MLVS.cpp
-    double num = vpri_->logp(g);
-    if(num==BOOM::negative_infinity() || g.nvars() == 0) {
+    double num = spike_->logp(g);
+    if (num == BOOM::negative_infinity() || g.nvars() == 0) {
       // If num == -infinity then it is in a zero support point in the
       // prior.  If g.nvars()==0 then all coefficients are zero
       // because of the point mass.  The only entries remaining in the
@@ -91,57 +88,43 @@ namespace BOOM{
       // in the non-empty case below.
       return num;
     }
-    SpdMatrix ivar = g.select(pri_->siginv());
-    num += .5*ivar.logdet();
-    if(num == BOOM::negative_infinity()) return num;
+    SpdMatrix ivar = g.select(slab_->siginv());
+    num += .5 * ivar.logdet();
+    if (num == BOOM::negative_infinity()) return num;
 
-    Vector mu = g.select(pri_->mu());
+    Vector mu = g.select(slab_->mu());
     Vector ivar_mu = ivar * mu;
-    num -= .5*mu.dot(ivar_mu);
+    num -= .5 * mu.dot(ivar_mu);
 
-    bool ok=true;
+    bool ok = true;
     ivar += g.select(suf().xtx());
     Matrix L = ivar.chol(ok);
-    if(!ok)  return BOOM::negative_infinity();
+    if (!ok) return BOOM::negative_infinity();
     double denom = sum(log(L.diag()));  // = .5 log |ivar|
     Vector S = g.select(suf().xty()) + ivar_mu;
-    Lsolve_inplace(L,S);
-    denom-= .5*S.normsq();  // S.normsq =  beta_tilde ^T V_tilde beta_tilde
-    return num-denom;
+    Lsolve_inplace(L, S);
+    denom -= .5 * S.normsq();  // S.normsq =  beta_tilde ^T V_tilde beta_tilde
+    return num - denom;
   }
 
-  void BLSSS::allow_model_selection(bool tf) {
-    allow_model_selection_ = tf;
-  }
+  void BLSSS::allow_model_selection(bool tf) { allow_model_selection_ = tf; }
 
-  void BLSSS::limit_model_selection(int max_flips) {
-    max_flips_ = max_flips;
-  }
+  void BLSSS::limit_model_selection(int max_flips) { max_flips_ = max_flips; }
 
-  class BinomialLogitUnNormalizedLogPosterior
-      : public d2TargetFun {
+  class BinomialLogitUnNormalizedLogPosterior : public d2TargetFun {
    public:
     BinomialLogitUnNormalizedLogPosterior(BinomialLogitModel *model,
                                           MvnBase *prior)
-        : model_(model),
-          prior_(prior)
-    {}
+        : model_(model), prior_(prior) {}
 
-    double operator()(const Vector &included_coefficients,
-                      Vector &gradient,
-                      Matrix &hessian,
-                      uint nd) const {
+    double operator()(const Vector &included_coefficients, Vector &gradient,
+                      Matrix &hessian, uint nd) const {
       double ans = prior_->logp_given_inclusion(
-          included_coefficients,
-          nd > 0 ? &gradient : nullptr,
-          nd > 1 ? &hessian : nullptr,
-          model_->coef().inc(),
-          true);
-      ans += model_->log_likelihood(
-          included_coefficients,
-          nd > 0 ? &gradient : nullptr,
-          nd > 1 ? &hessian : nullptr,
-          false);
+          included_coefficients, nd > 0 ? &gradient : nullptr,
+          nd > 1 ? &hessian : nullptr, model_->coef().inc(), true);
+      ans += model_->log_likelihood(included_coefficients,
+                                    nd > 0 ? &gradient : nullptr,
+                                    nd > 1 ? &hessian : nullptr, false);
       return ans;
     }
     using d2TargetFun::operator();
@@ -156,9 +139,9 @@ namespace BOOM{
     posterior_mode_found_ = false;
     log_posterior_at_mode_ = negative_infinity();
     try {
-      BinomialLogitUnNormalizedLogPosterior logpost(m_, pri_.get());
-      const Selector &inc(m_->coef().inc());
-      Vector beta(m_->included_coefficients());
+      BinomialLogitUnNormalizedLogPosterior logpost(model_, slab_.get());
+      const Selector &inc(model_->coef().inc());
+      Vector beta(model_->included_coefficients());
       int dim = beta.size();
       if (dim == 0) {
         return;
@@ -169,32 +152,26 @@ namespace BOOM{
         Vector gradient(dim);
         Matrix hessian(dim, dim);
         std::string error_message;
-        bool ok = max_nd2_careful(beta,
-                                  gradient,
-                                  hessian,
-                                  log_posterior_at_mode_,
-                                  Target(logpost),
-                                  dTarget(logpost),
-                                  d2Target(logpost),
-                                  epsilon,
-                                  error_message);
+        bool ok = max_nd2_careful(
+            beta, gradient, hessian, log_posterior_at_mode_, Target(logpost),
+            dTarget(logpost), d2Target(logpost), epsilon, error_message);
         if (ok) {
           posterior_mode_found_ = true;
-          m_->set_included_coefficients(beta, inc);
+          model_->set_included_coefficients(beta, inc);
           return;
         } else {
           log_posterior_at_mode_ = negative_infinity();
           return;
         }
       }
-    } catch(...) {
+    } catch (...) {
       return;
     }
   }
 
   void BLSSS::draw_model_indicators() {
-    Selector g = m_->coef().inc();
-    std::vector<int> indx = seq<int>(0, g.nvars_possible()-1);
+    Selector g = model_->coef().inc();
+    std::vector<int> indx = seq<int>(0, g.nvars_possible() - 1);
     // I'd like to rely on std::random_shuffle for this, but I want
     // control over the random number generator.
     for (int i = 0; i < indx.size(); ++i) {
@@ -204,36 +181,51 @@ namespace BOOM{
 
     double logp = log_model_prob(g);
 
-    if(!std::isfinite(logp)) {
-      vpri_->make_valid(g);
+    if (!std::isfinite(logp)) {
+      spike_->make_valid(g);
       logp = log_model_prob(g);
     }
-    if(!std::isfinite(logp)) {
+    if (!std::isfinite(logp)) {
       ostringstream err;
       err << "BinomialLogitSpikeSlabSampler did not start with a "
-          << "legal configuration."
-          << endl << "Selector vector:  " << g << endl
-          << "beta: " << m_->included_coefficients() << endl;
+          << "legal configuration." << endl
+          << "Selector vector:  " << g << endl
+          << "beta: " << model_->included_coefficients() << endl;
       report_error(err.str());
     }
 
     uint n = g.nvars_possible();
-    if(max_flips_ > 0) n = std::min<int>(n, max_flips_);
-    for(uint i=0; i<n; ++i) {
+    if (max_flips_ > 0) n = std::min<int>(n, max_flips_);
+    for (uint i = 0; i < n; ++i) {
       logp = mcmc_one_flip(g, indx[i], logp);
     }
-    m_->coef().set_inc(g);
+    model_->coef().set_inc(g);
   }
 
   double BLSSS::mcmc_one_flip(Selector &mod, uint which_var, double logp_old) {
     mod.flip(which_var);
     double logp_new = log_model_prob(mod);
-    double u = runif_mt(rng(), 0,1);
-    if(log(u) > logp_new - logp_old) {
+    double u = runif_mt(rng(), 0, 1);
+    if (log(u) > logp_new - logp_old) {
       mod.flip(which_var);  // reject draw
       return logp_old;
     }
     return logp_new;
   }
 
+  const Ptr<MvnBase> &BLSSS::check_slab_dimension(const Ptr<MvnBase> &slab) {
+    if (slab->dim() != model_->xdim()) {
+      report_error("Slab does not match model dimension.");
+    }
+    return slab;
+  }
+
+  const Ptr<VariableSelectionPrior> &BLSSS::check_spike_dimension(
+      const Ptr<VariableSelectionPrior> &spike) {
+    if (spike->potential_nvars() != model_->xdim()) {
+      report_error("Spike does not match model dimension.");
+    }
+    return spike;
+  }
+
 }  // namespace BOOM
