@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -16,55 +17,51 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/PosteriorSamplers/MLVS_data_imputer.hpp>
+#include "Models/Glm/PosteriorSamplers/MLVS_data_imputer.hpp"
 
-#include <cpputil/math_utils.hpp>
-#include <cpputil/lse.hpp>
+#include "cpputil/lse.hpp"
+#include "cpputil/math_utils.hpp"
 
-#include <stats/logit.hpp>
+#include "stats/logit.hpp"
 
-#include <distributions.hpp>
 #include <cmath>
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  MlvsDataImputer::MlvsDataImputer(
-      SufficientStatistics &global_suf,
-      std::mutex &global_suf_mutex,
-      MultinomialLogitModel *model,
-      RNG *rng,
-      RNG &seeding_rng)
-      : SufstatImputeWorker<ChoiceData, SufficientStatistics> (
+  MlvsDataImputer::MlvsDataImputer(SufficientStatistics &global_suf,
+                                   std::mutex &global_suf_mutex,
+                                   MultinomialLogitModel *model, RNG *rng,
+                                   RNG &seeding_rng)
+      : SufstatImputeWorker<ChoiceData, SufficientStatistics>(
             global_suf, global_suf_mutex, rng, seeding_rng),
         model_(model),
         mu_(Vector("5.09 3.29 1.82 1.24 0.76 0.39 0.04 -0.31 -0.67  -1.06")),
-        sigsq_inv_(pow(Vector(
-            "4.5 2.02 1.1 0.42 0.2 0.11 0.08 0.08 0.09 0.15"),-1)),
-        sd_(pow(sigsq_inv_,-0.5)),
+        sigsq_inv_(
+            pow(Vector("4.5 2.02 1.1 0.42 0.2 0.11 0.08 0.08 0.09 0.15"), -1)),
+        sd_(pow(sigsq_inv_, -0.5)),
         log_mixing_weights_(log(Vector(
             "0.004 0.04 0.168 0.147 0.125 0.101 0.104 0.116 0.107 0.088"))),
         log_sampling_probs_(model_->log_sampling_probs()),
-        downsampling_ (log_sampling_probs_.size() == model_->Nchoices()),
-        post_prob_ (log_mixing_weights_),
+        downsampling_(log_sampling_probs_.size() == model_->Nchoices()),
+        post_prob_(log_mixing_weights_),
         u(model_->Nchoices()),
         eta(u),
-        wgts(u)
-  {}
+        wgts(u) {}
 
-  void MlvsDataImputer::impute_latent_data_point(
-      const ChoiceData &dp,
-      SufficientStatistics *suf,
-      RNG &rng) {
-    model_->fill_eta(dp, eta);      // eta+= downsampling_logprob
-    if(downsampling_) eta += log_sampling_probs_;  //
+  void MlvsDataImputer::impute_latent_data_point(const ChoiceData &dp,
+                                                 SufficientStatistics *suf,
+                                                 RNG &rng) {
+    model_->fill_eta(dp, eta);  // eta+= downsampling_logprob
+    if (downsampling_) eta += log_sampling_probs_;  //
     uint M = model_->Nchoices();
     uint y = dp.value();
     assert(y < M);
     double loglam = lse(eta);
     double logzmin = rlexp_mt(rng, loglam);
-    u[y] = - logzmin;
-    for (uint m=0; m<M; ++m) {
-      if(m!=y){
+    u[y] = -logzmin;
+    for (uint m = 0; m < M; ++m) {
+      if (m != y) {
         double tmp = rlexp_mt(rng, eta[m]);
         double logz = lse2(logzmin, tmp);
         u[m] = -logz;
@@ -79,11 +76,10 @@ namespace BOOM{
   //----------------------------------------------------------------------
   uint MlvsDataImputer::unmix(RNG &rng, double u) const {
     uint K = post_prob_.size();
-    for(uint k=0; k<K; ++k)
-      post_prob_[k] = log_mixing_weights_[k] +
-          dnorm(u, mu_[k], sd_[k], true);
+    for (uint k = 0; k < K; ++k)
+      post_prob_[k] = log_mixing_weights_[k] + dnorm(u, mu_[k], sd_[k], true);
     post_prob_.normalize_logprob();
     return rmulti_mt(rng, post_prob_);
   }
 
-} // namespace BOOM
+}  // namespace BOOM
