@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2013 Steven L. Scott
 
@@ -16,40 +17,37 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Hierarchical/HierarchicalPoissonModel.hpp>
+#include "Models/Hierarchical/HierarchicalPoissonModel.hpp"
 
 namespace BOOM {
 
-  HierarchicalPoissonData::HierarchicalPoissonData(
-      double event_count, double exposure)
-      : event_count_(event_count),
-        exposure_(exposure)
-  {}
+  HierarchicalPoissonData::HierarchicalPoissonData(double event_count,
+                                                   double exposure)
+      : event_count_(event_count), exposure_(exposure) {}
 
-  HierarchicalPoissonData * HierarchicalPoissonData::clone() const {
+  HierarchicalPoissonData *HierarchicalPoissonData::clone() const {
     return new HierarchicalPoissonData(*this);
   }
 
-  ostream & HierarchicalPoissonData::display(ostream &out) const {
+  ostream &HierarchicalPoissonData::display(ostream &out) const {
     out << event_count_ << " " << exposure_;
     return out;
   }
 
   HierarchicalPoissonModel::HierarchicalPoissonModel(
-      double lambda_prior_guess,
-      double lambda_prior_sample_size)
-      : HierarchicalBase(new GammaModel(lambda_prior_sample_size,
-                                        lambda_prior_guess,
-                                        0)) {}
+      double lambda_prior_guess, double lambda_prior_sample_size)
+      : HierarchicalBase(
+            new GammaModel(lambda_prior_sample_size, lambda_prior_guess, 0)) {}
 
-  HierarchicalPoissonModel::HierarchicalPoissonModel(Ptr<GammaModel> prior)
+  HierarchicalPoissonModel::HierarchicalPoissonModel(
+      const Ptr<GammaModel> &prior)
       : HierarchicalBase(prior) {}
 
-  HierarchicalPoissonModel * HierarchicalPoissonModel::clone() const {
+  HierarchicalPoissonModel *HierarchicalPoissonModel::clone() const {
     return new HierarchicalPoissonModel(*this);
   }
 
-  void HierarchicalPoissonModel::add_data(Ptr<Data> dp) {
+  void HierarchicalPoissonModel::add_data(const Ptr<Data> &dp) {
     Ptr<HierarchicalPoissonData> data_point =
         dp.dcast<HierarchicalPoissonData>();
     double events = data_point->event_count();
