@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-20015 Steven L. Scott
 
@@ -15,54 +16,50 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/PosteriorSamplers/DirichletPosteriorSampler.hpp>
-#include <Samplers/ScalarSliceSampler.hpp>
-#include <cpputil/math_utils.hpp>
-#include <distributions.hpp>
+#include "Models/PosteriorSamplers/DirichletPosteriorSampler.hpp"
 #include <utility>
+#include "Samplers/ScalarSliceSampler.hpp"
+#include "cpputil/math_utils.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
   typedef DirichletPosteriorSampler DPS;
 
   DPS::DirichletPosteriorSampler(DirichletModel *mod,
-                                 Ptr<VectorModel> Phi,
-                                 Ptr<DoubleModel> alpha,
+                                 const Ptr<VectorModel> &Phi,
+                                 const Ptr<DoubleModel> &alpha,
                                  RNG &seeding_rng)
-    : PosteriorSampler(seeding_rng),
-      model_(mod),
-      phi_prior_(Phi),
-      alpha_prior_(alpha)
-  {
-    set_method(
-        std::shared_ptr<DirichletSampler::DirichletSamplerImpl>(
-            new DirichletSampler::MlogitSliceImpl(
-                model_,
-                phi_prior_.dcast<DiffVectorModel>(),
-                alpha_prior_.dcast<DiffDoubleModel>(),
-                &rng())),
-        1.0);
+      : PosteriorSampler(seeding_rng),
+        model_(mod),
+        phi_prior_(Phi),
+        alpha_prior_(alpha) {
+    set_method(std::shared_ptr<DirichletSampler::DirichletSamplerImpl>(
+                   new DirichletSampler::MlogitSliceImpl(
+                       model_, phi_prior_.dcast<DiffVectorModel>(),
+                       alpha_prior_.dcast<DiffDoubleModel>(), &rng())),
+               1.0);
   }
 
-  double DPS::logpri()const{
-    const Vector & nu(model_->nu());
+  double DPS::logpri() const {
+    const Vector &nu(model_->nu());
     double alpha = sum(nu);
     double ans = alpha_prior_->logp(alpha);
-    ans+= phi_prior_->logp(nu/alpha);
+    ans += phi_prior_->logp(nu / alpha);
     // Add in the Jacobian term to make the prior with respect to nu.
-    ans -= (dim()-1) * log(alpha);
+    ans -= (dim() - 1) * log(alpha);
     return ans;
   }
 
   void DPS::set_method(
-      std::shared_ptr<DirichletSampler::DirichletSamplerImpl> method,
+      const std::shared_ptr<DirichletSampler::DirichletSamplerImpl> &method,
       double weight) {
     sampler_implementations_.clear();
     weights_.clear();
-    add_method(std::move(method), weight);
+    add_method(method, weight);
   }
 
   void DPS::add_method(
-      std::shared_ptr<DirichletSampler::DirichletSamplerImpl> method,
+      const std::shared_ptr<DirichletSampler::DirichletSamplerImpl> &method,
       double weight) {
     if (weight <= 0) {
       report_error("Argument 'weight' must be positive.");
@@ -71,9 +68,10 @@ namespace BOOM{
     weights_.push_back(weight);
   }
 
-  void DPS::draw_impl(const std::vector<std::shared_ptr<
-                      DirichletSampler::DirichletSamplerImpl>>  &impl,
-                      const Vector &weights) {
+  void DPS::draw_impl(
+      const std::vector<std::shared_ptr<DirichletSampler::DirichletSamplerImpl>>
+          &impl,
+      const Vector &weights) {
     int n = impl.size();
     if (n == 0) {
       report_error("Either no sampling methods were set, or all failed.");
@@ -88,8 +86,8 @@ namespace BOOM{
       if (n > 1) {
         std::vector<std::shared_ptr<DirichletSampler::DirichletSamplerImpl>>
             other_implementations(impl);
-        other_implementations.erase(other_implementations.begin()
-                                    + which_sampler);
+        other_implementations.erase(other_implementations.begin() +
+                                    which_sampler);
         Vector other_weights = weights;
         other_weights.erase(other_weights.begin() + which_sampler);
         draw_impl(other_implementations, other_weights);
@@ -99,11 +97,9 @@ namespace BOOM{
     }
   }
 
-  void DPS::draw() {
-    draw_impl(sampler_implementations_, weights_);
-  }
+  void DPS::draw() { draw_impl(sampler_implementations_, weights_); }
 
-  uint DPS::dim()const{ return model_->nu().size(); }
+  uint DPS::dim() const { return model_->nu().size(); }
 
   //======================================================================
   namespace DirichletSampler {
@@ -115,70 +111,58 @@ namespace BOOM{
           report_error("Matrix must be square.");
         }
         for (int i = 0; i < m.nrow(); ++i) {
-          for (int j = i+1; j < m.ncol(); ++j) {
+          for (int j = i + 1; j < m.ncol(); ++j) {
             m(j, i) = m(i, j);
           }
         }
       }
     }  // namespace
 
-
     typedef DirichletLogp DLP;
-    DLP::DirichletLogp(uint pos,
-                       const Vector & nu,
-                       const Vector & sumlogpi,
-                       double nobs,
-                       const VectorModel *phi_prior,
-                       const DoubleModel *alpha_prior,
-                       double min_nu)
+    DLP::DirichletLogp(uint pos, const Vector &nu, const Vector &sumlogpi,
+                       double nobs, const VectorModel *phi_prior,
+                       const DoubleModel *alpha_prior, double min_nu)
         : sumlogpi_(sumlogpi),
           nobs_(nobs),
           pos_(pos),
           nu_(nu),
           min_nu_(min_nu),
           alpha_prior_(alpha_prior),
-          phi_prior_(phi_prior)
-    {}
+          phi_prior_(phi_prior) {}
 
     //----------------------------------------------------------------------
-    double DLP::operator()(double nu)const{
-      if(nu < min_nu_) return BOOM::negative_infinity();
-      nu_[pos_]=nu;
+    double DLP::operator()(double nu) const {
+      if (nu < min_nu_) return BOOM::negative_infinity();
+      nu_[pos_] = nu;
       return logp();
     }
 
     //----------------------------------------------------------------------
-    double DLP::logp()const{
+    double DLP::logp() const {
       double alpha = sum(nu_);
-      if(alpha<=0) return BOOM::negative_infinity();
+      if (alpha <= 0) return BOOM::negative_infinity();
       uint d = nu_.size();
-      double ans = alpha_prior_->logp(alpha);   // alpha prior
-      if(!std::isfinite(ans)) return ans;
-      ans+= phi_prior_->logp(nu_/alpha);        // phi prior
-      if(!std::isfinite(ans)) return ans;
-      ans-= (d-1) * log(alpha);                 // jacobian
+      double ans = alpha_prior_->logp(alpha);  // alpha prior
+      if (!std::isfinite(ans)) return ans;
+      ans += phi_prior_->logp(nu_ / alpha);  // phi prior
+      if (!std::isfinite(ans)) return ans;
+      ans -= (d - 1) * log(alpha);  // jacobian
       ans += dirichlet_loglike(nu_, 0, 0, sumlogpi_, nobs_);
       return ans;
     }
-  //----------------------------------------------------------------------
+    //----------------------------------------------------------------------
     DirichletSamplerImpl::DirichletSamplerImpl(
-        DirichletModel *model,
-        Ptr<VectorModel> phi_prior,
-        Ptr<DoubleModel> alpha_prior,
-        RNG *rng)
+        DirichletModel *model, const Ptr<VectorModel> &phi_prior,
+        const Ptr<DoubleModel> &alpha_prior, RNG *rng)
         : model_(model),
           phi_prior_(phi_prior),
           alpha_prior_(alpha_prior),
-          rng_(rng)
-    {}
+          rng_(rng) {}
 
-    NuSliceImpl::NuSliceImpl(
-        DirichletModel *model,
-        Ptr<VectorModel> phi_prior,
-        Ptr<DoubleModel> alpha_prior,
-        RNG *rng)
-        : DirichletSamplerImpl(model, phi_prior, alpha_prior, rng)
-    {}
+    NuSliceImpl::NuSliceImpl(DirichletModel *model,
+                             const Ptr<VectorModel> &phi_prior,
+                             const Ptr<DoubleModel> &alpha_prior, RNG *rng)
+        : DirichletSamplerImpl(model, phi_prior, alpha_prior, rng) {}
 
     void NuSliceImpl::draw() {
       Vector nu = model()->nu();
@@ -187,11 +171,8 @@ namespace BOOM{
         // We need to use the local variable nu here so that each
         // draw will be conditional on the most recent value of the
         // other nu elements.
-        DirichletLogp logp(i, nu,
-                           model()->suf()->sumlog(),
-                           model()->suf()->n(),
-                           phi_prior(),
-                           alpha_prior());
+        DirichletLogp logp(i, nu, model()->suf()->sumlog(), model()->suf()->n(),
+                           phi_prior(), alpha_prior());
         ScalarSliceSampler sam(logp, true, 1.0, rng());
         sam.set_lower_limit(0);
         nu[i] = sam.draw(nu[i]);
@@ -200,23 +181,15 @@ namespace BOOM{
     }
 
     //----------------------------------------------------------------------
-    MlogitSliceImpl::MlogitSliceImpl(
-        DirichletModel *model,
-        Ptr<DiffVectorModel> phi_prior,
-        Ptr<DiffDoubleModel> alpha_prior,
-        RNG *rng)
+    MlogitSliceImpl::MlogitSliceImpl(DirichletModel *model,
+                                     const Ptr<DiffVectorModel> &phi_prior,
+                                     const Ptr<DiffDoubleModel> &alpha_prior,
+                                     RNG *rng)
         : DirichletSamplerImpl(model, phi_prior, alpha_prior, rng),
           phi_logpost_(MultinomialLogitLogPosterior(model, phi_prior)),
-          phi_sampler_(phi_logpost_,
-                       1.0,
-                       true,
-                       rng),
+          phi_sampler_(phi_logpost_, 1.0, true, rng),
           alpha_logpost_(model, alpha_prior),
-          log_alpha_sampler_(alpha_logpost_,
-                             true,
-                             1.0,
-                             rng)
-    {}
+          log_alpha_sampler_(alpha_logpost_, true, 1.0, rng) {}
 
     void MlogitSliceImpl::draw() {
       Vector nu = model()->nu();
@@ -230,18 +203,15 @@ namespace BOOM{
     }
 
     //----------------------------------------------------------------------
-    TimImpl::TimImpl(
-        DirichletModel *model,
-        Ptr<DiffVectorModel> phi_prior,
-        Ptr<DiffDoubleModel> alpha_prior,
-        RNG *rng)
+    TimImpl::TimImpl(DirichletModel *model,
+                     const Ptr<DiffVectorModel> &phi_prior,
+                     const Ptr<DiffDoubleModel> &alpha_prior, RNG *rng)
         : DirichletSamplerImpl(model, phi_prior, alpha_prior, rng),
           phi_logpost_(MultinomialLogitLogPosterior(
               model, phi_prior.dcast<DiffVectorModel>())),
           phi_sampler_(phi_logpost_, 3, rng),
           alpha_logpost_(model, alpha_prior),
-          log_alpha_sampler_(alpha_logpost_, true, 1.0, rng)
-    {}
+          log_alpha_sampler_(alpha_logpost_, true, 1.0, rng) {}
 
     void TimImpl::draw() {
       draw_alpha_given_phi();
@@ -271,19 +241,15 @@ namespace BOOM{
 
     //----------------------------------------------------------------------
     DirichletPhiLogPosterior::DirichletPhiLogPosterior(
-        DirichletModel *model,
-        Ptr<DiffVectorModel> phi_prior)
-        : model_(model),
-          phi_prior_(phi_prior)
-    {}
+        DirichletModel *model, const Ptr<DiffVectorModel> &phi_prior)
+        : model_(model), phi_prior_(phi_prior) {}
 
     // Note the phi argument here has element 0 omitted because it is
     // a function of the other elements.
-    double DirichletPhiLogPosterior::operator()(
-        const Vector &truncated_phi,
-        Vector &gradient,
-        Matrix &Hessian,
-        uint nderiv) const {
+    double DirichletPhiLogPosterior::operator()(const Vector &truncated_phi,
+                                                Vector &gradient,
+                                                Matrix &Hessian,
+                                                uint nderiv) const {
       if (truncated_phi.size() != model_->dim() - 1) {
         report_error("truncated_phi is the wrong size.");
       }
@@ -311,10 +277,10 @@ namespace BOOM{
       ans += (nu0 - 1) * sumlog[0] - n * lgamma(nu0);
       for (int s = 0; s < truncated_phi.size(); ++s) {
         double nu = truncated_phi[s] * alpha;
-        ans += (nu - 1) * sumlog[s+1] - n * lgamma(nu);
+        ans += (nu - 1) * sumlog[s + 1] - n * lgamma(nu);
         if (nderiv > 0) {
-          gradient[s] += alpha * (sumlog[s+1] - sumlog[0])
-              - n * alpha * (digamma(nu) - digamma(nu0));
+          gradient[s] += alpha * (sumlog[s + 1] - sumlog[0]) -
+                         n * alpha * (digamma(nu) - digamma(nu0));
           if (nderiv > 1) {
             for (int r = 0; r < truncated_phi.size(); ++r) {
               Hessian(r, s) -= n * square(alpha) * trigamma(nu0);
@@ -333,8 +299,7 @@ namespace BOOM{
     typedef MultinomialLogitLogPosterior Mlogit;
 
     Mlogit::Jacobian::Jacobian(const Vector &truncated_phi)
-        : truncated_phi_(truncated_phi)
-    {}
+        : truncated_phi_(truncated_phi) {}
 
     // Here is the math for the Jacobian of the multinomial logit
     // transform of phi:  phi -> eta.
@@ -405,8 +370,7 @@ namespace BOOM{
     //      = (1/phi0) * (-1) * sum_s(J[r,s]) + sum_s (1/phi[s]) J(r,s)
     //      = sum_s J(r, s) * (1/phi[s] - 1/phi0)
     void Mlogit::Jacobian::add_eta_gradient(
-        Vector &gradient,
-        const SpdMatrix &jacobian_matrix) const {
+        Vector &gradient, const SpdMatrix &jacobian_matrix) const {
       if (gradient.size() != truncated_phi_.size()) {
         report_error("gradient is the wrong size.");
       }
@@ -445,22 +409,18 @@ namespace BOOM{
             sum(J.row(r)) / square(phi0);
         for (int s = 0; s < dim; ++s) {
           for (int t = 0; t < dim; ++t) {
-            hessian(r, s) +=
-                second_order_element(r, s, t)
-                * (1.0 / truncated_phi_[t] - 1.0 / phi0)
-                - J(s, t) * (J(r, t) / square(truncated_phi_[t])
-                             + jacobian_row_sum_over_phi0_squared);
+            hessian(r, s) += second_order_element(r, s, t) *
+                                 (1.0 / truncated_phi_[t] - 1.0 / phi0) -
+                             J(s, t) * (J(r, t) / square(truncated_phi_[t]) +
+                                        jacobian_row_sum_over_phi0_squared);
           }
         }
       }
     }
 
-    Mlogit::MultinomialLogitLogPosterior(
-        DirichletModel *model,
-        Ptr<DiffVectorModel> phi_prior)
-        : model_(model),
-          phi_prior_(phi_prior)
-    {}
+    Mlogit::MultinomialLogitLogPosterior(DirichletModel *model,
+                                         const Ptr<DiffVectorModel> &phi_prior)
+        : model_(model), phi_prior_(phi_prior) {}
 
     Vector Mlogit::to_eta(const Vector &phi) const {
       Vector ans = log(phi / phi[0]);
@@ -480,8 +440,7 @@ namespace BOOM{
       return ans;
     }
 
-    double Mlogit::scalar_derivative(const Vector &eta,
-                                     double &derivative,
+    double Mlogit::scalar_derivative(const Vector &eta, double &derivative,
                                      int position) const {
       Vector gradient;
       Matrix hessian;
@@ -490,10 +449,8 @@ namespace BOOM{
       return ans;
     }
 
-    double Mlogit::operator()(const Vector &eta,
-                              Vector &gradient,
-                              Matrix &Hessian,
-                              uint nderiv) const {
+    double Mlogit::operator()(const Vector &eta, Vector &gradient,
+                              Matrix &Hessian, uint nderiv) const {
       Vector truncated_phi = to_full_phi(eta);
       truncated_phi.erase(truncated_phi.begin());
       DirichletPhiLogPosterior logp_phi(model_, phi_prior_);
@@ -528,14 +485,11 @@ namespace BOOM{
 
     //----------------------------------------------------------------------
     LogAlphaLogPosterior::LogAlphaLogPosterior(
-        DirichletModel *model,
-        Ptr<DiffDoubleModel> alpha_prior)
-        : model_(model),
-          alpha_prior_(alpha_prior)
-    {}
+        DirichletModel *model, const Ptr<DiffDoubleModel> &alpha_prior)
+        : model_(model), alpha_prior_(alpha_prior) {}
 
-    double LogAlphaLogPosterior::operator()(
-        double log_alpha, double &d1, double &d2, uint nderiv) const {
+    double LogAlphaLogPosterior::operator()(double log_alpha, double &d1,
+                                            double &d2, uint nderiv) const {
       double alpha = exp(log_alpha);
       if (!std::isfinite(alpha)) {
         return negative_infinity();
@@ -598,22 +552,15 @@ namespace BOOM{
       return ans;
     }
 
-    LangevinImpl::LangevinImpl(
-        DirichletModel *model,
-        Ptr<DiffVectorModel> phi_prior,
-        Ptr<DiffDoubleModel> alpha_prior,
-        RNG *rng)
+    LangevinImpl::LangevinImpl(DirichletModel *model,
+                               const Ptr<DiffVectorModel> &phi_prior,
+                               const Ptr<DiffDoubleModel> &alpha_prior,
+                               RNG *rng)
         : DirichletSamplerImpl(model, phi_prior, alpha_prior, rng),
           phi_logpost_(new MultinomialLogitLogPosterior(model, phi_prior)),
-          phi_sampler_(phi_logpost_,
-                       model->nu().size() - 1,
-                       .05,
-                       rng),
+          phi_sampler_(phi_logpost_, model->nu().size() - 1, .05, rng),
           alpha_logpost_(new LogAlphaLogPosterior(model, alpha_prior)),
-          log_alpha_sampler_(alpha_logpost_,
-                             .05,
-                             rng)
-    {
+          log_alpha_sampler_(alpha_logpost_, .05, rng) {
       phi_sampler_.allow_adaptation(false);
       log_alpha_sampler_.allow_adaptation(false);
     }
@@ -640,4 +587,4 @@ namespace BOOM{
 
   }  // namespace DirichletSampler
 
-}
+}  // namespace BOOM
