@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2015 Steven L. Scott
 
@@ -15,17 +16,16 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/StateSpace/PosteriorSamplers/StateSpacePoissonPosteriorSampler.hpp>
-#include <Models/StateSpace/PosteriorSamplers/SufstatManager.hpp>
-#include <distributions.hpp>
+#include "Models/StateSpace/PosteriorSamplers/StateSpacePoissonPosteriorSampler.hpp"
+#include "Models/StateSpace/PosteriorSamplers/SufstatManager.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
   namespace StateSpace {
 
-    class PoissonSufstatManager
-      : public SufstatManagerBase {
+    class PoissonSufstatManager : public SufstatManagerBase {
      public:
-      PoissonSufstatManager(StateSpacePoissonPosteriorSampler *sampler)
+      explicit PoissonSufstatManager(StateSpacePoissonPosteriorSampler *sampler)
           : sampler_(sampler) {}
 
       void clear_complete_data_sufficient_statistics() override {
@@ -49,14 +49,12 @@ namespace BOOM {
 
   SSPPS::StateSpacePoissonPosteriorSampler(
       StateSpacePoissonModel *model,
-      Ptr<PoissonRegressionSpikeSlabSampler> observation_model_sampler,
+      const Ptr<PoissonRegressionSpikeSlabSampler> &observation_model_sampler,
       RNG &seeding_rng)
       : StateSpacePosteriorSampler(model, seeding_rng),
         model_(model),
-        observation_model_sampler_(observation_model_sampler)
-  {
-    model_->register_data_observer(
-        new StateSpace::PoissonSufstatManager(this));
+        observation_model_sampler_(observation_model_sampler) {
+    model_->register_data_observer(new StateSpace::PoissonSufstatManager(this));
     observation_model_sampler_->fix_latent_data(true);
   }
 
@@ -70,8 +68,7 @@ namespace BOOM {
       double state_contribution =
           model_->observation_matrix(t).dot(model_->state(t));
       for (int j = 0; j < dp->total_sample_size(); ++j) {
-        const PoissonRegressionData &observation(
-            dp->poisson_data(j));
+        const PoissonRegressionData &observation(dp->poisson_data(j));
         if (observation.missing() == Data::observed) {
           double regression_contribution =
               model_->observation_model()->predict(observation.x());
@@ -100,13 +97,12 @@ namespace BOOM {
           precision_weighted_sum *= external_mixture_precision;
           if (observation.y() > 0) {
             precision_weighted_sum +=
-                (internal_neglog_final_event_time - internal_mixture_mean)
-                * internal_mixture_precision;
+                (internal_neglog_final_event_time - internal_mixture_mean) *
+                internal_mixture_precision;
             total_precision += internal_mixture_precision;
           }
           dp->set_latent_data(precision_weighted_sum / total_precision,
-                              total_precision,
-                              j);
+                              total_precision, j);
         }
       }
       dp->set_state_model_offset(state_contribution);
@@ -124,13 +120,12 @@ namespace BOOM {
         double precision_weighted_mean = dp->latent_data_value(j);
 
         precision_weighted_mean -= dp->state_model_offset();
-        double precision = 1.0 / dp -> latent_data_variance(j);
+        double precision = 1.0 / dp->latent_data_variance(j);
         observation_model_sampler_->update_complete_data_sufficient_statistics(
-            precision_weighted_mean * precision,
-            precision,
+            precision_weighted_mean * precision, precision,
             model_->data(t, j).x());
       }
     }
   }
 
-}   // namespace BOOM
+}  // namespace BOOM
