@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2012 Steven L. Scott
 
@@ -16,11 +17,11 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/StateSpace/PosteriorSamplers/StudentLocalLinearTrendPosteriorSampler.hpp>
-#include <cpputil/math_utils.hpp>
-#include <distributions.hpp>
-#include <distributions/trun_gamma.hpp>
-#include <Samplers/ScalarSliceSampler.hpp>
+#include "Models/StateSpace/PosteriorSamplers/StudentLocalLinearTrendPosteriorSampler.hpp"
+#include "Samplers/ScalarSliceSampler.hpp"
+#include "cpputil/math_utils.hpp"
+#include "distributions.hpp"
+#include "distributions/trun_gamma.hpp"
 
 namespace BOOM {
 
@@ -28,8 +29,7 @@ namespace BOOM {
     // A local namespace for minor implementation details.
     class NuPosterior {
      public:
-      NuPosterior(const BOOM::DoubleModel *nu_prior,
-                  const BOOM::GammaSuf *suf)
+      NuPosterior(const BOOM::DoubleModel *nu_prior, const BOOM::GammaSuf *suf)
           : nu_prior_(nu_prior), suf_(suf) {}
 
       // Returns the un-normalized log posterior evaulated at nu.
@@ -45,6 +45,7 @@ namespace BOOM {
         ans -= nu2 * sum;
         return ans;
       }
+
      private:
       const BOOM::DoubleModel *nu_prior_;
       const BOOM::GammaSuf *suf_;
@@ -56,11 +57,10 @@ namespace BOOM {
 
   SLLTPS::StudentLocalLinearTrendPosteriorSampler(
       StudentLocalLinearTrendStateModel *model,
-      Ptr<GammaModelBase> sigsq_level_prior,
-      Ptr<DoubleModel> nu_level_prior,
-      Ptr<GammaModelBase> sigsq_slope_prior,
-      Ptr<DoubleModel> nu_slope_prior,
-      RNG &seeding_rng)
+      const Ptr<GammaModelBase> &sigsq_level_prior,
+      const Ptr<DoubleModel> &nu_level_prior,
+      const Ptr<GammaModelBase> &sigsq_slope_prior,
+      const Ptr<DoubleModel> &nu_slope_prior, RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
         model_(model),
         sigsq_level_prior_(sigsq_level_prior),
@@ -68,14 +68,13 @@ namespace BOOM {
         sigsq_slope_prior_(sigsq_slope_prior),
         nu_slope_prior_(nu_slope_prior),
         sigsq_level_sampler_(sigsq_level_prior_),
-        sigsq_slope_sampler_(sigsq_slope_prior_)
-  {}
+        sigsq_slope_sampler_(sigsq_slope_prior_) {}
 
   double SLLTPS::logpri() const {
-    return sigsq_level_sampler_.log_prior(model_->sigsq_level())
-        + nu_level_prior_->logp(model_->nu_level())
-        + sigsq_slope_sampler_.log_prior(model_->sigsq_slope())
-        + nu_slope_prior_->logp(1.0 / model_->nu_slope());
+    return sigsq_level_sampler_.log_prior(model_->sigsq_level()) +
+           nu_level_prior_->logp(model_->nu_level()) +
+           sigsq_slope_sampler_.log_prior(model_->sigsq_slope()) +
+           nu_slope_prior_->logp(1.0 / model_->nu_slope());
   }
 
   void SLLTPS::draw() {
@@ -85,26 +84,22 @@ namespace BOOM {
     draw_nu_slope();
   }
 
-  void SLLTPS::set_sigma_level_upper_limit(
-      double upper_limit) {
+  void SLLTPS::set_sigma_level_upper_limit(double upper_limit) {
     sigsq_level_sampler_.set_sigma_max(upper_limit);
   }
 
-  void SLLTPS::set_sigma_slope_upper_limit(
-      double upper_limit) {
+  void SLLTPS::set_sigma_slope_upper_limit(double upper_limit) {
     sigsq_slope_sampler_.set_sigma_max(upper_limit);
   }
 
   void SLLTPS::draw_sigsq_level() {
-    const WeightedGaussianSuf &suf(
-        model_->sigma_level_complete_data_suf());
+    const WeightedGaussianSuf &suf(model_->sigma_level_complete_data_suf());
     double sigsq = sigsq_level_sampler_.draw(rng(), suf.n(), suf.sumsq());
     model_->set_sigsq_level(sigsq);
   }
 
   void SLLTPS::draw_sigsq_slope() {
-    const WeightedGaussianSuf &suf(
-        model_->sigma_slope_complete_data_suf());
+    const WeightedGaussianSuf &suf(model_->sigma_slope_complete_data_suf());
     double sigsq = sigsq_slope_sampler_.draw(rng(), suf.n(), suf.sumsq());
     model_->set_sigsq_slope(sigsq);
   }
@@ -127,4 +122,4 @@ namespace BOOM {
     model_->set_nu_slope(nu);
   }
 
-} // namespace BOOM
+}  // namespace BOOM
