@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2005-2011 Steven L. Scott
+  Copyright (C) 2005-2018 Steven L. Scott
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -20,24 +20,38 @@
 #include <sstream>
 
 #include <r_interface/boom_r_tools.hpp>
-#include <cpputil/report_error.hpp>
+#include "cpputil/report_error.hpp"
 
 #include <R.h>
 #include <Rinternals.h>
+#include <R_ext/Parse.h>
 
-namespace BOOM{
-  SEXP getListElement(SEXP list, const std::string &name){
+namespace BOOM {
+
+  namespace {
+    using std::endl;
+  }  // namespace 
+  
+  SEXP getListElement(SEXP list, const std::string &name, bool expect_answer) {
     SEXP elmt = R_NilValue;
     SEXP names = Rf_getAttrib(list, R_NamesSymbol);
     if(Rf_isNull(names)){
-      report_error("attempt to use getListElement in a list with"
-                   " no 'names' attribute.");
+      std::ostringstream err;
+      err << "Attempt to use getListElement in a list with"
+          << " no 'names' attribute." << endl
+          << "You were searching for the name: " << name << endl;
+      report_error(err.str());
     }
     for(int i = 0; i < Rf_length(list); i++)
       if(name == CHAR(STRING_ELT(names, i))){
         elmt = VECTOR_ELT(list, i);
         break;
       }
+    if (expect_answer && elmt == R_NilValue) {
+      std::ostringstream warning;
+      warning << "Could not find list element named: " << name << endl;
+      report_warning(warning.str());
+    }
     return elmt;
   }
 
@@ -277,7 +291,6 @@ namespace BOOM{
     } else {
       // If r_array is actually a matrix that's okay, because to R a
       // matrix is a 2-d array.
-      std::vector<int> dims = GetArrayDimensions(r_array);
       return Array(GetArrayDimensions(r_array), REAL(r_array));
     }
   }
@@ -295,7 +308,6 @@ namespace BOOM{
     } else {
       // If r_array is actually a matrix that's okay, because to R a
       // matrix is a 2-d array.
-      std::vector<int> dims = GetArrayDimensions(r_array);
       return ConstArrayView(REAL(r_array), GetArrayDimensions(r_array));
     }
   }
@@ -319,10 +331,11 @@ namespace BOOM{
       SEXP r_variable = VECTOR_ELT(r_data_frame, i);
       if (Rf_isFactor(r_variable)) {
         Factor factor(r_variable);
-        table.append_variable(factor.vector_of_observations(),
-                              variable_names[i]);
+        CategoricalVariable variable(factor.vector_of_observations(),
+                                     factor.key());
+        table.append_variable(variable, variable_names[i]);
       } else if (Rf_isString(r_variable)) {
-        table.append_variable(make_catdat_ptrs(StringVector(r_variable)),
+        table.append_variable(CategoricalVariable(StringVector(r_variable)),
                               variable_names[i]);
       } else if (Rf_isNumeric(r_variable)) {
         table.append_variable(ToBoomVector(r_variable),
@@ -388,6 +401,22 @@ namespace BOOM{
     return ans;
   }
 
+  // R's date object is the number of days since Jan 1 1970.
+  Date ToBoomDate(SEXP r_Date) {
+    Date ans;
+    ans.set(lround(Rf_asReal(r_Date)));
+    return ans;
+  }
+
+  std::vector<BOOM::Date> ToBoomDateVector(SEXP r_dates) {
+    Vector date_numbers = ToBoomVector(r_dates);
+    std::vector<BOOM::Date> ans(date_numbers.size());
+    for (int i = 0; i < ans.size(); ++i) {
+      ans[i].set(lround(date_numbers[i]));
+    }
+    return ans;
+  }
+  
   SEXP ToRVector(const Vector &v){
     int n = v.size();
     RMemoryProtector protector;
@@ -478,6 +507,24 @@ namespace BOOM{
     return "";
   }
 
+  SEXP ToRString(const std::string &s) {
+    SEXP ans;
+    RMemoryProtector protector;
+    protector.protect(ans = Rf_allocVector(STRSXP, 1));
+    SET_STRING_ELT(ans, 0, Rf_mkChar(s.c_str()));
+    return ans;
+  }
+
+  SEXP ToRStringVector(const std::vector<std::string> &string_vector) {
+    SEXP ans;
+    RMemoryProtector protector;
+    protector.protect(ans = Rf_allocVector(STRSXP, string_vector.size()));
+    for (int i = 0; i < string_vector.size(); ++i) {
+      SET_STRING_ELT(ans, i, Rf_mkChar(string_vector[i].c_str()));
+    }
+    return ans;
+  }
+  
   Factor::Factor(SEXP r_factor)
       : values_(Rf_length(r_factor)),
         levels_(new CatKey(GetFactorLevels(r_factor)))
@@ -497,7 +544,7 @@ namespace BOOM{
   }
 
   int Factor::number_of_levels() const {
-    return levels_->size();
+    return levels_->max_levels();
   }
 
   int Factor::operator[](int i) const {
@@ -536,6 +583,51 @@ namespace BOOM{
     }
   }
 
+
+  RVectorFunction::RVectorFunction(SEXP r_vector_function)
+      : function_name_(ToString(getListElement(
+            r_vector_function, "function.name"))),
+        argument_name_("RVectorFunction_arg_"),
+        r_env_(getListElement(r_vector_function, "env"))
+  {
+    if (!Rf_isEnvironment(r_env_)) {
+      Rf_PrintValue(r_env_);
+      report_error("The second argument to RVectorFunction must be an "
+                   "environment.");
+    }
+    call_string_ = function_name_ + "(" + argument_name_ + ")";
+
+  }
+
+  // If RVectorFunction_arg_ exists in r_env_ then delete it
+  RVectorFunction::~RVectorFunction() {
+    // ParseStatus parse_status;
+    // std::string rm_string = "if (exists(" + argument_name_ + ") rm(" + argument_name_ + ")";
+    // RMemoryProtector protector;
+    // SEXP r_call = protector.protect(R_ParseVector(
+    //     ToRString(rm_string), 1, &parse_status, R_NilValue));
+    // Rf_eval(VECTOR_ELT(r_call, 0), r_env_);
+  }
+  
+  // Creates an object named argument_name_ in the function's environment, then
+  // calls f(argument_name_) on the function.
+  double RVectorFunction::evaluate(const Vector &x) {
+    // First, write x as an R object with the right name.
+    SEXP symbol, value;
+    RMemoryProtector protector;
+    protector.protect(symbol = Rf_install(argument_name_.c_str()));
+    protector.protect(value = ToRVector(x));
+    Rf_defineVar(symbol, value, r_env_);
+
+    // Next, create a call that we can pass to Rf_eval.
+    // ParseStatus is an enum defined in .../include/R_ext/Parse.h
+    ParseStatus parse_status;
+    SEXP r_call = protector.protect(R_ParseVector(
+        ToRString(call_string_), 1, &parse_status, R_NilValue));
+    return Rf_asReal(Rf_eval(VECTOR_ELT(r_call, 0), r_env_));
+  }
+
+  
   namespace {
     // Wrapper for R_CheckUserInterrupt.
     static void check_interrupt_func(void *dummy) {
@@ -548,5 +640,5 @@ namespace BOOM{
     // longjmp out of the current context, so C++ can clean up correctly.
     return (!R_ToplevelExec(check_interrupt_func, NULL));
   }
-
+  
 }  // namespace BOOM;
