@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,60 +14,61 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
-#include <cpputil/string_utils.hpp>
-#include <string>
 #include <iostream>
 #include <sstream>
+#include <string>
+#include "cpputil/string_utils.hpp"
 
-namespace BOOM{
-  std::string operator+(const std::string &s, int i){
+namespace BOOM {
+  std::string operator+(const std::string &s, int i) {
     std::ostringstream ans;
     ans << s << i;
     return ans.str();
   }
 
-  std::string operator+(int i , const std::string &s){
+  std::string operator+(int i, const std::string &s) {
     std::ostringstream ans;
-    ans << i<< s;
+    ans << i << s;
     return ans.str();
   }
 
-  std::string operator+(const std::string& s, double d){
+  std::string operator+(const std::string &s, double d) {
     std::ostringstream ans;
     ans << s << d;
     return ans.str();
   }
 
-  std::string operator+(double d, const std::string& s){
+  std::string operator+(double d, const std::string &s) {
     std::ostringstream ans;
     ans << d << s;
     return ans.str();
   }
 
-  std::string operator+=(std::string &s, int n){
+  std::string operator+=(std::string &s, int n) {
     std::ostringstream ans;
     ans << n;
-    s +=ans.str();
+    s += ans.str();
     return s;
   }
 
-  std::string operator+=(std::string &s, double d){
+  std::string operator+=(std::string &s, double d) {
     std::ostringstream ans;
     ans << d;
-    s +=ans.str();
+    s += ans.str();
     return s;
   }
 
-  std::string operator>>(const std::string& s, int &n){
+  std::string operator>>(const std::string &s, int &n) {
     std::istringstream ans(s);
     ans >> n;
     return ans.str();
   }
 
-  std::string operator>>(const std::string& s, double &d){
+  std::string operator>>(const std::string &s, double &d) {
     std::istringstream ans(s);
     ans >> d;
     return ans.str();
