@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -17,12 +18,13 @@
 */
 
 #include <cctype>
-#include <BOOM.hpp>
-namespace BOOM{
+#include "BOOM.hpp"
+namespace BOOM {
 
-  bool is_all_white(const string &s){
+  bool is_all_white(const string &s) {
     // returns true if s is either empty or all white space
-    for(uint i = 0; i<s.size(); ++i) if(!isspace(s[i])) return false;
+    for (uint i = 0; i < s.size(); ++i)
+      if (!isspace(s[i])) return false;
     return true;
   }
-}
+}  // namespace BOOM
