@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -15,16 +16,16 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <cpputil/str2d.hpp>
+#include "cpputil/str2d.hpp"
 #include <sstream>
 
-namespace BOOM{
+namespace BOOM {
   using namespace std;
   using std::string;
-  double str2d(const string &s){
+  double str2d(const string &s) {
     istringstream str(s);
     double ans;
     str >> ans;
     return ans;
   }
-}
+}  // namespace BOOM
