@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -18,16 +19,17 @@
 
 #include <algorithm>
 #include <cmath>
-#include <distributions.hpp>
-#include <LinAlg/Vector.hpp>
-#include <LinAlg/Matrix.hpp>
-#include <LinAlg/SpdMatrix.hpp>
-#include <LinAlg/Cholesky.hpp>
+#include "LinAlg/Cholesky.hpp"
+#include "LinAlg/Matrix.hpp"
+#include "LinAlg/SpdMatrix.hpp"
+#include "LinAlg/Vector.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
 
   Vector rmvn_robust(const Vector &mu, const SpdMatrix &V) {
-    return rmvn_robust_mt(GlobalRng::rng, mu, V); }
+    return rmvn_robust_mt(GlobalRng::rng, mu, V);
+  }
   Vector rmvn_robust_mt(RNG &rng, const Vector &mu, const SpdMatrix &V) {
     uint n = V.nrow();
     Matrix eigenvectors(n, n);
@@ -36,7 +38,7 @@ namespace BOOM {
       // We're guaranteed that eigenvalues[i] is real and non-negative.  We
       // can take the absolute value of eigenvalues[i] to guard against
       // spurious negative numbers close to zero.
-      eigenvalues[i]  = sqrt(fabs(eigenvalues[i])) * rnorm_mt(rng, 0, 1);
+      eigenvalues[i] = sqrt(fabs(eigenvalues[i])) * rnorm_mt(rng, 0, 1);
     }
     Vector ans(eigenvectors * eigenvalues);
     ans += mu;
@@ -44,10 +46,11 @@ namespace BOOM {
   }
 
   Vector rmvn_L(const Vector &mu, const Matrix &L) {
-    return rmvn_L_mt(GlobalRng::rng, mu, L);}
+    return rmvn_L_mt(GlobalRng::rng, mu, L);
+  }
 
-  Vector rmvn_L_mt(RNG & rng, const Vector &mu, const Matrix &L) {
-    // L is the lower cholesky triange of Sigma
+  Vector rmvn_L_mt(RNG &rng, const Vector &mu, const Matrix &L) {
+    // L is the lower cholesky triangle of Sigma.
     uint n = mu.size();
     Vector wsp(n);
     for (uint i = 0; i < n; ++i) wsp[i] = rnorm_mt(rng, 0, 1);
@@ -58,7 +61,7 @@ namespace BOOM {
     return rmvn_mt(GlobalRng::rng, mu, V);
   }
 
-  Vector rmvn_mt(RNG & rng, const Vector &mu, const SpdMatrix &V) {
+  Vector rmvn_mt(RNG &rng, const Vector &mu, const SpdMatrix &V) {
     bool okay = true;
     Matrix L = V.chol(okay);
     if (okay) return rmvn_L_mt(rng, mu, L);
@@ -69,16 +72,15 @@ namespace BOOM {
     return rmvn_ivar_mt(GlobalRng::rng, mu, ivar);
   }
 
-  Vector rmvn_ivar_mt(RNG & rng, const Vector &mu, const SpdMatrix &ivar) {
+  Vector rmvn_ivar_mt(RNG &rng, const Vector &mu, const SpdMatrix &ivar) {
     // Draws a multivariate normal with mean mu and precision matrix
     // ivar.
     Matrix U = ivar.chol().t();
     return rmvn_precision_upper_cholesky_mt(rng, mu, U);
   }
 
-  Vector rmvn_precision_upper_cholesky_mt(RNG & rng,
-                                          const Vector &mu,
-                                          const Matrix &precision_upper_cholesky) {
+  Vector rmvn_precision_upper_cholesky_mt(
+      RNG &rng, const Vector &mu, const Matrix &precision_upper_cholesky) {
     // U is the upper cholesky factor of the inverse variance Matrix
     uint n = mu.size();
     Vector z(n);
@@ -87,33 +89,34 @@ namespace BOOM {
     return Usolve_inplace(precision_upper_cholesky, z) + mu;
   }
 
-  Vector rmvn_suf(const SpdMatrix & Ivar, const Vector & IvarMu) {
-    return rmvn_suf_mt(GlobalRng::rng, Ivar, IvarMu);  }
+  Vector rmvn_suf(const SpdMatrix &Ivar, const Vector &IvarMu) {
+    return rmvn_suf_mt(GlobalRng::rng, Ivar, IvarMu);
+  }
 
-  Vector rmvn_suf_mt(RNG & rng, const SpdMatrix & Ivar, const Vector & IvarMu) {
+  Vector rmvn_suf_mt(RNG &rng, const SpdMatrix &Ivar, const Vector &IvarMu) {
     Chol L(Ivar);
     uint n = IvarMu.size();
     Vector z(n);
     for (uint i = 0; i < n; ++i) z[i] = rnorm_mt(rng);
     LTsolve_inplace(L.getL(), z);  // returns LT^-1 z which is ~ N(0, Ivar.inv)
-    z+= L.solve(IvarMu);
+    z += L.solve(IvarMu);
     return z;
   }
 
   //======================================================================
-  double dmvn(const Vector &y, const Vector &mu,
-              const SpdMatrix &Siginv, double ldsi, bool logscale) {
+  double dmvn(const Vector &y, const Vector &mu, const SpdMatrix &Siginv,
+              double ldsi, bool logscale) {
     const double log2pi = 1.83787706641;
     double n = y.size();
-    double ans = 0.5*(ldsi - Siginv.Mdist(y, mu) -n*log2pi);
+    double ans = 0.5 * (ldsi - Siginv.Mdist(y, mu) - n * log2pi);
     return logscale ? ans : std::exp(ans);
   }
 
-  double dmvn_zero_mean(const Vector &y, const SpdMatrix &Siginv,
-                        double ldsi, bool logscale) {
+  double dmvn_zero_mean(const Vector &y, const SpdMatrix &Siginv, double ldsi,
+                        bool logscale) {
     const double log2pi = 1.83787706641;
     double n = y.size();
-    double ans = 0.5*(ldsi - Siginv.Mdist(y) -n*log2pi);
+    double ans = 0.5 * (ldsi - Siginv.Mdist(y) - n * log2pi);
     return logscale ? ans : std::exp(ans);
   }
 
