@@ -1,11 +1,24 @@
 // Copyright 2011 Google Inc. All Rights Reserved.
-// Author: stevescott@google.com (Steve Scott)
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
+// version 2.1 of the License, or (at your option) any later version.
+//
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+// Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public
+// License along with this library; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 
 #include <string>
-#include <r_interface/list_io.hpp>
-#include <r_interface/boom_r_tools.hpp>
-#include <cpputil/math_utils.hpp>
-#include <cpputil/report_error.hpp>
+#include "r_interface/list_io.hpp"
+#include "r_interface/boom_r_tools.hpp"
+#include "cpputil/math_utils.hpp"
+#include "cpputil/report_error.hpp"
 
 namespace BOOM {
 
@@ -112,12 +125,14 @@ namespace BOOM {
   }
 
   //======================================================================
-  PartialSpdListElement::PartialSpdListElement(
-      Ptr<SpdParams> prm, const std::string &name, int which, bool report_sd)
+  PartialSpdListElement::PartialSpdListElement(const Ptr<SpdParams> &prm,
+                                               const std::string &name,
+                                               int which, bool
+                                               report_sd)
       : RealValuedRListIoElement(name),
-      prm_(prm),
-      which_(which),
-      report_sd_(report_sd) {}
+        prm_(prm),
+        which_(which),
+        report_sd_(report_sd) {}
 
   void PartialSpdListElement::write() {
     CheckSize();
@@ -146,11 +161,11 @@ namespace BOOM {
     }
   }
   //======================================================================
-  UnivariateListElement::UnivariateListElement(Ptr<UnivParams> prm,
+  UnivariateListElement::UnivariateListElement(const Ptr<UnivParams> &prm,
                                                const std::string &name)
       : RealValuedRListIoElement(name),
-      prm_(prm)
-      {}
+        prm_(prm)
+  {}
 
   void UnivariateListElement::write() {
     data()[next_position()] = prm_->value();
@@ -161,10 +176,10 @@ namespace BOOM {
   }
   //======================================================================
   StandardDeviationListElement::StandardDeviationListElement(
-      Ptr<UnivParams> variance, const std::string &name)
+      const Ptr<UnivParams> &variance, const std::string &name)
       : RealValuedRListIoElement(name),
         variance_(variance)
-      {}
+  {}
 
   void StandardDeviationListElement::write() {
     data()[next_position()] = sqrt(variance_->value());
@@ -218,7 +233,7 @@ namespace BOOM {
   }
 
   //======================================================================
-  VectorListElement::VectorListElement(Ptr<VectorParams> prm,
+  VectorListElement::VectorListElement(const Ptr<VectorParams> &prm,
                                        const std::string &name,
                                        const std::vector<string> &element_names)
       : RealValuedRListIoElement(name),
@@ -272,7 +287,7 @@ namespace BOOM {
     }
   }
   //======================================================================
-  GlmCoefsListElement::GlmCoefsListElement(Ptr<GlmCoefs> coefs,
+  GlmCoefsListElement::GlmCoefsListElement(const Ptr<GlmCoefs> &coefs,
                                            const std::string &param_name,
                                            const std::vector<string> &element_names)
       : VectorListElement(coefs, param_name, element_names),
@@ -287,7 +302,7 @@ namespace BOOM {
   }
 
   //======================================================================
-  SdVectorListElement::SdVectorListElement(Ptr<VectorParams> prm,
+  SdVectorListElement::SdVectorListElement(const Ptr<VectorParams> &prm,
                                            const std::string &name)
       : RealValuedRListIoElement(name),
         prm_(prm),
@@ -383,7 +398,7 @@ namespace BOOM {
 
   //======================================================================
 
-  MatrixListElement::MatrixListElement(Ptr<MatrixParams> m,
+  MatrixListElement::MatrixListElement(const Ptr<MatrixParams> &m,
                                        const std::string &param_name)
       : MatrixListElementBase(param_name),
         prm_(m),
@@ -467,6 +482,7 @@ namespace BOOM {
       : RealValuedRListIoElement(param_name),
         array_view_(0, Array::index3(0, 0, 0))
   {
+    parameters_.reserve(parameters.size());
     for (int i = 0; i < parameters.size(); ++i) {
       add_vector(parameters[i]);
     }
@@ -498,11 +514,24 @@ namespace BOOM {
     RMemoryProtector protector;
     SEXP buffer = protector.protect(Rf_alloc3DArray(
         REALSXP, niter, number_of_groups, dim));
+    set_buffer_group_names(buffer);
     StoreBuffer(buffer);
     array_view_.reset(data(), Array::index3(niter, number_of_groups, dim));
     return buffer;
   }
 
+  void HierarchicalVectorListElement::set_buffer_group_names(SEXP buffer) {
+    if (group_names_.empty()) return;
+    RMemoryProtector protector;
+    SEXP r_dimnames = protector.protect(Rf_allocVector(VECSXP, 3));
+    // The leading dimension (MCMC iteration number) does not get
+    // names.
+    SET_VECTOR_ELT(r_dimnames, 0, R_NilValue);
+    SET_VECTOR_ELT(r_dimnames, 1, CharacterVector(group_names_));
+    SET_VECTOR_ELT(r_dimnames, 2, R_NilValue);
+    Rf_dimnamesgets(buffer, r_dimnames);
+  }
+
   void HierarchicalVectorListElement::prepare_to_stream(SEXP object) {
     RealValuedRListIoElement::prepare_to_stream(object);
     RMemoryProtector protector;
@@ -536,6 +565,16 @@ namespace BOOM {
     }
   }
 
+  void HierarchicalVectorListElement::set_group_names(
+      const std::vector<std::string> &group_names) {
+    if (group_names.size() != parameters_.size()) {
+      report_error("Vector of group names must be the same size as the "
+                   "number of groups.");
+    }
+    group_names_ = group_names;
+  }
+  
+
   void HierarchicalVectorListElement::CheckSize() {
     const std::vector<int> &dims(array_view_.dim());
     if (dims[1] != parameters_.size() ||
@@ -620,7 +659,7 @@ namespace BOOM {
 
   //======================================================================
 
-  SpdListElement::SpdListElement(Ptr<SpdParams> m,
+  SpdListElement::SpdListElement(const Ptr<SpdParams> &m,
                                  const std::string &param_name)
       : MatrixListElementBase(param_name),
         prm_(m),
