@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -16,48 +17,44 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <cpputil/math_utils.hpp>
-#include <cpputil/report_error.hpp>
+#include "cpputil/math_utils.hpp"
+#include "cpputil/report_error.hpp"
 
-#include <LinAlg/Vector.hpp>
-#include <LinAlg/Matrix.hpp>
+#include "LinAlg/Matrix.hpp"
+#include "LinAlg/Vector.hpp"
 
-#include <numopt.hpp>
-#include <TargetFun/TargetFun.hpp>
+#include "TargetFun/TargetFun.hpp"
+#include "numopt.hpp"
 
-#include <vector>
-#include <iostream>
-#include <iomanip>
 #include <cmath>
+#include <iomanip>
+#include <iostream>
+#include <vector>
 
-namespace BOOM{
+namespace BOOM {
   using namespace std;
 
-  const double stepredn =0.2;
-  const double acctol =0.0001;
-  const double reltest =10.0;
+  const double stepredn = 0.2;
+  const double acctol = 0.0001;
+  const double reltest = 10.0;
 
   /*  BFGS variable-metric method, based on Pascal code
       in J.C. Nash, `Compact Numerical Methods for Computers', 2nd edition,
       converted by p2c then re-crafted by B.D. Ripley */
 
-  double bfgs(Vector &b,
-              const Target &target,
-              const dTarget &dtarget,
-              int maxit,
-              double abstol, double reltol,
-              int &fncount, int & grcount, bool & fail,
-              int trace_frequency){
-    bool trace = trace_frequency>0;
+  double bfgs(Vector &b, const Target &target, const dTarget &dtarget,
+              int maxit, double abstol, double reltol, int &fncount,
+              int &grcount, bool &fail, int trace_frequency) {
+    bool trace = trace_frequency > 0;
     int nREPORT = trace_frequency;
     bool accpoint;
     double Fmin;
-    int   count, funcount, gradcount;
+    int count, funcount, gradcount;
     double f, gradproj;
-    int   i, j, ilast, iter = 0;
+    int i, j, ilast, iter = 0;
     double s, steplength;
     double D1, D2;
-    int   n;
+    int n;
     int n0 = b.size();
 
     Vector g(n0);  // gradient
@@ -74,14 +71,13 @@ namespace BOOM{
     Vector t(n);
     Vector X(n);
     Vector c(n);
-    Matrix B(n,n);
+    Matrix B(n, n);
 
     f = target(b);
 
-    if (!std::isfinite(f)){
+    if (!std::isfinite(f)) {
       std::ostringstream err;
-      err << "Non-fatal warning: initial value in bfgs is not finite"
-          << endl
+      err << "Non-fatal warning: initial value in bfgs is not finite" << endl
           << "Initial x = " << b << endl
           << "Initial f(x) = " << f << endl;
       report_warning(err.str());
@@ -98,22 +94,22 @@ namespace BOOM{
     do {
       if (ilast == gradcount) {
         for (i = 0; i < n; i++) {
-          for (j = 0; j < i; j++) B(i,j) = 0.0;
-          B(i,i) = 1.0;
+          for (j = 0; j < i; j++) B(i, j) = 0.0;
+          B(i, i) = 1.0;
         }
       }
-      X=b;
-      c=g;
+      X = b;
+      c = g;
       gradproj = 0.0;
       for (i = 0; i < n; i++) {
         s = 0.0;
-        for (j = 0; j <= i; j++) s -= B(i,j) * g[j];
-        for (j = i + 1; j < n; j++) s -= B(j,i) * g[j];
+        for (j = 0; j <= i; j++) s -= B(i, j) * g[j];
+        for (j = i + 1; j < n; j++) s -= B(j, i) * g[j];
         t[i] = s;
         gradproj += s * g[i];
       }
 
-      if (gradproj < 0.0) {     /* search direction is downhill */
+      if (gradproj < 0.0) { /* search direction is downhill */
         steplength = 1.0;
         accpoint = false;
         do {
@@ -127,7 +123,7 @@ namespace BOOM{
             f = target(b);
             funcount++;
             accpoint = std::isfinite(f) &&
-              (f <= Fmin + gradproj * steplength * acctol);
+                       (f <= Fmin + gradproj * steplength * acctol);
             if (!accpoint) {
               steplength *= stepredn;
             }
@@ -135,16 +131,16 @@ namespace BOOM{
         } while (!(count == n || accpoint));
         // SLS... changed the following line, which appears to assume f>0
         //        bool enough = (f > abstol) &&
-        bool enough = (fabs(f-Fmin) > abstol) &&
-          fabs(f - Fmin) > reltol * (fabs(Fmin) + reltol);
+        bool enough = (fabs(f - Fmin) > abstol) &&
+                      fabs(f - Fmin) > reltol * (fabs(Fmin) + reltol);
         /* stop if value if small or if relative change is low */
         if (!enough) {
           count = n;
           Fmin = f;
         }
-        if (count < n) {/* making progress */
+        if (count < n) { /* making progress */
           Fmin = f;
-          dtarget(b,g);
+          dtarget(b, g);
           gradcount++;
           iter++;
           D1 = 0.0;
@@ -157,32 +153,31 @@ namespace BOOM{
             D2 = 0.0;
             for (i = 0; i < n; i++) {
               s = 0.0;
-              for (j = 0; j <= i; j++)
-                s += B(i,j) * c[j];
-              for (j = i + 1; j < n; j++)
-                s += B(j,i) * c[j];
+              for (j = 0; j <= i; j++) s += B(i, j) * c[j];
+              for (j = i + 1; j < n; j++) s += B(j, i) * c[j];
               X[i] = s;
               D2 += s * c[i];
             }
             D2 = 1.0 + D2 / D1;
             for (i = 0; i < n; i++) {
               for (j = 0; j <= i; j++)
-                B(i,j) += (D2 * t[i] * t[j]
-                           - X[i] * t[j] - t[i] * X[j]) / D1;
+                B(i, j) += (D2 * t[i] * t[j] - X[i] * t[j] - t[i] * X[j]) / D1;
             }
-          } else {      /* D1 < 0 */
+          } else { /* D1 < 0 */
             ilast = gradcount;
           }
-        } else {        /* no progress */
+        } else { /* no progress */
           if (ilast < gradcount) {
             count = 0;
             ilast = gradcount;
           }
         }
-      } else {          /* uphill search */
+      } else { /* uphill search */
         count = 0;
-        if (ilast == gradcount) count = n;
-        else ilast = gradcount;
+        if (ilast == gradcount)
+          count = n;
+        else
+          ilast = gradcount;
         /* Resets unless has just been reset */
       }
       if (trace && (iter % nREPORT == 0)) {
@@ -191,14 +186,15 @@ namespace BOOM{
         report_message(msg);
       }
       if (iter >= maxit) break;
-      if (gradcount - ilast > 2 * n)
-        ilast = gradcount;      /* periodic restart */
+      if (gradcount - ilast > 2 * n) ilast = gradcount; /* periodic restart */
     } while (count != n || ilast != gradcount);
     if (trace) {
       ostringstream msg;
       msg << "final value " << Fmin << endl;
-      if (iter < maxit) msg << "converged" << endl;
-      else msg << "stopped after " << iter << "iterations" << endl;
+      if (iter < maxit)
+        msg << "converged" << endl;
+      else
+        msg << "stopped after " << iter << "iterations" << endl;
       report_message(msg);
     }
     fail = (iter < maxit) ? false : true;
